# with_modules:: define to 0 if you don't want the modules to be built
# with_qemu_img: change this to include/exclude qemu-img from the package

%define with_spice 1

%define with_qemu_img 1
%define with_modules 1
%define build_arches x86_64


%if %{with_modules}
%define mod_arch_dir x86


# Hacks to make it go through brew:
%define kmodtool bash %{SOURCE11}
%{!?kversion: %define kversion 2.6.18-194.8.1.el5}

%define kmod_name kvm
%define kverrel %(%{kmodtool} verrel %{?kversion} 2>/dev/null)

# only the default kernel (no suffix)
%define flavors_to_build ""

# the subdirectory where the modules will be placed
# NOTE: It must be an exclusive directory for our package,
# because the install/uninstall scripts will work
# on all .ko files on this directory.
%define mod_dir extra/kmod-%{name}

%endif

# normally kvmversion and pkgversion will be the same,
# but for -rc and snapshots (e.g. 78-rc1), we need to use
# something else (e.g. version: 78, release: 0.1.rc1),
# to keep RPM version comparison working

%define kvmversion 83-maint-snapshot-20090205
%define pkgversion 83
%define pkgrelease 164
%define zrelease   21

Summary: Kernel-based Virtual Machine
Name: kvm
Version: %{pkgversion}
Release: %{pkgrelease}%{?dist}.%{zrelease}

# There is a mix of different licenses on the source code:
# - qemu: GPLv2, MIT, BSD, and possibly GPLv2+
# - kernel: GPLv2 and possibly others
# - libfdt: BSD and possibly others
# - bios: LGPLv2+ (no other licenses, it seems)
# - vgabios: LGPLv2+ (no other licenses, it seems)
# - libkvm: LGPLv2 and possibly others
#
# GPLv2 seems to be the safest answer
# https://fedoraproject.org/wiki/Licensing/FAQ#How_should_I_handle_multiple_licensing_situations.3F
# bz#490741
License: GPLv2
Group: Development/Tools
URL: http://%{name}.sf.net


################################################################################
# READ THIS BEFORE DEALING WITH THE TARBALL + PATCHES ON THIS PACKAGE
################################################################################
#
# Beware, there are some things to be careful about, on the # tarball+patches
# packaged below:
#
# 1) It is a upstream git snapshot, from the maint/2.6.29 branch. The main
#    tarball is generated by kvm-make-release (based on the script Avi uses to
#    generate the official upstream release tarballs).
#
# 2) The official-like tarball generated by kvm-make-release needs to be
#    stripped of the crypto code to avoid crypto export complications.
#    Beware, the resulting tarball won't compile without the patches that
#    change it to use libgcrypt (patches 1-4)
#
# 3) The pre-built bios and etherboot binaries need to be removed from
#    the tarball, also.
#
# - Steps 2 and 3 are done by kvm-strip-tarball.sh
#
# 3) The upstream KVM kernel-code patches apply against kvm.git, but the
#    files on kvm.git are different from the files on the released kvm
#    tarballs, because they are mangled by 'make sync'. To avoid having
#    to translate the kernel patches to the mangled files, kvm-make-release
#    was hacked to generate a -kernel.tar.gz file, containing the pristine
#    files from kvm.git. The kernel patches are applied against those files,
#    and we run 'make sync' on %%build
#
################################################################################

#Source0: http://download.sourceforge.net/sourceforge/%{name}/%{name}-%{kvmversion}.tar.gz
#Source0: http://people.qumranet.com:8888/avi/snapshots/kvm-snapshot-%{snapshot}.tar.gz

# The output of kvm-make-release, similar to official releases,
# but after going through kvm-strip-tarball.sh.
#
# Usage: sh kvm-strip-tarball.sh kvm-%{kvmversion}
Source0: %{name}-%{kvmversion}-stripped.tar.gz

# Pristine KVM kernel files from the kernel kvm.git repository.
# We need those files to be able to apply kvm.git patches without
# manually retranslating them.
Source1: %{name}-%{kvmversion}-kernel.tar.gz

# kernel module stuff:
Source2: %{name}-kmod-preamble
Source10: %{name}.modules
Source11: kmodtool

# list of non-whitelisted kernel symbols KVM uses.
# this will be used to filter out the find-requires output, after build.
Source12: kvm-ksym-whitelist

# Helper scripts:

# generates a kvm tarball like the official release ones, from git
Source21: kvm-make-release
# strips the cripto code from the tarball
Source22: kvm-strip-tarball.sh


#########################################
# kvm-userspace.git patches:

Patch1: kvm-0001-qemu-configure-check-for-libgcrypt.patch
Patch2: kvm-0002-qemu-qcow-use-libgcrypt-AES-implementation.patch
Patch3: kvm-0003-qemu-vnc-use-libgcrypt-for-DES-encryption-on-authe.patch
Patch4: kvm-0004-Kill-sha1-test-code.patch
# The above patches complement the kvm-strip-tarball.sh stuff

Patch5: kvm-0005-qxl-import-base-qxl-files-from-qdesktop-repo.patch
Patch6: kvm-0006-avoid-cancelling-ide-dma.patch
Patch7: kvm-0007-export-anon_inode_getfd.patch
Patch8: kvm-0008-ksmctl-buildsystem.patch
Patch9: kvm-0009-ksmctl.patch
Patch10: kvm-0010-qxl-add-qxl-device-support-libspice.patch
Patch11: kvm-0011-qemu-always-install-SIGIO-handler.patch
Patch12: kvm-0012-qemu-port-Uri-s-migration-notifiers.patch
Patch13: kvm-0013-Fix-CVE-2008-0928-insufficient-block-device-addres.patch
Patch14: kvm-0014-kvm-qemu-don-t-fail-building-when-pc-bios-dir-is-e.patch
Patch15: kvm-0015-Use-native-anon_inodes-on-RHEL5-if-available.patch
Patch16: kvm-0016-compat-code-fixes-for-RHEL-5.3.patch
Patch17: kvm-0017-include-asm-svm.h-on-external-module-compat.h.patch
Patch18: kvm-0018-kvm-userspace-set-pci-mem-to-start-at-0xc100000-and.patch
Patch19: kvm-0019-hpet-config-mask-fix.patch
Patch20: kvm-0020-Use-macros-for-virtio-net-PCI-vendor-device-IDs.patch
Patch21: kvm-0021-Use-the-default-subsystem-vendor-ID-for-virtio-devic.patch
Patch22: kvm-0022-qemu-add-audio-interface.patch
Patch23: kvm-0023-qemu-control-qxl-ram-size-via-command-line.patch
Patch24: kvm-0024-qemu-fix-isa-vga-dirty-page-log.patch
Patch25: kvm-0025-qemu-added-mem-size-to-QXLDevInfo.patch
Patch26: kvm-0026-spice-add-vdi_port.patch
Patch27: kvm-0027-qemu-Print-asynchronous-notifications-on-request.patch
Patch28: kvm-0028-qemu-vnc-Use-async-notifications-for-closing-down.patch
Patch29: kvm-0029-qemu-rtc-Use-async-notifications-for-time-change-m.patch
Patch30: kvm-0030-qemu-Use-async-notification-for-guest-shutdown-mess.patch
Patch31: kvm-0031-qemu-notify-async-management-when-migration-finis.patch
Patch32: kvm-0032-qemu-Use-async-notification-for-guest-reboot-messag.patch
Patch33: kvm-0033-Add-vmchannel-support-again.patch
Patch34: kvm-0034-vmchannel-Fix-qemu_chr_open-usage.patch
Patch35: kvm-0035-Add-rtc-td-hack-option-to-fix-time-drift-with-RTC-o.patch
Patch36: kvm-0036-bdrv_write-should-not-stop-on-partial-write-Gleb-Na.patch
Patch37: kvm-0037-Return-errno-on-write-failure-Gleb-Natapov.patch
Patch38: kvm-0038-Handle-link-status-in-qemu_sendv_packet.patch
Patch39: kvm-0039-kvm-qemu-fix-the-prototype-of-virtio_net_init.patch
Patch40: kvm-0040-vmchannel-Update-to-hypercall-device-implementation.patch
Patch41: kvm-0041-Remove-the-advertising-clause-from-the-slirp-license.patch
Patch42: kvm-0042-ksm-buildsystem.patch
Patch43: kvm-0043-kmem-cache.patch
Patch44: kvm-0044--ksm.patch
Patch45: kvm-0045-imported-patch-ksm-register.patch
Patch46: kvm-0046-udev-rules-for-ksm.patch
Patch47: kvm-0047-modprobe-ksm-mem.patch
Patch48: kvm-0048-kvm-swapping-with-kprobes.patch
Patch49: kvm-0049-fix-signed-unsigned-overflows-in-SCSI-disk-Rik-van.patch
Patch50: kvm-0050-support-2TB-SCSI-disks-Rik-van-Riel.patch
Patch51: kvm-0051-SCSI-divide-capacity-by-s-cluster_size-Rik-van-Rie.patch
Patch52: kvm-0052-Avoid-confusion-given-future-mainline-kernel-module.patch
Patch53: kvm-0053-Add-ksmctl-to-spec.patch
Patch54: kvm-0054-qemu-drive_init-Don-t-try-to-read-passwords-before.patch
Patch55: kvm-Stop-VM-on-ENOSPC-error-IDE.patch
Patch56: kvm-Stop-VM-on-error-in-scsi-disk.patch
Patch57: kvm-Stop-VM-on-error-in-virtio-blk.patch
Patch58: kvm-kvm-qemu-Allow-calling-vm_stop-from-vcpu-thread.patch
Patch59: kvm-vdi_port-don-t-modifay-device-while-in-stop-state.patch
Patch60: kvm-Don-t-notify-virtio-devices-before-S_DRIVER_OK.patch
Patch61: kvm-kvm-qemu-Don-t-unregister-unassigned-PCI-BAR.patch
Patch62: kvm-kvm-qemu-preallocate-mem-path-memory-by-default.patch
Patch63: kvm-kvm-qemu-Remove-eflags-conversion-into-emulator-fo.patch
Patch64: kvm-Always-return-latest-pmsts-instead-of-the-old-one.patch
Patch65: kvm-kvm-qemu-make-mem-path-memory-allocation-depend.patch
Patch66: kvm-Fix-SIGSEGV-crash-in-slirp-networking-code.patch
Patch67: kvm-check-SCSI-read-write-requests-against-max-LBA.patch
Patch68: kvm-qemu-vnc-reset-has_WMVi-when-new-client-connects.patch
Patch69: kvm-fix-use-of-host-serial-port.patch
Patch70: kvm-don-t-call-kvm_init_vcpu-twice.patch
Patch71: kvm-Fix-GPE-registers-read-write-handling.patch
Patch72: kvm-Fix-CPU-hotplug.patch
Patch73: kvm-Use-reserved-STS-bits-from-PIIX4-chipset-to-avoid-cl.patch
Patch74: kvm-PCI-hotplug-SCI-fix.patch
Patch75: kvm-qemu-fix-double-removal-of-assigned-device.patch
Patch76: kvm-backport-kvm-qemu-fix-leak-of-ioperm-data.patch
Patch77: kvm-backport-kvm-qemu-remove-the-useless-parameter.patch
Patch78: kvm-qemu-use-fd-instead-of-QEMUFile-in-pre-VM-migrate-s.patch
Patch79: kvm-external-module-compatibility-for-hrtimer_expi.patch
Patch80: kvm-handle-IRQ-status-injection-in-userspace.patch
Patch81: kvm-Allow-additions-of-ACPI-tables-from-command-line.patch
Patch82: kvm-cirrus-cleanup-reset-handler.patch
Patch83: kvm-add-notification-for-vmstops.patch
Patch84: kvm-Change-default-werror-semantics-from-report-to-en.patch
Patch85: kvm-Fix-cpu_physical_memory_rw-for-64-bit-I-O-accesses.patch
Patch86: kvm-block-qcow2-keep-highest-allocated-byte-Uri-Lublin.patch
Patch87: kvm-block-qcow2-export-highest_allocated-through-BlockD.patch
Patch88: kvm-info-blockstats-show-highest_allocated-if-exists-U.patch
Patch89: kvm-qcow2-format-keep-num_free_bytes-and-show-it-upo.patch
Patch90: kvm-qemu-img-info-show-highest_alloc-and-num_free_byte.patch
Patch91: kvm-Introducing-qcow2-extensions-keep-backing-file-for.patch
Patch92: kvm-qemu-img-adding-a-F-base_fmt-option-to-qemu-img.patch
Patch93: kvm-bios-make-MMIO-address-page-aligned-in-guest.patch
Patch94: kvm-external-module-backward-compatibility-for-com.patch
Patch95: kvm-external-module-handle-compound_head-on-RHEL.patch
Patch96: kvm-vmchannel-use-Red-Hat-s-PCI-vendor-ID.patch
Patch97: kvm-qemu-prevent-reset-of-vga-fb-mapping-in-case-of-isa.patch
Patch98: kvm-TPR-patching-instruction_is_ok-fix-virtual-addre.patch
Patch99: kvm-Fix-size-of-async_printable_events-array.patch
Patch100: kvm-Parse-full-PCI-device-addresses-Markus-Armbruster.patch
Patch101: kvm-Backport-upstream-QEMU-PCI-hotplug-code.patch
Patch102: kvm-make-qemu_announce_self-handle-non-contiguous-net-ta.patch
Patch103: kvm-qemu-fix-physical-memory-migration.patch
Patch104: kvm-host_device_remove-remove-incorrect-check-for-devic.patch
Patch105: kvm-e1000-Fix-RX-descriptor-low-threshold-interrupt-log.patch
Patch106: kvm-qemu-fix-bad-physical-address-in-kvm_update_dirty_p.patch
Patch107: kvm-vdi_port-fix-migration.patch
Patch108: kvm-external-module-do-not-hardcode-tsc_khz.patch
Patch109: kvm-qemu-stop-start-cpus-before-after-devices.patch
Patch110: kvm-extboot-should-update-number-of-HDs-reported-by-BIOS.patch
Patch111: kvm-Revert-Introducing-qcow2-extensions-keep-backing.patch
Patch112: kvm-Revert-qemu-img-info-show-highest_alloc-and-num_f.patch
Patch113: kvm-Revert-qcow2-format-keep-num_free_bytes-and-sho.patch
Patch114: kvm-Revert-info-blockstats-show-highest_allocated-if-e.patch
Patch115: kvm-Revert-block-qcow2-export-highest_allocated-throug.patch
Patch116: kvm-Revert-block-qcow2-keep-highest-allocated-byte-Ur.patch
Patch117: kvm-Introducing-qcow2-extensions-Uri-Lublin.patch
Patch118: kvm-block-support-known-backing-format-for-image-create.patch
Patch119: kvm-block-qcow2-keep-backing-file-format-in-a-qcow2-ext.patch
Patch120: kvm-block-qcow2-keep-highest-allocated-offset.patch
Patch121: kvm-block-set-high-watermark-and-get-a-notification-whe.patch
Patch122: kvm-Show-drive-name-on-ENOSPC-notification.patch
Patch123: kvm-Avoid-running-audio-ctl-s-when-vm-is-not-running.patch
Patch124: kvm-external-module-hrtimer_expires_remaining-was.patch
Patch125: kvm-Make-make-install-depend-on-bios-and-vgabios.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch126: kvm-qemu-tool-adding-an-empty-implementation-of-term_pr.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch127: kvm-block_set_watermark-use-term_printf_async-for-notif.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch128: kvm-Fix-at-least-one-cause-of-qcow2-corruption.-Nolan.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch129: kvm-Flush-all-pending-io-at-the-end-of-a-migration.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch130: kvm-make-BlockDriver-struct-opaque-and-global.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch131: kvm-Reopen-block-drivers-after-migration.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch132: kvm-qcow2-corruption-Fix-alloc_cluster_link_l2.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch133: kvm-Change-RTC-time-drift-IRQ-re-injection-logic.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch134: kvm-KSM-fix-bug-495348.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch135: kvm-KSM-fix-bug-495349-KSM-correctness-issue.patch
# For bz#497886 - Import kvm fixes from RHEV branch
Patch136: kvm-KSM-fix-bug-495351-effective-issue.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch137: kvm-KSM-fix-bug-495714.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch138: kvm-fix-extboot-from-boot-with-cache-off.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch139: kvm-KSM-fix-bug-495912.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch140: kvm-KSM-fix-495350-effective-bug.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch141: kvm-ksm-fix-Bug-496668-stabilaty-issue.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch142: kvm-qemu-drop-packet-from-tap-device-if-all-NICs-are.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch143: kvm-fix-effective-bug-497042.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch144: kvm-qemu-fixup-4GB-memslot-large-page-alignment.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch145: kvm-Import-qemu-io-source-from-upstream.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch146: kvm-qemu-io-Comment-out-readv-writev-code.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch147: kvm-Add-qemu-io-to-Makefile-and-configure.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch148: kvm-Fix-migration-with-smp-Bz-485966.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch149: kvm-char-Fix-closing-of-various-char-devices-Jan-Kiszka.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch150: kvm-spice-improve-audio-quality-493279.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch151: kvm-spice-using-term_printf_async-for-vdi-log-messages-4.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch152: kvm-qemu-Add-support-for-SMBIOS-command-line-options-Ale.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch153: kvm-Don-t-try-to-extract-protocol-from-absolute-filename.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch154: kvm-kvmtrace_format-read-usr-share-kvm-formats-by-defaul.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch155: kvm-e1000-Do-not-reinit-pci-config-space-to-0.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch156: kvm-Fix-cluster-freeing-in-qcow2.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch157: kvm-Revert-Fix-CVE-2008-0928-insufficient-block-device-a.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch158: kvm-Fix-CVE-2008-0928-insufficient-block-device-address-.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch159: kvm-don-t-use-a-32-bit-bit-type-as-offset-argument.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch160: kvm-Fix-oops-on-2.6.25-guest-Rusty-Russell.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch161: kvm-Fix-segfault-after-tap-host_net_remove.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch162: kvm-Fix-virtio-net-segfault-during-live-migrate-after-NI.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch163: kvm-Fix-e1000-segfault-during-live-migrate-after-NIC-hot.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch164: kvm-Backport-oom_check-from-upstream.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch165: kvm-qcow2-fix-image-creation-for-large-2TB-images-Chris-.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch166: kvm-Fix-live-migratation-failure-after-pcnet-NIC-hot-unp.patch
# For bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt
Patch167: kvm-Fix-qemu_realloc-with-size-0.patch
# For bz#498071 - kvm external module build fixes for RHEL 5.4
Patch168: kvm-external-module-Fix-build-for-VT-d-AMD-IOMMU.patch
# For bz#498071 - kvm external module build fixes for RHEL 5.4
Patch169: kvm-external-module-don-t-conflict-w-phys_addr_t.patch
# For bz#501777 - kvm doesn't build on newer RHEL-5.4 kernels because of get_user_pages_fast()
Patch170: kvm-external-module-don-t-redefined-get_user_pages_fast-.patch
# For bz#501777 - kvm doesn't build on newer RHEL-5.4 kernels because of get_user_pages_fast()
Patch171: kvm-Revert-external-module-don-t-redefined-get_user_page.patch
# For bz#501777 - kvm doesn't build on newer RHEL-5.4 kernels because of get_user_pages_fast()
Patch172: kvm-external-module-don-t-redefine-get_user_pages_fast-o.patch
# For bz#498071 - kvm external module build fixes for RHEL 5.4
Patch173: kvm-Fix-request_irq-for-2.6.19.patch
# For bz#498071 - kvm external module build fixes for RHEL 5.4
Patch174: kvm-Fix-kvm_request_irq-race.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch175: kvm-qemu-device-assignment-don-t-use-libkvm-s-privat.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch176: kvm-qemu-device-assignment-add-assigned_dev_update_i.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch177: kvm-qemu-device-assignment-fix-ROM-writing.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch178: kvm-libkvm-support-for-irq-routing.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch179: kvm-qemu-initialize-irq-routing-table.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch180: kvm-libkvm-Fix-return-of-kvm_commit_irq_routes.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch181: kvm-libkvm-add-deassign-ioctl.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch182: kvm-qemu-free-device-on-error-in-init_assigned_devic.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch183: kvm-qemu-wrap-assign_device-and-assign_irq.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch184: kvm-qemu-deassign-device-from-guest.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch185: kvm-qemu-fix-hot-remove-assigned-device.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch186: kvm-qemu-fix-build-breakage-on-non-device-deassignme.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch187: kvm-qemu-deassign-irq-for-INTx.patch
# For bz#498085 - kvm add guest MSI support
Patch188: kvm-libkvm-support-KVM_ASSIGN_DEV_IRQ-and-KVM_DEASSI.patch
# For bz#498085 - kvm add guest MSI support
Patch189: kvm-qemu-Replace-force-type-convert-with-container_o.patch
# For bz#498085 - kvm add guest MSI support
Patch190: kvm-qemu-Make-device-assignment-depend-on-libpci.patch
# For bz#498085 - kvm add guest MSI support
Patch191: kvm-qemu-Figure-out-device-capability.patch
# For bz#498085 - kvm add guest MSI support
Patch192: kvm-qemu-Support-for-device-capability.patch
# For bz#498085 - kvm add guest MSI support
Patch193: kvm-libkvm-user-interface-for-MSI-type-irq-routing.patch
# For bz#498085 - kvm add guest MSI support
Patch194: kvm-libkvm-allocate-unused-gsi-for-irq-routing.patch
# For bz#498085 - kvm add guest MSI support
Patch195: kvm-qemu-expose-MSI-capability-to-guest.patch
# For bz#498085 - kvm add guest MSI support
Patch196: kvm-qemu-Support-MSI-convert-to-INTx-in-device-assig.patch
# For bz#498085 - kvm add guest MSI support
Patch197: kvm-qemu-Add-MSI-X-related-macro-to-pci.c.patch
# For bz#498085 - kvm add guest MSI support
Patch198: kvm-libkvm-add-ioctl-wrappers-for-KVM_SET_MSIX_ENTRY.patch
# For bz#498085 - kvm add guest MSI support
Patch199: kvm-qemu-enable-MSI-X-capabilty-for-assigned-device.patch
# For bz#498085 - kvm add guest MSI support
Patch200: kvm-qemu-fix-interrupt-pin-0-assignment.patch
# For bz#498085 - kvm add guest MSI support
Patch201: kvm-qemu-Fill-config-with-correct-VID-DID.patch
# For bz#498085 - kvm add guest MSI support
Patch202: kvm-qemu-emulate-command-register-for-SRIOV-virtual-.patch
# For bz#498085 - kvm add guest MSI support
Patch203: kvm-qemu-Move-assigned-device-capability-init-earlie.patch
# For bz#498085 - kvm add guest MSI support
Patch204: kvm-qemu-improve-pci-host-device-address-parsing.patch
# For bz#498085 - kvm add guest MSI support
Patch205: kvm-qemu-don-t-check-per-vector-mask-bit-before-enab.patch
# For bz#498085 - kvm add guest MSI support
Patch206: kvm-qemu-Fix-wrong-counting-of-MSI-X-table-size.patch
# For bz#498085 - kvm add guest MSI support
Patch207: kvm-device-assignment-move-memset-to-after-mmap-failure-.patch
# For bz#498085 - kvm add guest MSI support
Patch208: kvm-Remove-MSI-masking-when-setting-initial-MSI-X-entrie.patch
# For bz#498085 - kvm add guest MSI support
Patch209: kvm-nr_cpu_ids-compat.patch
# For bz#498085 - kvm add guest MSI support
Patch210: kvm-smp_send_reschedule-compat.patch
# For bz#498085 - kvm add guest MSI support
Patch211: kvm-Adjust-kvm_smp_send_reschedule-availability.patch
# For bz#498085 - kvm add guest MSI support
Patch212: kvm-Adjust-nr_cpu_ids-check.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch213: kvm-Revert-qemu-fix-bad-physical-address-in-kvm_update_d.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch214: kvm-Enable-dirty-logging-for-all-regions-during-migratio.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch215: kvm-migrate.c-migrate_fd_put_buffer-Do-not-busyloop-stop.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch216: kvm-cirrus-fix-text-screen-corruption-on-reset.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch217: kvm-Support-multiple-VNC-clients-re-added.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch218: kvm-vnc-fix-multiple-connections-displaystate-initializa.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch219: kvm-vnc-Remove-checks-for-qemu_realloc-return-value.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch220: kvm-ksm-remove-full-swapping-support-for-kvm-mmu-pages-u.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch221: kvm-keypad-support.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch222: kvm-Call-missing-qemu_bh_delete-at-the-end-of-raw_aio_em.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch223: kvm-Add-qemu_send_raw-to-vlan.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch224: kvm-Minimal-ethernet-frame-length-is-64-bytes.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch225: kvm-Don-t-send-all-gratuitous-packets-at-once.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch226: kvm-fix-wrong-bios-pci-mapping-for-large-slots-Bug-49943.patch
# For bz#503811 - Pull disable-virtio-balloon patch from RHEV branch
Patch227: kvm-Disable-virtio-balloon-bz-500453.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch228: kvm-augment-info-migrate-with-page-status.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch229: kvm-introduce-set_rate_limit-function-for-QEMUFile.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch230: kvm-allow-changing-the-speed-of-a-running-migration.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch231: kvm-remove-duplicated-code.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch232: kvm-only-execute-lapic-load-when-cpu-is-already-initiali.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch233: kvm-make-sure-kvm_vpu_init-is-the-last-thing-called-in-c.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch234: kvm-Prevent-CD-ROM-media-eject-while-device-is-locked.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch235: kvm-KSM-sync-ksm-and-rhel-5.4-gup-fast.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch236: kvm-ksm-remove-kprobes-usage-for-rhel-5.4-v3.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch237: kvm-KSM-avoid-usage-of-free-slabed-memory.-triggered-wit.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch238: kvm-qxl-fix-message-flood-in-qxl_display_update-501190.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch239: kvm-fix-bigmem-offset-calculation-for-qxl.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch240: kvm-add-non-arbitrary-migration-stop-condition.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch241: kvm-set-migration-max-downtime.patch
# For bz#504047 - kvm doesn't build on newer RHEL-5.4 kernels because of get_user_pages_fast()
Patch242: kvm-doesn-t-build-on-newer-RHEL-5.4-kernels-because-.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch243: kvm-fix-qemu_aio_flush.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch244: kvm-spice-change-vendor-id-504190.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch245: kvm-migrate_fd_close-delete-associated-io-handler-before.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch246: kvm-qemu-add-notify-command-line-option-to-enable-async-.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch247: kvm-migration-exec-notify-upon-successful-completion-of-.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch248: kvm-asynchronous-notifications-add-all-event-v3.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch249: kvm-exec-migration-handle-EINTR-in-popen_get_buffer-v3.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch250: kvm-KSM-avoid-losing-but-no-mem-leak-rmap_items-inside-k.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch251: kvm-vdi_port-call-disconnect-on-reset-504463.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch252: kvm-Add-rtc-reset-function.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch253: kvm-fix-unresigered-vbe-physical-mapping-as-reserved-mem.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch254: kvm-Add-reset-to-e1000-nic.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch255: kvm-Add-reset-to-rtl8139-nic.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch256: kvm-Register-uhci_reset-callback.patch
# For bz#504713 - BIOS bug - processor goes missing with RHEL3U8 boot kernel
Patch257: kvm-bios-Fix-missing-DMI-table-entries.patch
# For bz#504237 - Pull RHEV bugfixes for RHEL
Patch258: kvm-Correctly-assign-apic-ids-for-hotplugged-cpus.patch
# For bz#500717 - qemu-kvm can generate invalid screendumps during reboot
Patch259: kvm-Fix-vga_screen_dump_blank-PPM-generation-bz-500717.patch
# For bz#506017 - 'qemu-img check' subcommand is not backported
Patch260: kvm-Add-qemu-img-check-subcommand.patch
# For bz#504628 - Skype crashes on VM.
Patch261: kvm-enable-sysenter-on-32bit-guests-skype-fix.patch
# For bz#505090 - Virtual machine fails to start without cdom - qemu: could not open disk image /dev/sr0
Patch262: kvm-bz-505090-Guess-host-device-type-from-requested-gues.patch
# For bz#505641 - Remote VNC client can cause any QEMU VNC server to crash with a double-free
Patch263: kvm-vnc-rework-VncState-release-workflow.patch
# For bz#503790 - virtio balloon: add a command-line option to disable it at runtime
Patch264: kvm-Revert-Disable-virtio-balloon-bz-500453.patch
# For bz#503790 - virtio balloon: add a command-line option to disable it at runtime
Patch265: kvm-Remove-broken-command-line-option-balloon.patch
# For bz#503790 - virtio balloon: add a command-line option to disable it at runtime
Patch266: kvm-New-command-line-option-balloon.patch
# For bz#500977 - ne2k-pci segfault during live migrate after NIC hot-unplug
# For bz#500978 - Live migration fails after rtl8139 NIC hot-unplug
# For bz#500980 - Live migrate fails after i82551 NIC hot-unplug
Patch267: kvm-net-avoid-leaking-VLANClientState-on-PCI-NIC-hot-rem.patch
# For bz#500978 - Live migration fails after rtl8139 NIC hot-unplug
Patch268: kvm-Fix-rtl8139-segfault-during-live-migrate-after-NIC-h.patch
# For bz#500977 - ne2k-pci segfault during live migrate after NIC hot-unplug
Patch269: kvm-Fix-ne2k_pci-segfault-during-live-migrate-after-NIC-.patch
# For bz#500980 - Live migrate fails after i82551 NIC hot-unplug
Patch270: kvm-Fix-eepro100-segfault-during-live-migrate-after-NIC-.patch
# For bz#507880 - qemu hangs during VNC connection from RHEVM
Patch271: kvm-make-vnc-socket-non-blocking.patch
# For bz#505999 - pause reason not stored by qemu
Patch272: kvm-provide-stop-reason-on-demand.patch
# For bz#508623 - Only 1 processor can be detected in "systeminfo" of win2k3 guest with -smp 2 and ACPI multiprocessor HAL.
Patch273: kvm-Change-default-CPU-model-to-model-6-skype-fix-2.patch
# For bz#506375 - ksm latency issue when killing guests
Patch274: kvm-fix-bug-506375.patch
# For bz#505440 - Panic on suspend with KSM module loaded
Patch275: kvm-KSM-suspend-fix.patch
# For bz#497058 - Change virtio-blk pci dubclass to PCI_CLASS_STORAGE_SCSI
Patch276: kvm-Windows-virtio-driver-cannot-pass-WHQL-certification.patch
# For bz#508861 - kvm: add tap send buffer limit to help UDP networking
Patch277: kvm-net-add-net-tap-sndbuf-option-with-a-sensible-defaul.patch
# For bz#508776 - KVM: MMU: limit rmap chain
Patch278: kvm-kvmtrace-update-formats.patch
# For bz#507942 - QEMU: Windows 2003's built-in driver for e1000 does not work with QEMU's e1000  implementation
Patch279: kvm-fix-for-bug-507942-bad-macaddr-of-e1000-in-Windows-2.patch
# For bz#511199 - KVM : Failed to migrate VM to a loaded Host
# For bz#507659 - Migrate command not  end and vm  responseless on  Nahalem host
# For bz#511031 - qemu-kvm hang during migration when stress test is running in the guest
Patch280: kvm-Set-the-iothread-s-eventfd-pipe-descriptors-to-non-b.patch
# For bz#512894 - Disable hpet by default
Patch281: kvm-Disable-hpet-by-default-there-is-no-way-to-enable-it.patch
# For bz#504647 - Low UDP throughput from Linux KVM guest
Patch282: kvm-virtio_net-remove-the-tx-mitigation-timer.patch
# For bz#510806 - KVM: invoke pci_reset_function() when PCI device assigned or deassigned to a guest
Patch283: kvm-Use-pci_reset_function-in-RHEL5.4-so-FLR-done-proper.patch
# For bz#512898 - Enable rtd-hack by default
Patch284: kvm-enable-rtc-hack-by-default.patch
# For bz#513252 - Asignation instead of comparation inside if
Patch285: kvm-Fix-hdev_open-error.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch286: kvm-add-option-to-disable-smb-user-directories.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch287: kvm-add-option-to-disable-scsi.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch288: kvm-disable-isapc.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch289: kvm-add-option-to-disable-kvm-nested.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch290: kvm-add-option-to-disable-usb-mass-storage-devices.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch291: kvm-add-option-to-disable-usb-wacom-tablets.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch292: kvm-add-option-to-disable-usb-serial.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch293: kvm-add-option-to-disable-usb-net.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch294: kvm-add-option-to-disable-usb-bluez.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch295: kvm-change-qcow2-default-cache-mode-to-none.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch296: kvm-add-option-to-disable-all-cpu-s-model-different-from.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch297: kvm-add-option-to-disable-vmware-drivers.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch298: kvm-Enable-configure-out-cards-that-we-don-t-support.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch299: kvm-Be-able-to-compile-out-bluetooth.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch300: kvm-Disable-unsupported-block-formats.patch
# For bz#499405 - KVM: add manufacturer and product name info to guest SMBIOS
Patch301: kvm-add-workaround-for-libvirt-bug.patch
# For bz#514526 - Reset qxl, vdi irq line on guest reset
Patch302: kvm-Reset-irq-line-on-qxl-and-vdi-on-guest-reset.patch
# For bz#508664 - KVM: "could not read the boot disk" error message after running "Sys Mark" benchmark on Windows Guest
Patch303: kvm-fix-for-bug-508664-KVM-could-not-read-the-boot-disk.patch
# For bz#512837 - Disable unused/unsupported features on qemu-kvm
Patch304: kvm-Compile-out-NBD-removal.patch
# For bz#513991 - Qemu: change CD right after eject does not work
Patch305: kvm-make-windows-notice-media-change.patch
# For bz#511038 - QEMU: crash because of calling stop twice (QXL assertion)
Patch306: kvm-Work-around-VM-state-change-handlers-running-out-of-.patch
# For bz#514785 - KVM: support for -fda fat:floppy was removed - needed for RHEVM
Patch307: kvm-qemu-restore-bdrv-fat.patch
# For bz#514887 - Mouse and keyboard of guest are unavailable after migration-[kvm-83-101.el5]
Patch308: kvm-ide-calls-register_savevm-three-times-for-pci_ide_sa.patch
# For bz#515275 - guest not accepting keystrokes or mouse clicks after reboot
Patch309: kvm-Initialize-PS2-keyboard-mouse-state-on-reset.patch
# For bz#512672 - Remove initrd warning message
Patch310: kvm-Remove-initrd-warning-message.patch
# For bz#514522 - QEMU: Fix VM change state issue on IO errors
Patch311: kvm-Fix-VM-state-change-handlers-running-out-of-order.patch
# For bz#514522 - QEMU: Fix VM change state issue on IO errors
Patch312: kvm-Revert-Work-around-VM-state-change-handlers-running-.patch
# For bz#518169 - Bad qcow2 performance with cache=off
Patch313: kvm-qcow2-Refactor-update_refcount.patch
# For bz#518169 - Bad qcow2 performance with cache=off
Patch314: kvm-qcow2-Update-multiple-refcounts-at-once.patch
# For bz#518169 - Bad qcow2 performance with cache=off
Patch315: kvm-Combined-patch-of-two-upstream-commits-the-second-fi.patch
# For bz#518169 - Bad qcow2 performance with cache=off
Patch316: kvm-alloc_cluster_link_l2-Write-complete-sectors.patch
# For bz#518169 - Bad qcow2 performance with cache=off
Patch317: kvm-update_refcount-Write-complete-sectors.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch318: kvm-Use-quiet-command-to-get-a-cleaner-build-output.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch319: kvm-This-function-is-not-used-anymore.-It-is-opencoded-i.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch320: kvm-fds-variable-is-not-used.-Remaining-of-a-missmerge.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch321: kvm-use-proper-C89-declarations.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch322: kvm-pit-is-used-in-two-cases-not-easy-way-to-define-.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch323: kvm-In-qemu-all-buffers-are-uint8_t-not-char.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch324: kvm-kvm_allowed-is-exported-in-qemu-kvm.h-and-it-is-used.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch325: kvm-add-three-missing-static-modifiers-for-local-functio.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch326: kvm-put-declaration-of-enable_async_notification-in-a-pr.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch327: kvm-move-several-kvm-variables-after-qemu-kvm.h-include-.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch328: kvm-mark-static-do_block_set_watermark.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch329: kvm-txbufferaccu_offset-and-irq-fields-were-save-load-as.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch330: kvm-mp_state-is-treated-as-unsigned-int-uint32_t-for-sav.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch331: kvm-hp_reset-should-have-type-QEMUResetHandler.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch332: kvm-make-static-lsi_scsi_uninit.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch333: kvm-assigned_dev_data-was-not-used-anywhere.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch334: kvm-bios_enabled-is-load-saved-as-uint32_t-declare-it-as.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch335: kvm-remove-unused-variable.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch336: kvm-add-prototype-for-kvm_add_ioperm_data.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch337: kvm-removed-duplicated-re-declaration-of-kvm_context-2.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch338: kvm-make-static-update_vbios_real_tpr.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch339: kvm-fix-var-may-be-used-uninitialized.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch340: kvm-make-local-functions-static.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch341: kvm-remove-unused-variable-opt_rom_offset.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch342: kvm-removed-duplicated-re-declaration-of-kvm_context.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch343: kvm-perror-is-defined-in-stdio.h-that-got-included-indir.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch344: kvm-remove-unused-variable-cpu.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch345: kvm-nb_sectors-should-be-an-uint64_t.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch346: kvm-uhci_reset-should-have-QEMUResetHandler-type.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch347: kvm-initialize-blen-and-pa-variables-to-0.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch348: kvm-we-got-smp_cpus-declaration-through-sysemu.h.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch349: kvm-int-and-long-masked-as-pointers.-cast-to-avoid-warni.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch350: kvm-we-got-vm_running-declaration-through-sysemu.h.patch
# For bz#503367 - After migration, paused VM is running on destination
# For bz#503367 - After migration, paused VM is running on destination
Patch351: kvm-BZ503367-obey-S-on-migration.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch352: kvm-reason-paramenter-only-exist-in-newer-qemu-s-not-our.patch
# For bz#521835 - German keymap using KVM+VNC missing some keys
Patch353: kvm-Fix-AltGr-and-dead-keys-with-VNC.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch354: kvm-time_t-is-a-long-in-x86_64.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch355: kvm-bugzilla-504237-changed-size-of-variables-to-uint64_.patch
# For bz#502809 - [FEAT] Change qcow2 cluster size to 64k
Patch356: kvm-qcow2-Change-cluster-size-to-64k.patch
# For bz#510706 - qemu-kvm segfault when using i82551 vnic
Patch357: kvm-Fix-for-Bug-510706-qemu-kvm-segfault-when-using-i825.patch
# For bz#521829 - QEMU crash (during virtio-net WHQL tests for Win2008 R2)
Patch358: kvm-qemu-virtio-net-do-not-return-stack-pointer-from-fun.patch
# For bz#524970 - Guest single-cpu IPI leads to a global IPI on host
Patch359: kvm-Use-kernel-s-smp_call_function_single-instead-of-emu.patch
# For bz#525114 - KVM QEMU:RHEL OS VM's became not-responding and stopped answering monitor Commands.
Patch360: kvm-Properly-handle-pthread_cond_timedwait-timing-out.patch
# For bz#522887 - Call to migrate_set_speed after a migrate_cancel causes segmentation fault in kvm
Patch361: kvm-fix-segfault-in-setting-migration-speed.patch
# For bz#511072 - KVM - qemu-img fail to copy a RAW format image over FCP storage
Patch362: kvm-Add-host_device-support-to-qemu-img.-Nolan-Leake.patch
# For bz#511072 - KVM - qemu-img fail to copy a RAW format image over FCP storage
Patch363: kvm-raw-posix-Handle-errors-in-raw_create.patch
# For bz#508040 - Windows XP not using all CPUS
Patch364: kvm-libkvm-Add-a-wrapper-for-an-ioctl-for-the-KVM_SE.patch
# For bz#508040 - Windows XP not using all CPUS
Patch365: kvm-Fetch-sub-leaf-cpuid-values-for-functions-4-0xb-0xd.patch
# For bz#508040 - Windows XP not using all CPUS
Patch366: kvm-Initialize-entire-cpuid2-structure.patch
# For bz#508040 - Windows XP not using all CPUS
Patch367: kvm-extend-smp-parsing-to-include-cores-and-threads-opti.patch
# For bz#508040 - Windows XP not using all CPUS
Patch368: kvm-push-CPUID-level-to-4-to-allow-Intel-multicore-decod.patch
# For bz#508040 - Windows XP not using all CPUS
Patch369: kvm-set-CPUID-bits-to-present-cores-and-threads-topology.patch
# For bz#508040 - Windows XP not using all CPUS
Patch370: kvm-allow-overriding-of-CPUID-level-on-command-line.patch
# For bz#489900 - kvm configure should abort if a required option failed
Patch371: kvm-force-enable-options.patch
# For bz#489900 - kvm configure should abort if a required option failed
Patch372: kvm-move-kvm-extra-features-detection-after-kvm-detectio.patch
# For bz#489900 - kvm configure should abort if a required option failed
Patch373: kvm-add-options-to-request-kvm-pit-and-device-assignment.patch
# For bz#516672 - Disable unused/unsupported features on qemu-kvm
Patch374: kvm-Disable-help-for-vmware-vga-and-enable-nesting.patch
# For bz#516672 - Disable unused/unsupported features on qemu-kvm
Patch375: kvm-Now-that-we-have-disable-bluetooth-disable-also-bt-c.patch
# For bz#516672 - Disable unused/unsupported features on qemu-kvm
Patch376: kvm-migration_notify_register-is-only-used-by-spice.patch
# For bz#516672 - Disable unused/unsupported features on qemu-kvm
Patch377: kvm-Fix-typo-should-have-been-from-the-beggining.patch
# For bz#516672 - Disable unused/unsupported features on qemu-kvm
Patch378: kvm-Don-t-compile-drivers-that-are-not-used-in-a-pc.patch
# For bz#516672 - Disable unused/unsupported features on qemu-kvm
Patch379: kvm-Add-option-to-disable-pcspk.patch
# For bz#516672 - Disable unused/unsupported features on qemu-kvm
Patch380: kvm-usb_bluez-depends-of-bluez.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch381: kvm-test-access-remove-warning.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch382: kvm-test-emulator-remove-unused-variable.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch383: kvm-test-vmexit-remove-warning-undefined-printf.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch384: kvm-external-module-compat-bring-c89-prototypes-to-intel.patch
# For bz#527722 - Build tree for RHEL 5.X and RHEL 5.4.z contains build bugs
Patch385: kvm-RHEL-5.X-5.4.Z-Makefile-fix-ksm-dir-has-no-ARCH-pref.patch
# For bz#528917 - qemu-kvm : msrs[] array in kvm_arch_save_regs() too small / may cause stack corruption
Patch386: kvm-fix-kvm_arch_save_regs-potential-stack-corruptio.patch
# For bz#520394 - KVM : QEMU-Audio attempting to stop unactivated audio device (snd_playback_stop: ASSERT playback_channel->base.active failed).
Patch387: kvm-Fix-VDI-audio-stop.patch
# For bz#529694 - -initrd is broken with > 4GB guests
Patch388: kvm-keep-initrd-in-below-4g-area.patch
# For bz#533059 - kvm modules can't be built against latest kernel-devel package
Patch389: kvm-Add-smp_call_function_many-to-compat_apis.patch
# For bz#531701 - pvclock msr values are not preserved across remote migration
Patch390: kvm-531701-properly-save-kvm-system-time-msr-registers.patch
# For bz#531701 - pvclock msr values are not preserved across remote migration
Patch391: kvm-BZ531701-get-and-set-clock-upon-migration.patch
# For bz#537646 - backports of qemu barrier support
Patch392: kvm-block-use-fdatasync-instead-of-fsync-if-possible.patch
# For bz#537646 - backports of qemu barrier support
Patch393: kvm-block-add-aio_flush-operation.patch
# For bz#537646 - backports of qemu barrier support
Patch394: kvm-ide-use-bdrv_aio_flush.patch
# For bz#537646 - backports of qemu barrier support
Patch395: kvm-virtio-blk-add-volatile-writecache-feature.patch
# For bz#537075 - qcow2: infinite recursion on grow_refcount_table() error handling
Patch396: kvm-qcow2-Fix-grow_refcount_table-error-handling.patch
# For bz#531827 - O/S Filesystem Corruption with RHEL-5.4 on a RHEV Guest
Patch397: kvm-virtio-blk-Stop-VM-on-read-errors.patch
# For bz#531827 - O/S Filesystem Corruption with RHEL-5.4 on a RHEV Guest
# For bz#531827 - O/S Filesystem Corruption with RHEL-5.4 on a RHEV Guest
# For bz#533390 - RHEL5.4 VM image corruption with an IDE v-disk
Patch398: kvm-ide-Stop-VM-on-read-errors.patch
# For bz#531631 - Windows XP unattended install doesn't get an IP address after rebooting, if using -net user
Patch399: kvm-slirp-Reassign-same-address-to-same-DHCP-client.patch
# For bz#537646 - backports of qemu barrier support
Patch400: kvm-block-add-enable_write_cache-flag.patch
# For bz#539589 - kvm can't build against kernel-2.6.18-174.el5
Patch401: kvm-build-fix-add-pci_get_bus_and_slot-to-compat_apis.patch
# For bz#533090 - Windows Server 2008 R2 shutdown hangs after restore from migration
Patch402: kvm-Fix-race-between-migration-and-cpu-main-loop.patch
# For bz#540893 - qemu-img: snapshot info error
Patch403: kvm-qcow2-Store-exact-backing-format-length.patch
# For bz#542923 - Get segmentation fault when running with ide block on kvm-83-136.el5
Patch404: kvm-qcow-qcow2-Add-bdrv_aio_flush.patch
# For bz#537178 - Need to generate SMBIOS table 4 data for windows guests
Patch405: kvm-Make-SMBIOS-pass-MS-SVVP-test.patch
# For bz#545136 - whitelist host virtio networking features
Patch406: kvm-bz-545136-whitelist-host-virtio-networking-features.patch
# For bz#543137 - time drift in win2k364 KVM guest
Patch407: kvm-fix-rtc-td-hack-on-host-without-high-res-timers.patch
# For bz#543979 - gPXE fails to PXE boot on e1000 virtual NIC
Patch408: kvm-v2-RHEL5-BZ543979-get-roms-more-room.-Glauber-Costa.patch
# For bz#530533 - debug message is displayed when save VM state into a compressed file
Patch409: kvm-removing-debugging-printf-leftover.patch
# For bz#549938 - Maintain barrier state after migration
Patch410: kvm-enable_write_cache-is-one-bool-no-need-for-32bits.patch
# For bz#549938 - Maintain barrier state after migration
Patch411: kvm-virtio_blk-save-if-cache-was-enabled.patch
# For bz#549938 - Maintain barrier state after migration
Patch412: kvm-ide-propagate-version_id-to-all-save-load-functions.patch
# For bz#549938 - Maintain barrier state after migration
Patch413: kvm-ide-save-if-cache-was-enabled.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch414: kvm-savevm-add-version_id-to-all-savevm-functions.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch415: kvm-We-need-current-machine-defined-sooner.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch416: kvm-Add-support-for-DeviceVersion-to-machine-type.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch417: kvm-Introduce-rhel5.4.0-machine-type.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch418: kvm-Introduce-rhel-5.5.0-machine-type.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch419: kvm-cpu-for-x86-don-t-save-new-fields-if-version-8.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch420: kvm-RHEL5.4-needs-cpu-at-version-7.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch421: kvm-RHEL-5.4.0-don-t-have-kvmclock.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch422: kvm-RHEL5.4-needs-ide-at-device-version-3.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch423: kvm-RHEL5.4-needs-virtio-blk-at-device-version-2.patch
# For bz#541731 - kvm: migration: mechanism to make older savevm versions to be emitted on some cases
Patch424: kvm-make-5.4.0-machine-the-default.patch
# For bz#545194 - Discrepancy between man page and source code for qcow2 with regards to default value used when no explicit caching is specified
Patch425: kvm-Documentation-Fix-description-of-cache-option-for-dr.patch
# For bz#539250 - Cannot eject cd-rom when configured to host cd-rom
Patch426: kvm-monitor-allow-device-to-be-ejected-if-no-disk-is-ins.patch
# For bz#541084 - KVM: x86: Add KVM_GET/SET_VCPU_EVENTS
Patch427: kvm-x86-Add-support-for-VCPU-event-states.patch
# For bz#550265 - gPXE fails to PXE boot on e1000 virtual NIC
Patch428: kvm-BZ550265-compute-checksum-for-roms-bigger-than-a-seg.patch
# For bz#503759 - hypercall device - Vm becomes non responsive on Sysmark benchmark (when more than 7 vm's running simultaneously)
Patch429: kvm-Fix-a-race-in-the-device-that-cuased-guest-stack-on-.patch
# For bz#552250 - Windows virtio block driver performs poorly on small size requests. In addition, cpu usage on the quest side is very high while handling write requests.
# (REVERTED by kvm-Revert-Queue-notify-support-for-virtio-block-device.patch)
Patch430: kvm-Queue-notify-support-for-virtio-block-device.patch
# For bz#550755 - Hypercall driver doesn't reset device on power-down
Patch431: kvm-The-driver-device-pair-does-not-have-a-reset-option-.patch
# For bz#550755 - Hypercall driver doesn't reset device on power-down
Patch432: kvm-The-driver-device-pair-does-not-have-a-reset-option-2.patch
# For bz#549938 - Maintain barrier state after migration
Patch433: kvm-fix-barriers-support-during-migration.patch
# For bz#553187 - Add rhel-5.4.4 support to rhel5.5.0
Patch434: kvm-Add-machine-name-alias-support.patch
# For bz#553187 - Add rhel-5.4.4 support to rhel5.5.0
Patch435: kvm-make-pc-an-alias-of-rhel5.4.0.patch
# For bz#553187 - Add rhel-5.4.4 support to rhel5.5.0
Patch436: kvm-Introduce-rhel5.4.4-machine-type.patch
# For bz#530134 - RFE - In-place backing file format change
Patch437: kvm-block-Introduce-BDRV_O_NO_BACKING.patch
# For bz#530134 - RFE - In-place backing file format change
Patch438: kvm-qemu-img-rebase.patch
# For bz#517814 - Caps Lock the key's appearance  of guest is not synchronous as host's --view kvm with vnc
Patch439: kvm-vnc-improve-capslock-handling.patch
# For bz#530134 - RFE - In-place backing file format change
Patch440: kvm-block-Add-bdrv_change_backing_file.patch
# For bz#537655 - qemu-img: error creating a new preallocated volume image on FCP storage
Patch441: kvm-qemu-img-Automatically-detect-block-devices.patch
# For bz#537888 - fix unsafe device data handling
Patch442: kvm-qemu-qxl-fix-unsafe-rom-data-handling-bug-537888.patch
# For bz#537888 - fix unsafe device data handling
Patch443: kvm-qxl-fix-qxl-backwards-migration-to-version-3.patch
# For bz#518090 - [RFE] KVM should be able to export advanced cpu flags to the guest
Patch444: kvm-Allow-export-of-sse4.1-sse4.2-cpuid-flags-to-guest.-.patch
# For bz#497507 - Numeric keypad cannot be used in qemu monitor when using vnc to connect guest.
Patch445: kvm-vnc-more-keypad-fixing.patch
# For bz#552240 - Spice (QXL) - please add 1024x576 resolution to the driver (netbooks)
Patch446: kvm-qxl-add-netbooks-common-resolutions.-Rhel-5.5-552240.patch
# For bz#515655 - Add result test to prevent Infinite loop in raw_pread, reading too large offset
Patch447: kvm-block-raw-posix-Abort-on-pread-beyond-end-of-file.patch
# For bz#557327 - migration failed with -M rhel5.4.4 between host 5.5 and host 5.4.4
Patch448: kvm-Fix-cpu-versioning.patch
# For bz#556455 - KVM: WIN7-32bit blue screen (IMAGE_NAME:  ntkrnlmp.exe).
Patch449: kvm-reduce-number-of-reinjects-on-ACK.patch
# For bz#552250 - Windows virtio block driver performs poorly on small size requests. In addition, cpu usage on the quest side is very high while handling write requests.
Patch450: kvm-Revert-Queue-notify-support-for-virtio-block-device.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch451: kvm-qcow2-Fix-error-handling-in-qcow2_grow_l1_table.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch452: kvm-qcow2-Fix-error-handling-in-qcow_save_vmstate.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch453: kvm-qcow2-Return-0-errno-in-get_cluster_table.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch454: kvm-qcow2-Return-0-errno-in-qcow2_alloc_cluster_offset.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch455: kvm-block-Return-original-error-codes-in-bdrv_pread-writ.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch456: kvm-qcow2-Fix-error-handling-in-grow_refcount_table.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch457: kvm-qcow2-Improve-error-handling-in-update_refcount.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch458: kvm-qcow2-Allow-updating-no-refcounts.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch459: kvm-qcow2-Don-t-ignore-update_refcount-return-value.patch
# For bz#537077 - error codes aren't always propagated up through the block layer (e.g. -ENOSPC)
Patch460: kvm-qcow2-Don-t-ignore-qcow2_alloc_clusters-return-value.patch
# For bz#558195 - kvm: NFS : kvm-qemu-img convert failure on RAW/Sparse template with COW/Sparse snapshot
Patch461: kvm-qemu-img-Fix-qemu-img-with-backing-file.patch
# For bz#525323 - QEMU terminates without warning with virtio-net and SMP enabled
Patch462: kvm-qemu-add-routines-for-atomic-16-bit-accesses.patch
# For bz#525323 - QEMU terminates without warning with virtio-net and SMP enabled
Patch463: kvm-qemu-virtio-atomic-access-for-index-values.patch
# For bz#559163 - migration failed host 5.5 with -M rhel5.5.0 to host 5.5 with -M rhel5.5.0.
Patch464: kvm-fix-ide-versioning.patch
# For bz#559163 - migration failed host 5.5 with -M rhel5.5.0 to host 5.5 with -M rhel5.5.0.
Patch465: kvm-cpu-CPU_SAVE_VERSION-is-9-know.patch
# For bz#552487 - Guest image corruption after RHEV-H update to 5.4-2.1.3.el5_4rhev2_1
Patch466: kvm-virtio-blk-Fix-reads-turned-into-writes-after-read-e.patch
# For bz#552487 - Guest image corruption after RHEV-H update to 5.4-2.1.3.el5_4rhev2_1
Patch467: kvm-virtio-blk-Handle-bdrv_aio_read-write-NULL-return.patch
# For bz#560770 - CVE-2010-0297 kvm-userspace-rhel5: usb-linux.c: fix buffer overflow [rhel-5.5]
Patch468: kvm-CVE-2010-0297-usb-linux.c-fix-buffer-overflow.patch
# For bz#544785 - QEMU process can become non-responsive in case command are not pull from qxl vga ring
Patch469: kvm-qxl-defer-vga-updates-in-case-commands-ring-is-full-.patch
# For bz#563141 - qemu-img re-base subcommand got Segmentation fault
Patch470: kvm-qemu-img-Fix-segfault-during-rebase.patch
# For bz#569762 - 'qemu-img re-base' broken on block devices
Patch471: kvm-qemu-img-rebase-Add-f-option.patch
# For bz#536749 - can not boot rhel3.9 with if=virtio
Patch472: kvm-mark-PCI-IRQs-as-edge-triggered-in-mptables.patch
# For bz#495844 - KVM SVVP: "Signed Driver check" failure - on the disabled vCPUs (that the VM's BIOS doesn't hide)
Patch473: kvm-Fix-Windows-guests-SVVP-tests.patch
# For bz#579737 - QEMU: Too many devices are available for unplug in Windows XP (and we don't support that)
Patch474: kvm-Build-an-additional-bios-without-hotplug-support.patch
# For bz#581758 - Win7/32 stuck on 100% CPU (in testing VDI driver unclassified WHQL tests)
Patch475: kvm-fix-wrong-acpi-mapping-rhel5.x-kvm-userspace.patch
# For bz#581766 - qcow2 corruption with I/O error during refcount block allocation
Patch476: kvm-qcow2-Factor-next_refcount_table_size-out.patch
# For bz#581766 - qcow2 corruption with I/O error during refcount block allocation
Patch477: kvm-qcow2-Rewrite-alloc_refcount_block-grow_refcount_tab.patch
# For bz#581766 - qcow2 corruption with I/O error during refcount block allocation
Patch478: kvm-qcow2-More-checks-for-qemu-img-check.patch
# For bz#581764 - memory reported as used (by SwapCache and by Cache) though no process holds it.
Patch479: kvm-avoid-leaving-orphaned-swapcache-in-ksm.patch
# For bz#583947 - Guest aborted when make guest stop on write error
# For bz#586246 - Guest aborted when make guest stop on write error
Patch480: kvm-qcow2-Remove-abort-on-free_clusters-failure.patch
# For bz#581758 - Win7/32 stuck on 100% CPU (in testing VDI driver unclassified WHQL tests)
Patch481: kvm-Revert-fix-wrong-acpi-mapping-rhel5.x-kvm-userspace.patch
# For bz#587278 - After re-base snapshot, the file in the snapshot disappeared
# For bz#596378 - After re-base snapshot, the file in the snapshot disappeared
Patch482: kvm-qemu-img-rebase-Fix-output-image-corruption.patch
# For bz#598488 - qcow2 corruption bug in refcount table growth
# For bz#602363 - qcow2 corruption bug in refcount table growth
Patch483: kvm-qcow2-Fix-corruption-after-refblock-allocation.patch
# For bz#604188 - Guest suffers kernel panic when save snapshot then restart guest
Patch484: kvm-qcow2-Export-synchronous-qcow_read-write-to-avoid-br.patch
# For bz#604159 - virtio-blk: Avoid zeroing every request structure
Patch485: kvm-virtio-blk.c-avoid-zero-every-request-structure.patch
# For bz#606238 - Virtio: Transfer file caused guest in same vlan abnormally quit
# For bz#610343 - Virtio: Transfer file caused guest in same vlan abnormally quit
Patch486: kvm-virtio-net-truncating-packet.patch
# For bz#610344 - Excessive lseek() causes severe performance issues with vm disk images over NFS
Patch487: kvm-raw-posix-Use-pread-pwrite-instead-of-lseek-read-wri.patch
# For bz#610344 - Excessive lseek() causes severe performance issues with vm disk images over NFS
Patch488: kvm-block-Cache-total_sectors-to-reduce-bdrv_getlength-c.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch489: kvm-qcow2-Fix-access-after-end-of-array.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch490: kvm-qcow2-Don-t-ignore-immediate-read-write-failures.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch491: kvm-qcow2-Return-0-errno-in-write_l2_entries.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch492: kvm-qcow2-Fix-error-return-code-in-qcow2_alloc_cluster_l.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch493: kvm-qcow2-Return-0-errno-in-write_l1_entry.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch494: kvm-qcow2-Return-0-errno-in-l2_allocate.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch495: kvm-qcow2-Allow-qcow2_get_cluster_offset-to-return-error.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch496: kvm-qcow2-Change-l2_load-to-return-0-errno.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch497: kvm-qcow2-Return-right-error-code-in-write_refcount_bloc.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch498: kvm-qcow2-Fix-corruption-after-error-in-update_refcount.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch499: kvm-qcow2-Clear-L2-table-cache-after-write-error.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch500: kvm-qcow2-Fix-error-handling-in-l2_allocate.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch501: kvm-qcow2-Restore-L1-entry-on-l2_allocate-failure.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch502: kvm-qcow2-Allow-get_refcount-to-return-errors.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch503: kvm-qcow2-Allow-alloc_clusters_noref-to-return-errors.patch
# For bz#612508 - Backport qcow2 fixes to RHEL 5
Patch504: kvm-qcow2-Return-real-error-code-in-load_refcount_block.patch
# For bz#612507 - qcow2 image corruption when using cache=writeback
Patch505: kvm-block-Add-bdrv_-p-write_sync.patch
# For bz#612507 - qcow2 image corruption when using cache=writeback
Patch506: kvm-qcow2-Use-bdrv_-p-write_sync-for-metadata-writes.patch
Patch507: kvm-qemu-fix-unsafe-ring-handling.patch
# For bz#618205 - SPICE - race in KVM/Spice would cause migration to fail (slots are not registered properly?)
Patch508: kvm-New-slots-need-dirty-tracking-enabled-when-migrating.patch
# For bz#606434 - [kvm] segmentation fault when running qemu-img check on faulty image
# For bz#610342 - [kvm] segmentation fault when running qemu-img check on faulty image
Patch509: kvm-qcow2-Fix-qemu-img-check-segfault-on-corrupted-image.patch
# For bz#606434 - [kvm] segmentation fault when running qemu-img check on faulty image
# For bz#610342 - [kvm] segmentation fault when running qemu-img check on faulty image
Patch510: kvm-qcow2-Don-t-try-to-check-tables-that-couldn-t-be-loa.patch
# For bz#606651 - [kvm] qemu image check returns cluster errors when using virtIO block (thinly provisioned) during e_no_space events (along with EIO errors)
# For bz#618206 - [kvm] qemu image check returns cluster errors when using virtIO block (thinly provisioned) during e_no_space events (along with EIO errors)
Patch511: kvm-qemu-img-check-Distinguish-different-kinds-of-errors.patch
# For bz#606651 - [kvm] qemu image check returns cluster errors when using virtIO block (thinly provisioned) during e_no_space events (along with EIO errors)
# For bz#618206 - [kvm] qemu image check returns cluster errors when using virtIO block (thinly provisioned) during e_no_space events (along with EIO errors)
Patch512: kvm-qcow2-Change-check-to-distinguish-error-cases.patch
# For bz#610343 - Virtio: Transfer file caused guest in same vlan abnormally quit
Patch513: kvm-virtio-net-correct-packet-length-checks.patch
# For bz#619412 - CVE-2010-2784 qemu: insufficient constraints checking in exec.c:subpage_register() [rhel-5.5.z]
Patch514: kvm-Fix-segfault-in-mmio-subpage-handling-code.patch
# end of kvm-userspace.git patches
##########################################

#########################################
# kvm.git (kernel) patches:

Patch1501: kvm-kernel-0001-kvm-handlers-for-ksm.patch
Patch1502: kvm-kernel-0002-KVM-x86-Report-supported-virtualization-extensions.patch
Patch1503: kvm-kernel-0003-KVM-PIT-fix-i8254-pending-count-read.patch
Patch1504: kvm-kernel-0004-KVM-PIT-provide-an-option-to-disable-interrupt-rei.patch
Patch1505: kvm-kernel-0005-KVM-VMX-initialize-TSC-offset-relative-to-vm-creat.patch
Patch1506: kvm-kernel-0006-KVM-Add-kvm_arch_sync_events-to-sync-with-asynchron.patch
Patch1507: kvm-kernel-0007-KVM-Fix-racy-in-kvm_free_assigned_irq.patch
Patch1508: kvm-kernel-0008-KVM-Properly-lock-PIT-creation.patch
Patch1509: kvm-kernel-0009-Disable-kvmclock-for-non-constant-tsc-cpus.patch
Patch1511: kvm-kernel-KVM-Fix-assigned-devices-circular-locking-dependenc.patch
Patch1512: kvm-kernel-KVM-Fix-INTx-for-device-assignment.patch
Patch1513: kvm-kernel-KVM-MMU-Map-device-MMIO-as-UC-in-EPT.patch
Patch1514: kvm-kernel-KVM-x86-fix-LAPIC-pending-count-calculation.patch
Patch1515: kvm-kernel-KVM-VMX-Flush-volatile-msrs-before-emulating-rdmsr.patch
Patch1516: kvm-kernel-Report-IRQ-injection-status-to-userspace.patch
Patch1517: kvm-kernel-KVM-x86-release-time_page-on-vcpu-destruction.patch
Patch1518: kvm-kernel-KVM-VMX-Update-necessary-state-when-guest-enters-l.patch
Patch1519: kvm-kernel-KVM-is_long_mode-should-check-for-EFER.LMA.patch
Patch1520: kvm-kernel-KVM-MMU-Fix-another-largepage-memory-leak.patch
Patch1521: kvm-kernel-KVM-MMU-handle-compound-pages-in-kvm_is_mmio_pfn.patch
Patch1522: kvm-kernel-Disable-kvmclock-by-default.patch
Patch1523: kvm-kernel-Fix-BZ483561-dmesg-flooded-with-kvm-14619-cpu1-u.patch
Patch1524: kvm-kernel-KVM-Fix-missing-smp-tlb-flush-in-invlpg.patch
Patch1525: kvm-kernel-Backport-fix-for-bz-482423-from-upstream.patch
Patch1526: kvm-kernel-Revert-Disable-kvmclock-by-default.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch1527: kvm-kernel-KVM-Add-CONFIG_HAVE_KVM_IRQCHIP.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch1528: kvm-kernel-KVM-Interrupt-mask-notifiers-for-ioapic.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch1529: kvm-kernel-KVM-Reset-PIT-irq-injection-logic-when-the-PIT-IRQ-i.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch1530: kvm-kernel-KVM-Fix-overlapping-check-for-memory-slots.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch1531: kvm-kernel-KVM-MMU-Fix-off-by-one-calculating-large-page-count.patch
# For bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt
Patch1532: kvm-kernel-KVM-MMU-disable-global-page-optimization.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1533: kvm-kernel-KVM-Add-support-to-disable-MSI-for-assigned-device.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1534: kvm-kernel-KVM-Userspace-controlled-irq-routing.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1535: kvm-kernel-KVM-Use-irq-routing-API-for-MSI.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1536: kvm-kernel-KVM-VMX-Use-kvm_mmu_page_fault-handle-EPT-violation-.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1537: kvm-kernel-KVM-Report-IRQ-injection-status-for-MSI-delivered-in.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1538: kvm-kernel-KVM-define-KVM_CAP_DEVICE_DEASSIGNMENT.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1539: kvm-kernel-KVM-fix-kvm_vm_ioctl_deassign_device.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1540: kvm-kernel-KVM-Split-IOAPIC-structure.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1541: kvm-kernel-KVM-Unify-the-delivery-of-IOAPIC-and-MSI-interrupts.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1542: kvm-kernel-KVM-Change-API-of-kvm_ioapic_get_delivery_bitmask.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1543: kvm-kernel-KVM-Update-intr-delivery-func-to-accept-unsigned-lon.patch
# For bz#498084 - Add infrastructure needed for later adding guest MSI support
Patch1544: kvm-kernel-KVM-bit-ops-for-deliver_bitmap.patch
# For bz#498085 - kvm add guest MSI support
Patch1545: kvm-kernel-KVM-Ioctls-for-init-MSI-X-entry.patch
# For bz#498085 - kvm add guest MSI support
Patch1546: kvm-kernel-KVM-Add-MSI-X-interrupt-injection-logic.patch
# For bz#498085 - kvm add guest MSI support
Patch1547: kvm-kernel-KVM-Enable-MSI-X-for-KVM-assigned-device.patch
# For bz#498085 - kvm add guest MSI support
Patch1548: kvm-kernel-KVM-Get-support-IRQ-routing-entry-counts.patch
# For bz#498085 - kvm add guest MSI support
Patch1549: kvm-kernel-KVM-Device-assignment-framework-rework.patch
# For bz#498085 - kvm add guest MSI support
Patch1550: kvm-kernel-KVM-Correct-deassign-device-ioctl-to-IOW.patch
# For bz#498085 - kvm add guest MSI support
Patch1551: kvm-kernel-KVM-Wake-up-waitqueue-before-calling-get_cpu.patch
# For bz#498085 - kvm add guest MSI support
Patch1552: kvm-kernel-KVM-use-smp_send_reschedule-in-kvm_vcpu_kick.patch
# For bz#498085 - kvm add guest MSI support
Patch1553: kvm-kernel-KVM-protect-assigned-dev-workqueue-int-handler-and-i.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch1554: kvm-kernel-KVM-Fix-NX-support-reporting.patch
# For bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
Patch1555: kvm-kernel-KVM-x86-check-for-cr3-validity-in-ioctl_set_sregs.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch1556: kvm-kernel-KVM-x86-check-for-cr3-validity-in-mmu_alloc_roots.patch
# For bz#504018 - kernel oops at kvm_get_intr_delivery_bitmask+0x4e/0x86
Patch1557: kvm-kernel-Merge-kvm_ioapic_get_delivery_bitmask-into-kvm_get_i.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch1558: kvm-kernel-fix-bug-between-mm_to_kvm-and-kvm_get_kvm-RHEL-5-bac.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch1559: kvm-kernel-KVM-x86-Ignore-reads-to-K7-EVNTSEL-MSRs.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch1560: kvm-kernel-KVM-MMU-protect-kvm_mmu_change_mmu_pages-with-mmu_lo.patch
# For bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt
Patch1561: kvm-kernel-KVM-Fix-PDPTR-reloading-on-CR4-writes.patch
# For bz#504237 - Pull RHEV bugfixes for RHEL
Patch1562: kvm-kernel-KVM-Make-paravirt-tlb-flush-also-reload-the-PAE-PDPT.patch
# For bz#482423 - Kaspersky AV crash the VM after installation
Patch1563: kvm-kernel-kvm-x86-ignore-reads-to-perfctr-msrs.patch
# For bz#507730 - KVM: SVM: Remove port 80 passthrough (upstream backport)
Patch1564: kvm-kernel-KVM-SVM-Remove-port-80-passthrough-upstream-backport.patch
# For bz#507733 - KVM: protect concurrent make_all_cpus_request (upstream backport)
Patch1565: kvm-kernel-KVM-protect-concurrent-make_all_cpus_request-upstrea.patch
# For bz#510087 - KVM: limit lapic periodic timer frequency
Patch1566: kvm-kernel-KVM-limit-lapic-periodic-timer-frequency.patch
# For bz#509208 - KVM fixes to make gPXE boot ROMs work
Patch1567: kvm-kernel-KVM-Introduce-set-get-_interrupt_shadow.patch
# For bz#509208 - KVM fixes to make gPXE boot ROMs work
Patch1568: kvm-kernel-KVM-Deal-with-interrupt-shadow-state-for-emulated-in.patch
# For bz#508776 - KVM: MMU: limit rmap chain
Patch1569: kvm-kernel-MMU-limit-rmap-chain.patch
# For bz#510770 - BUG: soft lockup - CPU#4 stuck for 10s! on kksmd
# For bz#505629 - KVM: MMU: protect kvm_mmu_change_mmu_pages with mmu_lock (upstream backport)
Patch1570: kvm-kernel-KVM-fix-missing-locking-in-alloc_mmu_pages.patch
# For bz#513098 - KVM: take mmu_lock when updating a deleted slot (upstream backport)
Patch1571: kvm-kernel-KVM-take-mmu_lock-when-updating-a-deleted-slot.patch
# For bz#513394 - KVM: SVM: force new asid on vcpu migration (upstream backport)
Patch1572: kvm-kernel-KVM-SVM-force-new-asid-on-vcpu-migration.patch
# For bz#512712 - Support huge pages in KVM
Patch1573: kvm-kernel-KVM-Fix-dirty-bit-tracking-for-slots-with-large-page.patch
# For bz#513946 - keyboard is slow in windows SMP guest.
Patch1574: kvm-kernel-Avoid-redelivery-of-edge-interrupt-before-next-edge.patch
# For bz#487857 - The emulator hung after input "cpu_set 1 online" on qemuMonitor and select "System->Shutdown"
Patch1575: kvm-kernel-KVM-MMU-handle-n_free_mmu_pages-n_alloc_mmu_pages-in.patch
# For bz#487857 - The emulator hung after input "cpu_set 1 online" on qemuMonitor and select "System->Shutdown"
Patch1576: kvm-kernel-KVM-MMU-fix-bogus-alloc_mmu_pages-assignment.patch
# For bz#519397 - KVM: MMU: make __kvm_mmu_free_some_pages handle empty list (upstream backport)
Patch1577: kvm-kernel-KVM-MMU-make-__kvm_mmu_free_some_pages-handle-empty-.patch
# For bz#502543 - Windows 2008 R2 KVM guest can not restart when set it as multiple cpus
# For bz#503322 - NMI filtering for AMD (Windows 2008 R2 KVM guest can not restart when set it as multiple cpus)
# For bz#492290 - KVM: XP virtio-net tests fail with BSOD on AMD host (due to lack of NMI injection masking ability)
Patch1578: kvm-kernel-add-nmi-support-to-svm.patch
# For bz#520285 - windows 64 bit does vmexit on each cr8 access.
Patch1579: kvm-kernel-VMX-Fix-cr8-exiting-control-clobbering-by-EPT.patch
# For bz#515549 - upstream qemu issues on rhel 5.4
Patch1580: kvm-kernel-Backport-44882eed2ebe7f75f8cdae5671ab1d6e0fa40dbc.patch
# For bz#515549 - upstream qemu issues on rhel 5.4
Patch1581: kvm-kernel-kvm-fix-ack-not-being-delivered-when-msi-present.patch
# For bz#515549 - upstream qemu issues on rhel 5.4
Patch1582: kvm-kernel-kvm-fix-build-with-defconfig.patch
# For bz#521025 - rtc-td-hack stopped working. Time drifts in windows
Patch1583: kvm-kernel-Fix-coalesced-interrupt-reporting-in-IOAPIC.patch
# For bz#502543 - Windows 2008 R2 KVM guest can not restart when set it as multiple cpus
# For bz#521749 - Guest Window2008-R2-datacenter installation is stopped at  step "Setup will continue after restarting your computer"
Patch1584: kvm-kernel-reset-hflags-on-cpu-reset.patch
# For bz#488130 - KVM: VMX: Don't intercept MSR_KERNEL_GS_BASE (upstream patch)
Patch1585: kvm-kernel-KVM-VMX-Don-t-intercept-MSR_KERNEL_GS_BASE.patch
# For bz#488130 - KVM: VMX: Don't intercept MSR_KERNEL_GS_BASE (upstream patch)
Patch1586: kvm-kernel-Revert-KVM-VMX-Don-t-intercept-MSR_KERNEL_GS_BASE.patch
# For bz#524126 - kernel: KVM: x86: Disallow hypercalls for guest callers in rings > 0 [rhel-5.5]
Patch1587: kvm-kernel-KVM-VMX-Optimize-vmx_get_cpl.patch
# For bz#524126 - kernel: KVM: x86: Disallow hypercalls for guest callers in rings > 0 [rhel-5.5]
Patch1588: kvm-kernel-KVM-x86-Disallow-hypercalls-for-guest-callers-in-rin.patch
# For bz#488130 - KVM: VMX: Don't intercept MSR_KERNEL_GS_BASE (upstream patch)
Patch1589: kvm-kernel-KVM-VMX-Don-t-intercept-MSR_KERNEL_GS_BASE-v2.patch
# For bz#526837 - KVM: x86: verify MTRR/PAT validity (upstream backport)
Patch1590: kvm-kernel-KVM-x86-verify-MTRR-PAT-validity.patch
# For bz#517324 - KVM does not implement proper support for hardware task linking when using vm8086 mode
Patch1591: kvm-kernel-KVM-VMX-Adjust-rflags-if-in-real-mode-emulation.patch
# For bz#517324 - KVM does not implement proper support for hardware task linking when using vm8086 mode
Patch1592: kvm-kernel-KVM-When-switching-to-a-vm8086-task-load-segments-as.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch1593: kvm-kernel-RHEL5.4-defined-this-constants-in-asm-msr.h.patch
# For bz#515749 - Remove warnings from kvm compilation
Patch1594: kvm-kernel-For-RHEl5.x-return-types-of-hrtimers-is-int.patch
# For bz#518081 - vmentry fails with ept misconfig
Patch1595: kvm-kernel-KVM-VMX-flush-TLB-with-INVEPT-on-cpu-migration.patch
# For bz#517324 - KVM does not implement proper support for hardware task linking when using vm8086 mode
Patch1596: kvm-kernel-KVM-Fix-task-switch-back-link-handling-v2-including-.patch
# For bz#516762 - qemu aborted when restart 32bitwin23k with more than 4G mem in intel host.
Patch1597: kvm-kernel-get_tss_base_addr-should-return-gpa_t-type.patch
# For bz#525699 - x86_64 guest hang when set guest's cpu1 online on AMD host
Patch1598: kvm-kernel-KVM-SVM-Reset-cr0-properly-on-vcpu-reset.patch
# For bz#492663 - KVM: Timer event should not unconditionally unhalt vcpu
Patch1599: kvm-kernel-KVM-Timer-event-should-not-unconditionally-unhalt-vc.patch
# For bz#502086 - KVM: Fix interrupt unhalting a vcpu when it shouldn't
Patch1600: kvm-kernel-KVM-Fix-interrupt-unhalting-a-vcpu-when-it-shouldn-t.patch
# For bz#516545 - qemu-kvm crashed when setting 32bitwin28k with 64G ram
# For bz#517223 - BUG: warning at /builddir/build/BUILD/kvm-83-maint-snapshot-20090205/kernel-/x86/x86.c:240/kvm_queue_exception_e() (Tainted: G     )
Patch1601: kvm-kernel-allow-to-address-up-to-48-bits-of-physical-memory-in.patch
# For bz#531701 - pvclock msr values are not preserved across remote migration
Patch1602: kvm-kernel-531701-KERNEL-v2-allow-userspace-to-adjust-kvmclock-.patch
# For bz#532086 - Rhev-Block driver causes  'unhandled vm exit' with 32bit win2k3r2sp2 Guest VM  on restart
Patch1603: kvm-kernel-KVM-x86-make-double-triple-fault-promotion-generic-t.patch
# For bz#532086 - Rhev-Block driver causes  'unhandled vm exit' with 32bit win2k3r2sp2 Guest VM  on restart
Patch1604: kvm-kernel-KVM-x86-raise-TSS-exception-for-NULL-CS-and-SS-segme.patch
# For bz#541165 - CVE-2009-4031 kernel: KVM: x86 emulator: limit instructions to 15 bytes [rhel-5.5]
Patch1605: kvm-kernel-KVM-x86-emulator-limit-instructions-to-15-bytes.patch
# For bz#531887 - BSOD BAD_POOL_HEADER STOP 0x19 during boot of Windows Server 2008 R2 installer
Patch1606: kvm-kernel-KVM-MMU-remove-prefault-from-invlpg-handler.patch
# For bz#541084 - KVM: x86: Add KVM_GET/SET_VCPU_EVENTS
Patch1607: kvm-kernel-KVM-x86-Add-KVM_GET-SET_VCPU_EVENTS.patch
# For bz#553126 - CVE-2010-0309 kvm: cat /dev/port in guest cause the host hang [rhel-5.5]
Patch1608: kvm-kernel-KVM-PIT-control-word-is-write-only.patch
# For bz#559095 - EMBARGOED CVE-2010-0298 kvm: emulator privilege escalation [rhel-5.5]
Patch1609: kvm-kernel-KVM-introduce-kvm_read_guest_virt-kvm_write_guest_vi.patch
# For bz#559095 - EMBARGOED CVE-2010-0298 kvm: emulator privilege escalation [rhel-5.5]
Patch1610: kvm-kernel-KVM-remove-the-vmap-usage.patch
# For bz#559095 - EMBARGOED CVE-2010-0298 kvm: emulator privilege escalation [rhel-5.5]
Patch1611: kvm-kernel-KVM-Use-kvm_-read-write-_guest_virt-to-read-and-writ.patch
# For bz#559095 - EMBARGOED CVE-2010-0298 kvm: emulator privilege escalation [rhel-5.5]
Patch1612: kvm-kernel-KVM-fix-memory-access-during-x86-emulation.patch
# For bz#560698 - EMBARGOED CVE-2010-0306 kvm: emulator privilege escalation IOPL/CPL level check [rhel-5.5]
Patch1613: kvm-kernel-Check-IOPL-level-during-io-instruction-emulation.patch
# For bz#560698 - EMBARGOED CVE-2010-0306 kvm: emulator privilege escalation IOPL/CPL level check [rhel-5.5]
Patch1614: kvm-kernel-Fix-popf-emulation.patch
# For bz#560698 - EMBARGOED CVE-2010-0306 kvm: emulator privilege escalation IOPL/CPL level check [rhel-5.5]
Patch1615: kvm-kernel-Check-CPL-level-during-privilege-instruction-emulati.patch
# For bz#563465 - EMBARGOED CVE-2010-0419 kvm: emulator privilege escalation segment selector check [rhel-5.5]
Patch1616: kvm-kernel-KVM-Don-t-check-access-permission-when-loading-segme.patch
# For bz#563465 - EMBARGOED CVE-2010-0419 kvm: emulator privilege escalation segment selector check [rhel-5.5]
Patch1617: kvm-kernel-KVM-Disable-move-to-segment-registers-and-jump-far-i.patch
# For bz#563517 - KVM: Check cpl before emulating debug register access [rhel-5.5]
Patch1618: kvm-kernel-KVM-VMX-Check-cpl-before-emulating-debug-register-ac.patch
# For bz#566385 - KVM host panic due to fault in paging64_sync_page() / panic occurs in connection with PCI passthru devices
Patch1619: kvm-kernel-avoid-collision-between-out-of-sync-ksm-and-pci-pass.patch
# For bz#578579 - Linux pvmmu guests (FC11, FC12, etc) crash on boot on AMD hosts with NPT disabled
Patch1620: kvm-kernel-KVM-x86-disable-paravirt-mmu-reporting.patch
# For bz#577266 - Time drift in win2k3-64bit and win2k8-64bit smp guest
Patch1621: kvm-kernel-account-only-for-IRQ-injected-into-vcpu0.patch
# For bz#579863 - SR-IOV -- Guest exit and host hang on if boot VM with 8 VFs assigned
Patch1622: kvm-kernel-Backport-KVM-fix-irq_source_id-size-verification.patch
# For bz#588251 - kvm spinning updating a guest pte, unkillable
# For bz#596381 - kvm spinning updating a guest pte, unkillable
Patch1623: kvm-kernel-KVM-MMU-bail-out-pagewalk-on-kvm_read_guest-error.patch
# For bz#596625 - race condition in pvclock wallclock calculation
Patch1624: kvm-kernel-KVM-Fix-wallclock-version-writing-race.patch
# For bz#610341 - fork causes trouble for vcpu threads
Patch1625: kvm-kernel-KVM-Keep-slot-ID-in-memory-slot-structure.patch
# For bz#610341 - fork causes trouble for vcpu threads
Patch1626: kvm-kernel-KVM-Prevent-internal-slots-from-being-COWed.patch
# For bz#570532 - EMBARGOED CVE-2010-0435 kvm: vmx null pointer dereference [rhel-5.6]
Patch1627: kvm-kernel-fix-null-pointer-dereference.patch
# For bz#616796 - KVM uses wrong permissions for large guest pages
Patch1628: kvm-kernel-KVM-MMU-fix-conflict-access-permissions-in-direct-sp.patch

# end of kvm.git (kernel) patches
###################################3


BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: SDL-devel
# to build the bios
BuildRequires: dev86
BuildRequires: iasl
BuildRequires: zlib-devel
# TLS / x509 auth in VNC server
BuildRequires: gnutls-devel
# for the docs
BuildRequires: texi2html
BuildRequires: rsync
BuildRequires: pkgconfig
# for device-assignment:
BuildRequires: pciutils-devel

# kvm kernel side is only x86/x86_64 as that's where the hardware is
ExclusiveArch: %{build_arches}
Requires: initscripts >= 8.08-1

# We need PXE roms from either gpxe or etherboot, but we want etherboot
# by default.
# yum pulls gpxe because its name is shorter (!) if we require the
# pxe-roms-qemu virtual package, so we need an explicit etherboot
# dependency here, unfortunately.
Requires: etherboot-zroms-kvm >= 5.4.4-13.el5

# the libspice.so dependency is not enough, because it's also provided
# by tclspice (bz#555657)
Requires: qspice-libs

# vdsm < vdsm-4.4-30926 looks for /usr/bin/qemu-kvm, that doesn't exist anymore
# (bz#504221)
Conflicts: vdsm < 4.4-30926


%if %{with_modules}
Requires: kmod-kvm
%endif

%if %{with_spice}
BuildRequires: qspice-libs-devel
%endif

%if %{with_modules}
# Ignore non-whitelisted symbols that we know KVM uses (bz#533197)
%define _use_internal_dependency_generator 0
%define __find_requires sh -c '/usr/lib/rpm/redhat/find-requires "$@" | grep -v -x -F -f %{SOURCE12}

# this macro is broken on brew:
# BuildRequires: %{kernel_module_package_buildreqs}
# use this instead:
BuildRequires: kernel-devel

# if it wasn't going through brew, this would be enough:
#kernel_module_package -p %{name}-kmod-preamble
# but instead we use this:
%{expand:%(kmp_override_preamble=%{name}-kmod-preamble %{kmodtool} rpmtemplate_kmp %{kmod_name} %{kverrel} %{mod_dir} %{flavors_to_build} 2>/dev/null)}

%endif


%package tools
Summary: KVM debugging and diagnostics tools
Group: Development/Tools

# the main package owns /usr/share/kvm
Requires: %{name}


%if %{with_qemu_img}
%package qemu-img
Summary: Qemu disk image utility
Group: Development/Tools
Provides: qemu-img = 0.9.1.kvm.%{version}
%endif

%description
KVM (for Kernel-based Virtual Machine) is a full virtualization solution
for Linux on x86 hardware.

Using KVM, one can run multiple virtual machines running unmodified Linux
or Windows images. Each virtual machine has private virtualized hardware:
a network card, disk, graphics adapter, etc.


%description tools
This package contains some diagnostics and debugging tools for KVM,
such as kvmtrace and kvm_stat.


%if %{with_qemu_img}
%description qemu-img
This package contains qemu-img, the qemu command line tool for
manipulating disk images, built from the qemu source code included on
the KVM source.

This package should be useful for systems that don't have a qemu package
but need qemu-img.
%endif

%prep
%setup -q -b 0 -n kvm-%{kvmversion} -a 1

# we must not use any of the binaries from the qemu/pc-bios/ directory,
# as they don't have the corresponding sources shipped with them
rm -rf qemu/pc-bios/*

#userspace code patches:
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1
%patch42 -p1
%patch43 -p1
%patch44 -p1
%patch45 -p1
%patch46 -p1
%patch47 -p1
%patch48 -p1
%patch49 -p1
%patch50 -p1
%patch51 -p1
%patch52 -p1
%patch53 -p1
%patch54 -p1
%patch55 -p1
%patch56 -p1
%patch57 -p1
%patch58 -p1
%patch59 -p1
%patch60 -p1
%patch61 -p1
%patch62 -p1
%patch63 -p1
%patch64 -p1
%patch65 -p1
%patch66 -p1
%patch67 -p1
%patch68 -p1
%patch69 -p1
%patch70 -p1
%patch71 -p1
%patch72 -p1
%patch73 -p1
%patch74 -p1
%patch75 -p1
%patch76 -p1
%patch77 -p1
%patch78 -p1
%patch79 -p1
%patch80 -p1
%patch81 -p1
%patch82 -p1
%patch83 -p1
%patch84 -p1
%patch85 -p1
%patch86 -p1
%patch87 -p1
%patch88 -p1
%patch89 -p1
%patch90 -p1
%patch91 -p1
%patch92 -p1
%patch93 -p1
%patch94 -p1
%patch95 -p1
%patch96 -p1
%patch97 -p1
%patch98 -p1
%patch99 -p1
%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -p1
%patch111 -p1
%patch112 -p1
%patch113 -p1
%patch114 -p1
%patch115 -p1
%patch116 -p1
%patch117 -p1
%patch118 -p1
%patch119 -p1
%patch120 -p1
%patch121 -p1
%patch122 -p1
%patch123 -p1
%patch124 -p1
%patch125 -p1
%patch126 -p1
%patch127 -p1
%patch128 -p1
%patch129 -p1
%patch130 -p1
%patch131 -p1
%patch132 -p1
%patch133 -p1
%patch134 -p1
%patch135 -p1
%patch136 -p1
%patch137 -p1
%patch138 -p1
%patch139 -p1
%patch140 -p1
%patch141 -p1
%patch142 -p1
%patch143 -p1
%patch144 -p1
%patch145 -p1
%patch146 -p1
%patch147 -p1
%patch148 -p1
%patch149 -p1
%patch150 -p1
%patch151 -p1
%patch152 -p1
%patch153 -p1
%patch154 -p1
%patch155 -p1
%patch156 -p1
%patch157 -p1
%patch158 -p1
%patch159 -p1
%patch160 -p1
%patch161 -p1
%patch162 -p1
%patch163 -p1
%patch164 -p1
%patch165 -p1
%patch166 -p1
%patch167 -p1
%patch168 -p1
%patch169 -p1
%patch170 -p1
%patch171 -p1
%patch172 -p1
%patch173 -p1
%patch174 -p1
%patch175 -p1
%patch176 -p1
%patch177 -p1
%patch178 -p1
%patch179 -p1
%patch180 -p1
%patch181 -p1
%patch182 -p1
%patch183 -p1
%patch184 -p1
%patch185 -p1
%patch186 -p1
%patch187 -p1
%patch188 -p1
%patch189 -p1
%patch190 -p1
%patch191 -p1
%patch192 -p1
%patch193 -p1
%patch194 -p1
%patch195 -p1
%patch196 -p1
%patch197 -p1
%patch198 -p1
%patch199 -p1
%patch200 -p1
%patch201 -p1
%patch202 -p1
%patch203 -p1
%patch204 -p1
%patch205 -p1
%patch206 -p1
%patch207 -p1
%patch208 -p1
%patch209 -p1
%patch210 -p1
%patch211 -p1
%patch212 -p1
%patch213 -p1
%patch214 -p1
%patch215 -p1
%patch216 -p1
%patch217 -p1
%patch218 -p1
%patch219 -p1
%patch220 -p1
%patch221 -p1
%patch222 -p1
%patch223 -p1
%patch224 -p1
%patch225 -p1
%patch226 -p1
%patch227 -p1
%patch228 -p1
%patch229 -p1
%patch230 -p1
%patch231 -p1
%patch232 -p1
%patch233 -p1
%patch234 -p1
%patch235 -p1
%patch236 -p1
%patch237 -p1
%patch238 -p1
%patch239 -p1
%patch240 -p1
%patch241 -p1
%patch242 -p1
%patch243 -p1
%patch244 -p1
%patch245 -p1
%patch246 -p1
%patch247 -p1
%patch248 -p1
%patch249 -p1
%patch250 -p1
%patch251 -p1
%patch252 -p1
%patch253 -p1
%patch254 -p1
%patch255 -p1
%patch256 -p1
%patch257 -p1
%patch258 -p1
%patch259 -p1
%patch260 -p1
%patch261 -p1
%patch262 -p1
%patch263 -p1
%patch264 -p1
%patch265 -p1
%patch266 -p1
%patch267 -p1
%patch268 -p1
%patch269 -p1
%patch270 -p1
%patch271 -p1
%patch272 -p1
%patch273 -p1
%patch274 -p1
%patch275 -p1
%patch276 -p1
%patch277 -p1
%patch278 -p1
%patch279 -p1
%patch280 -p1
%patch281 -p1
%patch282 -p1
%patch283 -p1
%patch284 -p1
%patch285 -p1
%patch286 -p1
%patch287 -p1
%patch288 -p1
%patch289 -p1
%patch290 -p1
%patch291 -p1
%patch292 -p1
%patch293 -p1
%patch294 -p1
%patch295 -p1
%patch296 -p1
%patch297 -p1
%patch298 -p1
%patch299 -p1
%patch300 -p1
%patch301 -p1
%patch302 -p1
%patch303 -p1
%patch304 -p1
%patch305 -p1
%patch306 -p1
%patch307 -p1
%patch308 -p1
%patch309 -p1
%patch310 -p1
%patch311 -p1
%patch312 -p1
%patch313 -p1
%patch314 -p1
%patch315 -p1
%patch316 -p1
%patch317 -p1
%patch318 -p1
%patch319 -p1
%patch320 -p1
%patch321 -p1
%patch322 -p1
%patch323 -p1
%patch324 -p1
%patch325 -p1
%patch326 -p1
%patch327 -p1
%patch328 -p1
%patch329 -p1
%patch330 -p1
%patch331 -p1
%patch332 -p1
%patch333 -p1
%patch334 -p1
%patch335 -p1
%patch336 -p1
%patch337 -p1
%patch338 -p1
%patch339 -p1
%patch340 -p1
%patch341 -p1
%patch342 -p1
%patch343 -p1
%patch344 -p1
%patch345 -p1
%patch346 -p1
%patch347 -p1
%patch348 -p1
%patch349 -p1
%patch350 -p1
%patch351 -p1
%patch352 -p1
%patch353 -p1
%patch354 -p1
%patch355 -p1
%patch356 -p1
%patch357 -p1
%patch358 -p1
%patch359 -p1
%patch360 -p1
%patch361 -p1
%patch362 -p1
%patch363 -p1
%patch364 -p1
%patch365 -p1
%patch366 -p1
%patch367 -p1
%patch368 -p1
%patch369 -p1
%patch370 -p1
%patch371 -p1
%patch372 -p1
%patch373 -p1
%patch374 -p1
%patch375 -p1
%patch376 -p1
%patch377 -p1
%patch378 -p1
%patch379 -p1
%patch380 -p1
%patch381 -p1
%patch382 -p1
%patch383 -p1
%patch384 -p1
%patch385 -p1
%patch386 -p1
%patch387 -p1
%patch388 -p1
%patch389 -p1
%patch390 -p1
%patch391 -p1
%patch392 -p1
%patch393 -p1
%patch394 -p1
%patch395 -p1
%patch396 -p1
%patch397 -p1
%patch398 -p1
%patch399 -p1
%patch400 -p1
%patch401 -p1
%patch402 -p1
%patch403 -p1
%patch404 -p1
%patch405 -p1
%patch406 -p1
%patch407 -p1
%patch408 -p1
%patch409 -p1
%patch410 -p1
%patch411 -p1
%patch412 -p1
%patch413 -p1
%patch414 -p1
%patch415 -p1
%patch416 -p1
%patch417 -p1
%patch418 -p1
%patch419 -p1
%patch420 -p1
%patch421 -p1
%patch422 -p1
%patch423 -p1
%patch424 -p1
%patch425 -p1
%patch426 -p1
%patch427 -p1
%patch428 -p1
%patch429 -p1
%patch430 -p1
%patch431 -p1
%patch432 -p1
%patch433 -p1
%patch434 -p1
%patch435 -p1
%patch436 -p1
%patch437 -p1
%patch438 -p1
%patch439 -p1
%patch440 -p1
%patch441 -p1
%patch442 -p1
%patch443 -p1
%patch444 -p1
%patch445 -p1
%patch446 -p1
%patch447 -p1
%patch448 -p1
%patch449 -p1
%patch450 -p1
%patch451 -p1
%patch452 -p1
%patch453 -p1
%patch454 -p1
%patch455 -p1
%patch456 -p1
%patch457 -p1
%patch458 -p1
%patch459 -p1
%patch460 -p1
%patch461 -p1
%patch462 -p1
%patch463 -p1
%patch464 -p1
%patch465 -p1
%patch466 -p1
%patch467 -p1
%patch468 -p1
%patch469 -p1
%patch470 -p1
%patch471 -p1
%patch472 -p1
%patch473 -p1
%patch474 -p1
%patch475 -p1
%patch476 -p1
%patch477 -p1
%patch478 -p1
%patch479 -p1
%patch480 -p1
%patch481 -p1
%patch482 -p1
%patch483 -p1
%patch484 -p1
%patch485 -p1
%patch486 -p1
%patch487 -p1
%patch488 -p1
%patch489 -p1
%patch490 -p1
%patch491 -p1
%patch492 -p1
%patch493 -p1
%patch494 -p1
%patch495 -p1
%patch496 -p1
%patch497 -p1
%patch498 -p1
%patch499 -p1
%patch500 -p1
%patch501 -p1
%patch502 -p1
%patch503 -p1
%patch504 -p1
%patch505 -p1
%patch506 -p1
%patch507 -p1
%patch508 -p1
%patch509 -p1
%patch510 -p1
%patch511 -p1
%patch512 -p1
%patch513 -p1
%patch514 -p1


# kernel code:
cd kvm-%{kvmversion}-kernel
%patch1501 -p1
%patch1502 -p1
%patch1503 -p1
%patch1504 -p1
%patch1505 -p1
%patch1506 -p1
%patch1507 -p1
%patch1508 -p1
%patch1509 -p1
%patch1511 -p1
%patch1512 -p1
%patch1513 -p1
%patch1514 -p1
%patch1515 -p1
%patch1516 -p1
%patch1517 -p1
%patch1518 -p1
%patch1519 -p1
%patch1520 -p1
%patch1521 -p1
%patch1522 -p1
%patch1523 -p1
%patch1524 -p1
%patch1525 -p1
%patch1526 -p1
%patch1527 -p1
%patch1528 -p1
%patch1529 -p1
%patch1530 -p1
%patch1531 -p1
%patch1532 -p1
%patch1533 -p1
%patch1534 -p1
%patch1535 -p1
%patch1536 -p1
%patch1537 -p1
%patch1538 -p1
%patch1539 -p1
%patch1540 -p1
%patch1541 -p1
%patch1542 -p1
%patch1543 -p1
%patch1544 -p1
%patch1545 -p1
%patch1546 -p1
%patch1547 -p1
%patch1548 -p1
%patch1549 -p1
%patch1550 -p1
%patch1551 -p1
%patch1552 -p1
%patch1553 -p1
%patch1554 -p1
%patch1555 -p1
%patch1556 -p1
%patch1557 -p1
%patch1558 -p1
%patch1559 -p1
%patch1560 -p1
%patch1561 -p1
%patch1562 -p1
%patch1563 -p1
%patch1564 -p1
%patch1565 -p1
%patch1566 -p1
%patch1567 -p1
%patch1568 -p1
%patch1569 -p1
%patch1570 -p1
%patch1571 -p1
%patch1572 -p1
%patch1573 -p1
%patch1574 -p1
%patch1575 -p1
%patch1576 -p1
%patch1577 -p1
%patch1578 -p1
%patch1579 -p1
%patch1580 -p1
%patch1581 -p1
%patch1582 -p1
%patch1583 -p1
%patch1584 -p1
%patch1585 -p1
%patch1586 -p1
%patch1587 -p1
%patch1588 -p1
%patch1589 -p1
%patch1590 -p1
%patch1591 -p1
%patch1592 -p1
%patch1593 -p1
%patch1594 -p1
%patch1595 -p1
%patch1596 -p1
%patch1597 -p1
%patch1598 -p1
%patch1599 -p1
%patch1600 -p1
%patch1601 -p1
%patch1602 -p1
%patch1603 -p1
%patch1604 -p1
%patch1605 -p1
%patch1606 -p1
%patch1607 -p1
%patch1608 -p1
%patch1609 -p1
%patch1610 -p1
%patch1611 -p1
%patch1612 -p1
%patch1613 -p1
%patch1614 -p1
%patch1615 -p1
%patch1616 -p1
%patch1617 -p1
%patch1618 -p1
%patch1619 -p1
%patch1620 -p1
%patch1621 -p1
%patch1622 -p1
%patch1623 -p1
%patch1624 -p1
%patch1625 -p1
%patch1626 -p1
%patch1627 -p1
%patch1628 -p1
cd ../


## you can uncomment the code below to test the
## 'make sync' code
#./configure
#cd kernel
#make sync LINUX=../kvm-%{kvmversion}-kernel version=%{name}-%{version}-%{release}
#cd ../


%build

# systems like rhel build system does not have a recent enough linker so 
# --build-id works. this option is used fedora 8 onwards for giving info
# to the debug packages.

build_id_available() {
    echo "int main () { return 0; }" | gcc -x c -Wl,--build-id - 2>/dev/null
}

if build_id_available; then
    qemuldflags="-Wl,--build-id";
else
    qemuldflags="";
fi

# we need to install the data bits in a different path
sed -i 's/datasuffix=\"\/share\/qemu\"/datasuffix=\"\/share\/kvm\"/' qemu/configure
%if %{with_modules}
# if we had kmod macros working, we would have this:
#kdir=%{kernel_source $flavor}
# instead, we have:
kdir="%{_usrsrc}/kernels/%{kverrel}-%{_target_cpu}"
%define cfg_args --kerneldir="$kdir" --with-kvm-trace
%else
# --kerneldir is a trick to make it use the headers bundled in the kvm
# tarball, on 'make header-sync'
%define cfg_args --with-patched-kernel --kerneldir=$(pwd)/kernel
%endif

%if %{with_spice}
spice_args="--enable-spice"
%else
spice_args=""
%endif

./configure %{cfg_args} --prefix=%{_prefix} --qemu-ldflags=$qemuldflags \
--audio-drv-list=oss,alsa --disable-blobs $spice_args \
--disable-smb --disable-scsi --disable-isapc --disable-kvm-nested --disable-usb-msd --disable-usb-wacom --disable-usb-serial --disable-usb-net --disable-usb-bluez --disable-vmware --disable-x86-non-generic-cpus \
--disable-bluez --audio-card-list=ac97 --disable-curses --disable-nbd \
--enable-kvm --enable-qxl --enable-spice --enable-gcrypt --enable-vnc-tls \
--disable-pcspk


%if %{with_spice}
# sanity check, while there are no real checks on configure
# (bz#489900)
if ! grep -q CONFIG_SPICE=yes qemu/config-host.mak;then
	echo "Spice support not enabled by configure. Aborting" >&2
	exit 1
fi
%endif


# We must synchronize the kvm-userspace kernel code
# with the code from the -kernel tarball that we
# patched.
# Unfortunately, 'make sync' needs configure
# to be run, so we can't do that on the %%prep script
cd kernel
make sync LINUX=../kvm-%{kvmversion}-kernel version=%{name}-%{version}-%{release}
cd ../


%if %{with_modules}
for flavor in %flavors_to_build ; do
   rm -rf kernel-$flavor
   cp -r kernel kernel-$flavor
   # if we had kmod macros working, we would have this:
   #kdir=%{kernel_source $flavor}
   # instead, we have:
   kdir="%{_usrsrc}/kernels/%{kverrel}${flavor:+-$flavor}-%{_target_cpu}"
   make -C kernel-$flavor KERNELDIR="$kdir"
done
%endif

# we can't use RPM_OPT_FLAGS for the same reasons as qemu (#208026) for the
# qemu bits.  so let's set it for the other pieces.  this requires some
# manual keeping up of what is in the kvm tree.
sed -i 's/CFLAGS =/CFLAGS +=/' user/Makefile
echo "CFLAGS=$RPM_OPT_FLAGS" >> user/config.mak

# build the bios, and fix it's makefile
sed -i 's/gcc -m32/gcc/' bios/Makefile
make bios
make vgabios

# need to avoid running make on 'kernel' dir, as we already built the
# modules, above.
# run it only on the remaining dirs:
make libkvm %{?__smp_mflags}
make qemu %{?__smp_mflags}
make user %{?__smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT

# need to avoid running 'make install' on kernel, so
# run it only on the remaining dirs:
make -C libkvm DESTDIR=$RPM_BUILD_ROOT install
make -C qemu DESTDIR=$RPM_BUILD_ROOT install

# 'user' dir doesn't have 'make install' rule
install -m 0755 user/kvmtrace %{buildroot}/%{_bindir}/
install -m 0755 user/kvmtrace_format %{buildroot}/%{_bindir}/
install -m 0755 user/ksmctl %{buildroot}/%{_bindir}/
install -m 0755 kvm_stat %{buildroot}/%{_bindir}/
#if we get /usr/share/kvm/formats to be used by kvmtrace_format
#by default, we can do this:
install -m 0755 user/formats %{buildroot}/%{_datadir}/%{name}/formats

mkdir -p %{buildroot}/%{_sysconfdir}/udev/rules.d
cp scripts/65-kvm.rules %{buildroot}/%{_sysconfdir}/udev/rules.d/

#mkdir -p %{buildroot}/%{_sysconfdir}/init.d
#cp scripts/kvm %{buildroot}/%{_sysconfdir}/init.d/

%if %{with_modules}
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=%{mod_dir}
for flavor in %flavors_to_build ; do 

    # we could do this if kvm didn't try to run 'depmod -a', and
    # if we had the kmod macros available on brew:
    #make -C kernel KERNELDIR=%{kernel_source $flavor} install
    # but we copy the modules manually instead:
    moddir="%{buildroot}/lib/modules/%{kverrel}${flavor:+-$flavor}/$INSTALL_MOD_DIR"
    mkdir -p "$moddir"
    cp kernel-$flavor/%{mod_arch_dir}/*.ko "$moddir/"
    cp kernel-$flavor/ksm/*.ko "$moddir/"
done
%endif

# we have to have our own copies of the bios/keymaps due to incompat with
# qemu 0.9.  include the man page
mv $RPM_BUILD_ROOT/%{_mandir}/man1/qemu.1* $RPM_BUILD_ROOT/%{_mandir}/man1/qemu-kvm.1
rm -rf $RPM_BUILD_ROOT/%{_docdir}
%if !0%{?with_qemu_img}
rm -rf $RPM_BUILD_ROOT/%{_mandir}/man*/qemu-img* $RPM_BUILD_ROOT/%{_docdir}
rm -f $RPM_BUILD_ROOT/%{_bindir}/qemu-img
%endif
# no shared lib, static libs
rm -fr $RPM_BUILD_ROOT/%{_includedir} $RPM_BUILD_ROOT/%{_libdir}

# make install gives it bogus execute permissiions
chmod -x $RPM_BUILD_ROOT/%{_mandir}/man1/qemu-kvm.1*
chmod -x $RPM_BUILD_ROOT/%{_mandir}/man*/qemu-*

install -d $RPM_BUILD_ROOT/%{_datadir}/%{name}
for i in bios.bin extboot.bin vgabios.bin vgabios-cirrus.bin
do
  install -m 0644 qemu/pc-bios/$i $RPM_BUILD_ROOT/%{_datadir}/%{name}/$i
done

mkdir -p $RPM_BUILD_ROOT/%{_bindir} $RPM_BUILD_ROOT/%{_libexecdir}
mv $RPM_BUILD_ROOT/%{_bindir}/qemu-system-x86_64 $RPM_BUILD_ROOT/%{_libexecdir}/qemu-kvm
#ln -s %{_libexecdir}/qemu-kvm $RPM_BUILD_ROOT/%{_bindir}/qemu-kvm

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules
install -m 0755 %{SOURCE10} $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules/kvm.modules


# the pxe etherboot images will be symlinks to the images on
# /usr/share/etherboot, as KVM doesn't know how to look
# for other paths, yet.
pxe_link() {
  ln -s ../qemu-pxe-roms/$2.zrom %{buildroot}/%{_datadir}/%{name}/pxe-$1.bin
}

pxe_link e1000 e1000-82542
pxe_link ne2k_pci rtl8029
pxe_link pcnet pcnet32
pxe_link rtl8139 rtl8139
pxe_link virtio virtio-net


%clean
rm -rf $RPM_BUILD_ROOT


%post
# gid 36 allocated to kvm at bz#481021
/usr/sbin/groupadd -fg 36 kvm


%files
%defattr(-,root,root,-)
%{_libexecdir}/qemu-kvm
%{_bindir}/ksmctl

%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/keymaps
%{_datadir}/%{name}/keymaps/*

%{_datadir}/%{name}/bios.bin
%{_datadir}/%{name}/extboot.bin
%{_datadir}/%{name}/pxe-e1000.bin
%{_datadir}/%{name}/pxe-ne2k_pci.bin
%{_datadir}/%{name}/pxe-pcnet.bin
%{_datadir}/%{name}/pxe-rtl8139.bin
%{_datadir}/%{name}/pxe-virtio.bin
%{_datadir}/%{name}/vgabios-cirrus.bin
%{_datadir}/%{name}/vgabios.bin

%{_mandir}/man1/qemu-kvm.1*

%{_sysconfdir}/sysconfig/modules/%{name}.modules
%config(noreplace) %{_sysconfdir}/udev/rules.d/65-kvm.rules


%files tools
%defattr(-,root,root,-)
%{_datadir}/%{name}/formats
%{_bindir}/kvmtrace
%{_bindir}/kvmtrace_format
%{_bindir}/kvm_stat
%{_bindir}/qemu-io

%if %{with_qemu_img}
%files qemu-img
%defattr(-,root,root,-)
%{_bindir}/qemu-img
%{_mandir}/man1/qemu-img*
%endif


%changelog
* Fri Jul 30 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.21
- kvm-Fix-segfault-in-mmio-subpage-handling-code.patch [bz#619412]
- Resolves: bz#619412
  (CVE-2010-2784 qemu: insufficient constraints checking in exec.c:subpage_register() [rhel-5.5.z])

* Thu Jul 29 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.20
- kvm-virtio-net-correct-packet-length-checks.patch [bz#610343]
- Resolves: bz#610343
  (Virtio: Transfer file caused guest in same vlan abnormally quit)

* Tue Jul 27 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.19
- kvm-qcow2-Fix-qemu-img-check-segfault-on-corrupted-image.patch [bz#610342]
- kvm-qcow2-Don-t-try-to-check-tables-that-couldn-t-be-loa.patch [bz#610342]
- kvm-qemu-img-check-Distinguish-different-kinds-of-errors.patch [bz#618206]
- kvm-qcow2-Change-check-to-distinguish-error-cases.patch [bz#618206]
- Resolves: bz#610342
  ([kvm] segmentation fault when running qemu-img check on faulty image)
- Resolves: bz#618206
  ([kvm] qemu image check returns cluster errors when using virtIO block (thinly provisioned) during e_no_space events (along with EIO errors))

* Tue Jul 27 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.18
- kvm-New-slots-need-dirty-tracking-enabled-when-migrating.patch [bz#618205]
- Resolves: bz#618205
  (SPICE - race in KVM/Spice would cause migration to fail (slots are not registered properly?))

* Thu Jul 22 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.17
- kvm-kernel-KVM-MMU-fix-conflict-access-permissions-in-direct-sp.patch [bz#616796]
- Resolves: bz#616796
  (KVM uses wrong permissions for large guest pages)

* Wed Jul 21 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.16
- kvm-kernel-fix-null-pointer-dereference.patch [bz#570531]
  - Resolves: bz#570531
  - CVE: CVE-2010-0435 
- kvm-qemu-fix-unsafe-ring-handling.patch [bz#568816]
  - Resolves: bz#568816
  - CVE: CVE-2010-0431

* Thu Jul 08 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.15
- Renumber patches on spec file to avoid patch number conflicts between
  userspace & kernel patches
- kvm-qcow2-Fix-access-after-end-of-array.patch [bz#612508]
- kvm-qcow2-Don-t-ignore-immediate-read-write-failures.patch [bz#612508]
- kvm-qcow2-Return-0-errno-in-write_l2_entries.patch [bz#612508]
- kvm-qcow2-Fix-error-return-code-in-qcow2_alloc_cluster_l.patch [bz#612508]
- kvm-qcow2-Return-0-errno-in-write_l1_entry.patch [bz#612508]
- kvm-qcow2-Return-0-errno-in-l2_allocate.patch [bz#612508]
- kvm-qcow2-Allow-qcow2_get_cluster_offset-to-return-error.patch [bz#612508]
- kvm-qcow2-Change-l2_load-to-return-0-errno.patch [bz#612508]
- kvm-qcow2-Return-right-error-code-in-write_refcount_bloc.patch [bz#612508]
- kvm-qcow2-Fix-corruption-after-error-in-update_refcount.patch [bz#612508]
- kvm-qcow2-Clear-L2-table-cache-after-write-error.patch [bz#612508]
- kvm-qcow2-Fix-error-handling-in-l2_allocate.patch [bz#612508]
- kvm-qcow2-Restore-L1-entry-on-l2_allocate-failure.patch [bz#612508]
- kvm-qcow2-Allow-get_refcount-to-return-errors.patch [bz#612508]
- kvm-qcow2-Allow-alloc_clusters_noref-to-return-errors.patch [bz#612508]
- kvm-qcow2-Return-real-error-code-in-load_refcount_block.patch [bz#612508]
- kvm-block-Add-bdrv_-p-write_sync.patch [bz#612507]
- kvm-qcow2-Use-bdrv_-p-write_sync-for-metadata-writes.patch [bz#612507]
- Resolves: bz#612507
  (qcow2 image corruption when using cache=writeback)
- Resolves: bz#612508
  (Backport qcow2 fixes to RHEL 5)

* Mon Jul 05 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.14
- Updated kversion to 2.6.18-194.8.1.el5 to match build root
- kvm-kernel-KVM-Keep-slot-ID-in-memory-slot-structure.patch [bz#610341]
- kvm-kernel-KVM-Prevent-internal-slots-from-being-COWed.patch [bz#610341]
- kvm-virtio-net-truncating-packet.patch [bz#610343]
- kvm-raw-posix-Use-pread-pwrite-instead-of-lseek-read-wri.patch [bz#610344]
- kvm-block-Cache-total_sectors-to-reduce-bdrv_getlength-c.patch [bz#610344]
- Resolves: bz#610341
  (fork causes trouble for vcpu threads)
- Resolves: bz#610343
  (Virtio: Transfer file caused guest in same vlan abnormally quit)
- Resolves: bz#610344
  (Excessive lseek() causes severe performance issues with vm disk images over NFS)

* Tue Jun 22 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.13
- kvm-virtio-blk.c-avoid-zero-every-request-structure.patch [bz#604159]
- Resolves: bz#604159
  (virtio-blk: Avoid zeroing every request structure)

* Wed Jun 16 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.12
- kvm-qcow2-Export-synchronous-qcow_read-write-to-avoid-br.patch [bz#604188]
- Resolves: bz#604188
  (Guest suffers kernel panic when save snapshot then restart guest)

* Wed Jun 09 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.11
- kvm-qcow2-Fix-corruption-after-refblock-allocation.patch [bz#602363]
- Resolves: bz#602363
  (qcow2 corruption bug in refcount table growth)

* Fri May 28 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.10
- Updated kversion to 2.6.18-194.3.1.el5 to match build root
- kvm-kernel-KVM-MMU-bail-out-pagewalk-on-kvm_read_guest-error.patch [bz#596381]
- kvm-kernel-KVM-Fix-wallclock-version-writing-race.patch [bz#596625]
- kvm-qemu-img-rebase-Fix-output-image-corruption.patch [bz#596378]
- Resolves: bz#596381
  (kvm spinning updating a guest pte, unkillable)
- Resolves: bz#596625
  (race condition in pvclock wallclock calculation)
- Resolves: bz#596378
  (After re-base snapshot, the file in the snapshot disappeared)

* Tue May 04 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.9
- Remove bios-nohotplug.bin from package
- Related: bz#579737
  (QEMU: Too many devices are available for unplug in Windows XP (and we don't support that))

* Thu Apr 29 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.8
- kvm-Revert-fix-wrong-acpi-mapping-rhel5.x-kvm-userspace.patch [bz#581758]
  - Patch causes issues (see bz#581758 comment 8)
- Related: bz#581758
  (Win7/32 stuck on 100% CPU (in testing VDI driver unclassified WHQL tests))

* Tue Apr 27 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.7
- kvm-qcow2-Remove-abort-on-free_clusters-failure.patch [bz#583947 bz#586246]
- Resolves: bz#583947
  (Guest aborted when make guest stop on write error)
- Resolves: bz#586246
  (Guest aborted when make guest stop on write error)

* Tue Apr 13 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.6
- kvm-avoid-leaving-orphaned-swapcache-in-ksm.patch [bz#581764]
- Resolves: bz#581764
  (memory reported as used (by SwapCache and by Cache) though no process holds it.)

* Tue Apr 13 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.5
- kvm-qcow2-Factor-next_refcount_table_size-out.patch [bz#581766]
- kvm-qcow2-Rewrite-alloc_refcount_block-grow_refcount_tab.patch [bz#581766]
- kvm-qcow2-More-checks-for-qemu-img-check.patch [bz#581766]
- Resolves: bz#581766
  (qcow2 corruption with I/O error during refcount block allocation)

* Tue Apr 13 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.4
- kvm-fix-wrong-acpi-mapping-rhel5.x-kvm-userspace.patch [bz#581758]
- Resolves: bz#581758
  (Win7/32 stuck on 100% CPU (in testing VDI driver unclassified WHQL tests))

* Wed Apr 07 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.3
- kvm-kernel-account-only-for-IRQ-injected-into-vcpu0.patch [bz#577266]
- kvm-kernel-Backport-KVM-fix-irq_source_id-size-verification.patch [bz#579863]
- Resolves: bz#577266
  (Time drift in win2k3-64bit and win2k8-64bit smp guest)
- Resolves: bz#579863
  (SR-IOV -- Guest exit and host hang on if boot VM with 8 VFs assigned)

* Tue Apr 06 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.2
- kvm-kernel-KVM-x86-disable-paravirt-mmu-reporting.patch [bz#578579]
- Resolves: bz#578579
  (Linux pvmmu guests (FC11, FC12, etc) crash on boot on AMD hosts with NPT disabled)

* Tue Apr 06 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5_5.1
- Updated kversion to 2.6.18-194.el5 to match build root
- kvm-Build-an-additional-bios-without-hotplug-support.patch [bz#579737]
- Resolves: bz#579737
  (QEMU: Too many devices are available for unplug in Windows XP (and we don't support that))

* Wed Mar 10 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-164.el5
- kvm-Fix-Windows-guests-SVVP-tests.patch [bz#495844]
- Resolves: bz#495844
  (KVM SVVP: "Signed Driver check" failure - on the disabled vCPUs (that the VM's BIOS doesn't hide))

* Tue Mar 09 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-163.el5
- kvm-kernel-avoid-collision-between-out-of-sync-ksm-and-pci-pass.patch [bz#566385]
- Resolves: bz#566385
  (KVM host panic due to fault in paging64_sync_page() / panic occurs in connection with PCI passthru devices)

* Tue Mar 09 2010 Glauber Costa <glommer@redhat.com> - kvm-83-162.el5
- kvm-qemu-img-rebase-Add-f-option.patch [bz#569762]
- kvm-mark-PCI-IRQs-as-edge-triggered-in-mptables.patch [bz#536749]
- Resolves: bz#536749
  (can not boot rhel3.9 with if=virtio)
- Resolves: bz#569762
  ('qemu-img re-base' broken on block devices)
- Moved kver to 2.6.18-191.el5 to match build root

* Tue Mar 02 2010 Glauber Costa <glommer@redhat.com> - kvm-83-161.el5
- kvm-qemu-img-Fix-segfault-during-rebase.patch [bz#563141]
- Resolves: bz#563141
  (qemu-img re-base subcommand got Segmentation fault)
- Moved kver to 2.6.18-190.el5 to match build root

* Tue Feb 23 2010 Glauber Costa <glommer@redhat.com> - kvm-83-160.el5
- kvm-qxl-defer-vga-updates-in-case-commands-ring-is-full-.patch [bz#544785]
- Resolves: bz#544785
  (QEMU process can become non-responsive in case command are not pull from qxl vga ring)

* Thu Feb 17 2010 Glauber Costa <glommer@redhat.com> - kvm-83-159.el5
- Applied patch to spec file [bz#533453]
- Updated kversion to 2.6.18-189.el5 to match build root
- Resolves: bz#533453
  (kvm kmod package should require a compatible kernel version)

* Thu Feb 11 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-158.el5
- Updated kversion to 2.6.18-187.el5 to match build root
- kvm-kernel-KVM-Don-t-check-access-permission-when-loading-segme.patch [bz#563465]
- kvm-kernel-KVM-Disable-move-to-segment-registers-and-jump-far-i.patch [bz#563465]
- kvm-kernel-KVM-VMX-Check-cpl-before-emulating-debug-register-ac.patch [bz#563517]
- Resolves: bz#563465
  (EMBARGOED CVE-2010-0419 kvm: emulator privilege escalation segment selector check [rhel-5.5])
- Resolves: bz#563517
  (KVM: Check cpl before emulating debug register access [rhel-5.5])

* Thu Feb 04 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-157.el5
- kvm-CVE-2010-0297-usb-linux.c-fix-buffer-overflow.patch [bz#560770]
- Resolves: bz#560770
  (CVE-2010-0297 kvm-userspace-rhel5: usb-linux.c: fix buffer overflow [rhel-5.5])

* Wed Feb 03 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-156.el5
- kvm-kernel-KVM-PIT-control-word-is-write-only.patch [bz#553126]
- kvm-kernel-KVM-introduce-kvm_read_guest_virt-kvm_write_guest_vi.patch [bz#559095]
- kvm-kernel-KVM-remove-the-vmap-usage.patch [bz#559095]
- kvm-kernel-KVM-Use-kvm_-read-write-_guest_virt-to-read-and-writ.patch [bz#559095]
- kvm-kernel-KVM-fix-memory-access-during-x86-emulation.patch [bz#559095]
- kvm-kernel-Check-IOPL-level-during-io-instruction-emulation.patch [bz#560698]
- kvm-kernel-Fix-popf-emulation.patch [bz#560698]
- kvm-kernel-Check-CPL-level-during-privilege-instruction-emulati.patch [bz#560698]
- Resolves: bz#553126
  (CVE-2010-0309 kvm: cat /dev/port in guest cause the host hang [rhel-5.5])
- Resolves: bz#559095
  (EMBARGOED CVE-2010-0298 kvm: emulator privilege escalation [rhel-5.5])
- Resolves: bz#560698
  (EMBARGOED CVE-2010-0306 kvm: emulator privilege escalation IOPL/CPL level check [rhel-5.5])


* Fri Jan 29 2010 Glauber Costa <glommer@redhat.com> - kvm-83-155.el5
- kvm-virtio-blk-Fix-reads-turned-into-writes-after-read-e.patch [bz#552487]
- kvm-virtio-blk-Handle-bdrv_aio_read-write-NULL-return.patch [bz#552487]
- Resolves: bz#552487
  (Guest image corruption after RHEV-H update to 5.4-2.1.3.el5_4rhev2_1)
- Moved kver to 2.6.18-186.el5 to match build root

* Wed Jan 27 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-154.el5
- kvm-qemu-img-Fix-qemu-img-with-backing-file.patch [bz#558195]
- kvm-qemu-add-routines-for-atomic-16-bit-accesses.patch [bz#525323]
- kvm-qemu-virtio-atomic-access-for-index-values.patch [bz#525323]
- kvm-fix-ide-versioning.patch [bz#559163]
- kvm-cpu-CPU_SAVE_VERSION-is-9-know.patch [bz#559163]
- Resolves: bz#525323
  (QEMU terminates without warning with virtio-net and SMP enabled)
- Resolves: bz#558195
  (kvm: NFS : kvm-qemu-img convert failure on RAW/Sparse template with COW/Sparse snapshot)
- Resolves: bz#559163
  (migration failed host 5.5 with -M rhel5.5.0 to host 5.5 with -M rhel5.5.0.)

* Wed Jan 27 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-153.el5
- kvm-qcow2-Fix-error-handling-in-qcow2_grow_l1_table.patch [bz#537077]
- kvm-qcow2-Fix-error-handling-in-qcow_save_vmstate.patch [bz#537077]
- kvm-qcow2-Return-0-errno-in-get_cluster_table.patch [bz#537077]
- kvm-qcow2-Return-0-errno-in-qcow2_alloc_cluster_offset.patch [bz#537077]
- kvm-block-Return-original-error-codes-in-bdrv_pread-writ.patch [bz#537077]
- kvm-qcow2-Fix-error-handling-in-grow_refcount_table.patch [bz#537077]
- kvm-qcow2-Improve-error-handling-in-update_refcount.patch [bz#537077]
- kvm-qcow2-Allow-updating-no-refcounts.patch [bz#537077]
- kvm-qcow2-Don-t-ignore-update_refcount-return-value.patch [bz#537077]
- kvm-qcow2-Don-t-ignore-qcow2_alloc_clusters-return-value.patch [bz#537077]
- Resolves: bz#537077
  (error codes aren't always propagated up through the block layer (e.g. -ENOSPC))

* Tue Jan 26 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-152.el5
- kvm-Revert-Queue-notify-support-for-virtio-block-device.patch [bz#552250]
  (Reverts kvm-Queue-notify-support-for-virtio-block-device.patch)
- Related: bz#552250
  (Windows virtio block driver performs poorly on small size requests)

* Tue Jan 26 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-151.el5
- kvm-Fix-cpu-versioning.patch [bz#557327]
- kvm-reduce-number-of-reinjects-on-ACK.patch [bz#556455]
- Resolves: bz#556455
  (KVM: WIN7-32bit blue screen (IMAGE_NAME:  ntkrnlmp.exe).)
- Resolves: bz#557327
  (migration failed with -M rhel5.4.4 between host 5.5 and host 5.4.4)

* Mon Jan 25 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-150.el5
- kvm-vnc-more-keypad-fixing.patch [bz#497507]
- kvm-qxl-add-netbooks-common-resolutions.-Rhel-5.5-552240.patch [bz#552240]
- kvm-block-raw-posix-Abort-on-pread-beyond-end-of-file.patch [bz#515655]
- Resolves: bz#497507
  (Numeric keypad cannot be used in qemu monitor when using vnc to connect guest.)
- Resolves: bz#515655
  (Add result test to prevent Infinite loop in raw_pread, reading too large offset)
- Resolves: bz#552240
  (Spice (QXL) - please add 1024x576 resolution to the driver (netbooks))

* Fri Jan 22 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-149.el5
- kvm-qemu-qxl-fix-unsafe-rom-data-handling-bug-537888.patch [bz#537888]
- kvm-qxl-fix-qxl-backwards-migration-to-version-3.patch [bz#537888]
- kvm-Allow-export-of-sse4.1-sse4.2-cpuid-flags-to-guest.-.patch [bz#518090]
- Resolves: bz#518090
  ([RFE] KVM should be able to export advanced cpu flags to the guest)
- Resolves: bz#537888
  (fix unsafe device data handling)

* Wed Jan 20 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-148.el5
- Updated kversion to 2.6.18-185.el5 to match build root
- Require qspice-libs to make sure the right libspice.so.0 file is installed
- Related: bz#555657

* Thu Jan 14 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-147.el5
- kvm-block-Introduce-BDRV_O_NO_BACKING.patch [bz#530134]
- kvm-qemu-img-rebase.patch [bz#530134]
- kvm-vnc-improve-capslock-handling.patch [bz#517814]
- kvm-block-Add-bdrv_change_backing_file.patch [bz#530134]
- kvm-qemu-img-Automatically-detect-block-devices.patch [bz#537655]
- Resolves: bz#517814
  (Caps Lock the key's appearance  of guest is not synchronous as host's --view kvm with vnc)
- Resolves: bz#530134
  (RFE - In-place backing file format change)
- Resolves: bz#537655
  (qemu-img: error creating a new preallocated volume image on FCP storage)

* Thu Jan 14 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-146.el5
- Require compatible etherboot-zroms-kvm package
- Resolves: bz#550053
  (require newer etherboot package that is compatible with new pxe ROM paths)

* Wed Jan 13 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-145.el5
- kvm-fix-barriers-support-during-migration.patch [bz#549938]
- kvm-Add-machine-name-alias-support.patch [bz#553187]
- kvm-make-pc-an-alias-of-rhel5.4.0.patch [bz#553187]
- kvm-Introduce-rhel5.4.4-machine-type.patch [bz#553187]
- Resolves: bz#549938
  (Maintain barrier state after migration)
- Resolves: bz#553187
  (Add rhel-5.4.4 support to rhel5.5.0)

* Thu Jan 07 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-144.el5
- kvm-kernel-KVM-x86-Add-KVM_GET-SET_VCPU_EVENTS.patch [bz#541084]
- Resolves: bz#541084
  (KVM: x86: Add KVM_GET/SET_VCPU_EVENTS)
- kvm-x86-Add-support-for-VCPU-event-states.patch [bz#541084]
- kvm-BZ550265-compute-checksum-for-roms-bigger-than-a-seg.patch [bz#550265]
- kvm-Fix-a-race-in-the-device-that-cuased-guest-stack-on-.patch [bz#503759]
- kvm-Queue-notify-support-for-virtio-block-device.patch [bz#552250]
- kvm-The-driver-device-pair-does-not-have-a-reset-option-.patch [bz#550755]
- kvm-The-driver-device-pair-does-not-have-a-reset-option-2.patch [bz#550755]
- Resolves: bz#503759
  (hypercall device - Vm becomes non responsive on Sysmark benchmark (when more than 7 vm's running simultaneously))
- Resolves: bz#541084
  (KVM: x86: Add KVM_GET/SET_VCPU_EVENTS)
- Resolves: bz#550265
  (gPXE fails to PXE boot on e1000 virtual NIC)
- Resolves: bz#550755
  (Hypercall driver doesn't reset device on power-down)
- Resolves: bz#552250
  (Windows virtio block driver performs poorly on small size requests. In addition, cpu usage on the quest side is very high while handling write requests.)

* Mon Jan 04 2010 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-143.el5
- kvm-Documentation-Fix-description-of-cache-option-for-dr.patch [bz#545194]
- kvm-monitor-allow-device-to-be-ejected-if-no-disk-is-ins.patch [bz#539250]
- Resolves: bz#539250
  (Cannot eject cd-rom when configured to host cd-rom)
- Resolves: bz#545194
  (Discrepancy between man page and source code for qcow2 with regards to default value used when no explicit caching is specified)

* Wed Dec 23 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-142.el5
- Updated kversion to 2.6.18-183.el5 to match build root
- kvm-removing-debugging-printf-leftover.patch [bz#530533]
- kvm-enable_write_cache-is-one-bool-no-need-for-32bits.patch [bz#549938]
- kvm-virtio_blk-save-if-cache-was-enabled.patch [bz#549938]
- kvm-ide-propagate-version_id-to-all-save-load-functions.patch [bz#549938]
- kvm-ide-save-if-cache-was-enabled.patch [bz#549938]
- kvm-savevm-add-version_id-to-all-savevm-functions.patch [bz#541731]
- kvm-We-need-current-machine-defined-sooner.patch [bz#541731]
- kvm-Add-support-for-DeviceVersion-to-machine-type.patch [bz#541731]
- kvm-Introduce-rhel5.4.0-machine-type.patch [bz#541731]
- kvm-Introduce-rhel-5.5.0-machine-type.patch [bz#541731]
- kvm-cpu-for-x86-don-t-save-new-fields-if-version-8.patch [bz#541731]
- kvm-RHEL5.4-needs-cpu-at-version-7.patch [bz#541731]
- kvm-RHEL-5.4.0-don-t-have-kvmclock.patch [bz#541731]
- kvm-RHEL5.4-needs-ide-at-device-version-3.patch [bz#541731]
- kvm-RHEL5.4-needs-virtio-blk-at-device-version-2.patch [bz#541731]
- kvm-make-5.4.0-machine-the-default.patch [bz#541731]
- Resolves: bz#530533
  (debug message is displayed when save VM state into a compressed file)
- Resolves: bz#541731
  (kvm: migration: mechanism to make older savevm versions to be emitted on some cases)
- Resolves: bz#549938
  (Maintain barrier state after migration)

* Tue Dec 22 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-140.el5
- kvm-kernel-KVM-MMU-remove-prefault-from-invlpg-handler.patch [bz#531887]
- Resolves: bz#531887
  (BSOD BAD_POOL_HEADER STOP 0x19 during boot of Windows Server 2008 R2 installer)
- kvm-Make-SMBIOS-pass-MS-SVVP-test.patch [bz#537178]
- kvm-bz-545136-whitelist-host-virtio-networking-features.patch [bz#545136]
- kvm-fix-rtc-td-hack-on-host-without-high-res-timers.patch [bz#543137]
- kvm-v2-RHEL5-BZ543979-get-roms-more-room.-Glauber-Costa.patch [bz#543979]
- Resolves: bz#537178
  (Need to generate SMBIOS table 4 data for windows guests)
- Resolves: bz#543137
  (time drift in win2k364 KVM guest)
- Resolves: bz#543979
  (gPXE fails to PXE boot on e1000 virtual NIC)
- Resolves: bz#545136
  (whitelist host virtio networking features)

* Thu Dec 17 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-139.el5
- Updated kversion to 2.6.18-182.el5 to match build root
- Require etherboot directly, to make sure it is installed by default
- Resolves: bz#546019

* Tue Dec 15 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-138.el5
- Updated kversion to 2.6.18-181.el5 to match build root
- Use the new gpxe/etherboot configurable pxe-zroms-qemu system
- Resolves: bz#546019

* Thu Dec 03 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-137.el5
- Updated kversion to 2.6.18-176.el5 to match build root
- kvm-kernel-KVM-x86-make-double-triple-fault-promotion-generic-t.patch [bz#532086]
- kvm-kernel-KVM-x86-raise-TSS-exception-for-NULL-CS-and-SS-segme.patch [bz#532086]
- kvm-kernel-KVM-x86-emulator-limit-instructions-to-15-bytes.patch [bz#541165]
- Resolves: bz#532086
  (Rhev-Block driver causes  'unhandled vm exit' with 32bit win2k3r2sp2 Guest VM  on restart)
- Resolves: bz#541165
  (CVE-2009-4031 kernel: KVM: x86 emulator: limit instructions to 15 bytes [rhel-5.5])

- kvm-qcow2-Store-exact-backing-format-length.patch [bz#540893]
- kvm-qcow-qcow2-Add-bdrv_aio_flush.patch [bz#542923]
- Resolves: bz#540893
  (qemu-img: snapshot info error)
- Resolves: bz#542923
  (Get segmentation fault when running with ide block on kvm-83-136.el5)

* Tue Nov 24 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-136.el5
- Update kversion to 2.6.18-175.el5 to match build root
- kvm-block-use-fdatasync-instead-of-fsync-if-possible.patch [bz#537646]
- kvm-block-add-aio_flush-operation.patch [bz#537646]
- kvm-ide-use-bdrv_aio_flush.patch [bz#537646]
- kvm-virtio-blk-add-volatile-writecache-feature.patch [bz#537646]
- kvm-qcow2-Fix-grow_refcount_table-error-handling.patch [bz#537075]
- kvm-virtio-blk-Stop-VM-on-read-errors.patch [bz#531827]
- kvm-ide-Stop-VM-on-read-errors.patch [bz#531827 bz#531827 bz#533390]
- kvm-slirp-Reassign-same-address-to-same-DHCP-client.patch [bz#531631]
- kvm-block-add-enable_write_cache-flag.patch [bz#537646]
- kvm-build-fix-add-pci_get_bus_and_slot-to-compat_apis.patch [bz#539589]
- kvm-Fix-race-between-migration-and-cpu-main-loop.patch [bz#533090]
- Resolves: bz#531631
  (Windows XP unattended install doesn't get an IP address after rebooting, if using -net user)
- Resolves: bz#531827
  (O/S Filesystem Corruption with RHEL-5.4 on a RHEV Guest)
- Resolves: bz#533090
  (Windows Server 2008 R2 shutdown hangs after restore from migration)
- Resolves: bz#533390
  (RHEL5.4 VM image corruption with an IDE v-disk)
- Resolves: bz#537075
  (qcow2: infinite recursion on grow_refcount_table() error handling)
- Resolves: bz#537646
  (backports of qemu barrier support)
- Resolves: bz#539589
  (kvm can't build against kernel-2.6.18-174.el5)

* Tue Nov 10 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-135.el5
- kvm-kernel-531701-KERNEL-v2-allow-userspace-to-adjust-kvmclock-.patch [bz#531701]
- kvm-531701-properly-save-kvm-system-time-msr-registers.patch [bz#531701]
- kvm-BZ531701-get-and-set-clock-upon-migration.patch [bz#531701]
- Resolves: bz#531701
  (pvclock msr values are not preserved across remote migration)

- Filter out ksym dependencies only known non-whitelisted symbols [bz#533197]
- Resolves: bz#533197

* Thu Nov 05 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-134.el5
- kvm-kernel-allow-to-address-up-to-48-bits-of-physical-memory-in.patch [bz#516545 bz#517223]
- Resolves: bz#516545
  (qemu-kvm crashed when setting 32bitwin28k with 64G ram)
- Related: bz#517223
  (BUG: warning at /builddir/build/BUILD/kvm-83-maint-snapshot-20090205/kernel-/x86/x86.c:240/kvm_queue_exception_e() (Tainted: G     ))

- kvm-Add-smp_call_function_many-to-compat_apis.patch [bz#533059]
- Resolves: bz#533059
  (kvm modules can't be built against latest kernel-devel package)

* Wed Nov 04 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-133.el5
- Update kversion to 2.6.18-172.el5 to match build root
- kvm-kernel-KVM-Timer-event-should-not-unconditionally-unhalt-vc.patch [bz#492663]
- kvm-kernel-KVM-Fix-interrupt-unhalting-a-vcpu-when-it-shouldn-t.patch [bz#502086]
- Resolves: bz#492663
  (KVM: Timer event should not unconditionally unhalt vcpu)
- Resolves: bz#502086
  (KVM: Fix interrupt unhalting a vcpu when it shouldn't)

* Wed Oct 28 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-132.el5
- kvm-keep-initrd-in-below-4g-area.patch [bz#529694]
- Resolves: bz#529694
  (-initrd is broken with > 4GB guests)

* Tue Oct 27 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-131.el5
- kvm-kernel-KVM-SVM-Reset-cr0-properly-on-vcpu-reset.patch [bz#525699]
- Resolves: bz#525699
  (x86_64 guest hang when set guest's cpu1 online on AMD host)

* Mon Oct 26 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-130.el5
- Update kversion to 2.6.18-168.el5 to match kernel-devel on build root
- kvm-kernel-get_tss_base_addr-should-return-gpa_t-type.patch [bz#516762]
- Resolves: bz#516762
  (qemu aborted when restart 32bitwin23k with more than 4G mem in intel host.)

* Wed Oct 21 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-129.el5
- kvm-Fix-VDI-audio-stop.patch [bz#520394]
- Resolves: bz#520394
  (KVM : QEMU-Audio attempting to stop unactivated audio device (snd_playback_stop: ASSERT playback_channel->base.active failed).)

* Fri Oct 16 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-128.el5
- kvm-fix-kvm_arch_save_regs-potential-stack-corruptio.patch [bz#528917]
- Resolves: bz#528917
  (qemu-kvm : msrs[] array in kvm_arch_save_regs() too small / may cause stack corruption)

* Wed Oct 14 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-127.el5
- kvm-RHEL-5.X-5.4.Z-Makefile-fix-ksm-dir-has-no-ARCH-pref.patch [bz#527722]
- Resolves: bz#527722
  (Build tree for RHEL 5.X and RHEL 5.4.z contains build bugs)

* Tue Oct 13 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-126.el5
- Add --disable-pcspk option to ./configure [bz#516672]
- Resolves: bz#516672
  (Disable unused/unsupported features on qemu-kvm)

* Mon Oct 05 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-125.el5
- kvm-kernel-KVM-VMX-Adjust-rflags-if-in-real-mode-emulation.patch [bz#517324]
- kvm-kernel-KVM-When-switching-to-a-vm8086-task-load-segments-as.patch [bz#517324]
- kvm-kernel-RHEL5.4-defined-this-constants-in-asm-msr.h.patch [bz#515749]
- kvm-kernel-For-RHEl5.x-return-types-of-hrtimers-is-int.patch [bz#515749]
- kvm-kernel-KVM-VMX-flush-TLB-with-INVEPT-on-cpu-migration.patch [bz#518081]
- kvm-kernel-KVM-Fix-task-switch-back-link-handling-v2-including-.patch [bz#517324]
- Resolves: bz#515749
  (Remove warnings from kvm compilation)
- Resolves: bz#517324
  (KVM does not implement proper support for hardware task linking when using vm8086 mode)
- Resolves: bz#518081
  (vmentry fails with ept misconfig)

- kvm-test-access-remove-warning.patch [bz#515749]
- kvm-test-emulator-remove-unused-variable.patch [bz#515749]
- kvm-test-vmexit-remove-warning-undefined-printf.patch [bz#515749]
- kvm-external-module-compat-bring-c89-prototypes-to-intel.patch [bz#515749]
- Resolves: bz#515749
  (Remove warnings from kvm compilation)

* Fri Oct 02 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-124.el5
- kvm-kernel-KVM-x86-verify-MTRR-PAT-validity.patch [bz#526837]
- Resolves: bz#526837
  (KVM: x86: verify MTRR/PAT validity (upstream backport))

* Fri Oct 02 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-123.el5
- kvm-Disable-help-for-vmware-vga-and-enable-nesting.patch [bz#516672]
- kvm-Now-that-we-have-disable-bluetooth-disable-also-bt-c.patch [bz#516672]
- kvm-migration_notify_register-is-only-used-by-spice.patch [bz#516672]
- kvm-Fix-typo-should-have-been-from-the-beggining.patch [bz#516672]
- kvm-Don-t-compile-drivers-that-are-not-used-in-a-pc.patch [bz#516672]
- kvm-Add-option-to-disable-pcspk.patch [bz#516672]
- kvm-usb_bluez-depends-of-bluez.patch [bz#516672]
- Resolves: bz#516672
  (Disable unused/unsupported features on qemu-kvm)

* Fri Oct 02 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-122.el5
- Update kversion to 2.6.18-164.2.1.el5 to match kernel-devel on build root
- kvm-libkvm-Add-a-wrapper-for-an-ioctl-for-the-KVM_SE.patch [bz#508040]
- kvm-Fetch-sub-leaf-cpuid-values-for-functions-4-0xb-0xd.patch [bz#508040]
- kvm-Initialize-entire-cpuid2-structure.patch [bz#508040]
- kvm-extend-smp-parsing-to-include-cores-and-threads-opti.patch [bz#508040]
- kvm-push-CPUID-level-to-4-to-allow-Intel-multicore-decod.patch [bz#508040]
- kvm-set-CPUID-bits-to-present-cores-and-threads-topology.patch [bz#508040]
- kvm-allow-overriding-of-CPUID-level-on-command-line.patch [bz#508040]
- kvm-force-enable-options.patch [bz#489900]
- kvm-move-kvm-extra-features-detection-after-kvm-detectio.patch [bz#489900]
- kvm-add-options-to-request-kvm-pit-and-device-assignment.patch [bz#489900]
- Added configure options to make build dependency checks more reliable:
  --enable-kvm --enable-qxl --enable-spice --enable-gcrypt --enable-vnc-tls
  [bz#489900]
- Resolves: bz#489900
  (kvm configure should abort if a required option failed)
- Resolves: bz#508040
  (Windows XP not using all CPUS)

* Mon Sep 28 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-121.el5
- Use rtl8029.zrom for ne2k_pci PXE booting (bz#526124)
- Resolves: bz#526124
  (ne model failed to get ip address)

* Fri Sep 25 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-120.el5
- kvm-Add-host_device-support-to-qemu-img.-Nolan-Leake.patch [bz#511072 bz#511072]
- kvm-raw-posix-Handle-errors-in-raw_create.patch [bz#511072 bz#511072]
- Resolves: bz#511072
  (KVM - qemu-img fail to copy a RAW format image over FCP storage)

* Thu Sep 24 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-119.el5
- kvm-Use-kernel-s-smp_call_function_single-instead-of-emu.patch [bz#524970]
- kvm-Properly-handle-pthread_cond_timedwait-timing-out.patch [bz#525114]
- kvm-fix-segfault-in-setting-migration-speed.patch [bz#522887]
- Resolves: bz#522887
  (Call to migrate_set_speed after a migrate_cancel causes segmentation fault in kvm)
- Resolves: bz#524970
  (Guest single-cpu IPI leads to a global IPI on host)
- Resolves: bz#525114
  (KVM QEMU:RHEL OS VM's became not-responding and stopped answering monitor Commands.)

* Wed Sep 23 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-118.el5
- kvm-qemu-virtio-net-do-not-return-stack-pointer-from-fun.patch [bz#521829]
- Resolves: bz#521829
  (QEMU crash (during virtio-net WHQL tests for Win2008 R2))

* Mon Sep 21 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-117.el5
- kvm-kernel-KVM-VMX-Optimize-vmx_get_cpl.patch [bz#524126]
- kvm-kernel-KVM-x86-Disallow-hypercalls-for-guest-callers-in-rin.patch [bz#524126]
- kvm-kernel-KVM-VMX-Don-t-intercept-MSR_KERNEL_GS_BASE-v2.patch [bz#488130 bz#488130]
- Resolves: bz#488130
  (KVM: VMX: Don't intercept MSR_KERNEL_GS_BASE (upstream patch))
- Resolves: bz#524126
  (kernel: KVM: x86: Disallow hypercalls for guest callers in rings > 0 [rhel-5.5])

- kvm-qcow2-Change-cluster-size-to-64k.patch [bz#502809]
- kvm-Fix-for-Bug-510706-qemu-kvm-segfault-when-using-i825.patch [bz#510706]
- Resolves: bz#502809
  ([FEAT] Change qcow2 cluster size to 64k)
- Resolves: bz#510706
  (qemu-kvm segfault when using i82551 vnic)

* Fri Sep 18 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-116.el5
- kvm-kernel-Revert-KVM-VMX-Don-t-intercept-MSR_KERNEL_GS_BASE.patch [bz#488130]
  kvm-kernel-KVM-VMX-Don-t-intercept-MSR_KERNEL_GS_BASE.patch was broken
- Related: bz#488130
  (KVM: VMX: Don't intercept MSR_KERNEL_GS_BASE (upstream patch))

* Thu Sep 17 2009 Eduardo Habkost <ehabkost@redhat.com> - kvm-83-115.el5
- kvm-kernel-KVM-VMX-Don-t-intercept-MSR_KERNEL_GS_BASE.patch [bz#488130]
- Resolves: bz#488130
  (KVM: VMX: Don't intercept MSR_KERNEL_GS_BASE (upstream patch))
- kvm-Use-quiet-command-to-get-a-cleaner-build-output.patch [bz#515749]
- kvm-This-function-is-not-used-anymore.-It-is-opencoded-i.patch [bz#515749]
- kvm-fds-variable-is-not-used.-Remaining-of-a-missmerge.patch [bz#515749]
- kvm-use-proper-C89-declarations.patch [bz#515749]
- kvm-pit-is-used-in-two-cases-not-easy-way-to-define-.patch [bz#515749]
- kvm-In-qemu-all-buffers-are-uint8_t-not-char.patch [bz#515749]
- kvm-kvm_allowed-is-exported-in-qemu-kvm.h-and-it-is-used.patch [bz#515749]
- kvm-add-three-missing-static-modifiers-for-local-functio.patch [bz#515749]
- kvm-put-declaration-of-enable_async_notification-in-a-pr.patch [bz#515749]
- kvm-move-several-kvm-variables-after-qemu-kvm.h-include-.patch [bz#515749]
- kvm-mark-static-do_block_set_watermark.patch [bz#515749]
- kvm-txbufferaccu_offset-and-irq-fields-were-save-load-as.patch [bz#515749]
- kvm-mp_state-is-treated-as-unsigned-int-uint32_t-for-sav.patch [bz#515749]
- kvm-hp_reset-should-have-type-QEMUResetHandler.patch [bz#515749]
- kvm-make-static-lsi_scsi_uninit.patch [bz#515749]
- kvm-assigned_dev_data-was-not-used-anywhere.patch [bz#515749]
- kvm-bios_enabled-is-load-saved-as-uint32_t-declare-it-as.patch [bz#515749]
- kvm-remove-unused-variable.patch [bz#515749]
- kvm-add-prototype-for-kvm_add_ioperm_data.patch [bz#515749]
- kvm-removed-duplicated-re-declaration-of-kvm_context-2.patch [bz#515749]
- kvm-make-static-update_vbios_real_tpr.patch [bz#515749]
- kvm-fix-var-may-be-used-uninitialized.patch [bz#515749]
- kvm-make-local-functions-static.patch [bz#515749]
- kvm-remove-unused-variable-opt_rom_offset.patch [bz#515749]
- kvm-removed-duplicated-re-declaration-of-kvm_context.patch [bz#515749]
- kvm-perror-is-defined-in-stdio.h-that-got-included-indir.patch [bz#515749]
- kvm-remove-unused-variable-cpu.patch [bz#515749]
- kvm-nb_sectors-should-be-an-uint64_t.patch [bz#515749]
- kvm-uhci_reset-should-have-QEMUResetHandler-type.patch [bz#515749]
- kvm-initialize-blen-and-pa-variables-to-0.patch [bz#515749]
- kvm-we-got-smp_cpus-declaration-through-sysemu.h.patch [bz#515749]
- kvm-int-and-long-masked-as-pointers.-cast-to-avoid-warni.patch [bz#515749]
- kvm-we-got-vm_running-declaration-through-sysemu.h.patch [bz#515749]
- kvm-BZ503367-obey-S-on-migration.patch [bz#503367 bz#503367]
- kvm-reason-paramenter-only-exist-in-newer-qemu-s-not-our.patch [bz#515749]
- kvm-Fix-AltGr-and-dead-keys-with-VNC.patch [bz#521835]
- kvm-time_t-is-a-long-in-x86_64.patch [bz#515749]
- kvm-bugzilla-504237-changed-size-of-variables-to-uint64_.patch [bz#515749]
- Resolves: bz#503367
  (After migration, paused VM is running on destination)
- Resolves: bz#515749
  (Remove warnings from kvm compilation)
- Resolves: bz#521835
  (German keymap using KVM+VNC missing some keys)

* Tue Sep 15 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-114.el5
- kvm-kernel-reset-hflags-on-cpu-reset.patch [bz#502543 bz#521749]
- Resolves: bz#502543
  (Windows 2008 R2 KVM guest can not restart when set it as multiple cpus)
- Related: bz#521749
  (Guest Window2008-R2-datacenter installation is stopped at  step "Setup will continue after restarting your computer")

* Wed Sep 09 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-113.el5
- kvm-qcow2-Refactor-update_refcount.patch [bz#518169]
- kvm-qcow2-Update-multiple-refcounts-at-once.patch [bz#518169]
- kvm-Combined-patch-of-two-upstream-commits-the-second-fi.patch [bz#518169]
- kvm-alloc_cluster_link_l2-Write-complete-sectors.patch [bz#518169]
- kvm-update_refcount-Write-complete-sectors.patch [bz#518169]
- Resolves: bz#518169
  (Bad qcow2 performance with cache=off)

* Fri Sep 04 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-112.el5
- kvm-kernel-Fix-coalesced-interrupt-reporting-in-IOAPIC.patch [bz#521025]
- Resolves: bz#521025
  (rtc-td-hack stopped working. Time drifts in windows)

* Thu Sep 03 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-111.el5
- kvm-Fix-VM-state-change-handlers-running-out-of-order.patch [bz#514522]
- kvm-Revert-Work-around-VM-state-change-handlers-running-.patch [bz#514522]
- Resolves: bz#514522
  (QEMU: Fix VM change state issue on IO errors)

* Thu Sep 03 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-110.el5
- Update kversion to 2.6.18-164.el5 to match kernel-devel on build root
- kvm-kernel-Backport-44882eed2ebe7f75f8cdae5671ab1d6e0fa40dbc.patch [bz#515549]
- kvm-kernel-kvm-fix-ack-not-being-delivered-when-msi-present.patch [bz#515549]
- kvm-kernel-kvm-fix-build-with-defconfig.patch [bz#515549]
- Resolves: bz#515549
  (upstream qemu issues on rhel 5.4)
- kvm-Remove-initrd-warning-message.patch [bz#512672]
- Resolves: bz#512672
  (Remove initrd warning message)

* Wed Sep 02 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-109.el5
- kvm-kernel-add-nmi-support-to-svm.patch [bz#502543 bz#503322 bz#492290]
- kvm-kernel-VMX-Fix-cr8-exiting-control-clobbering-by-EPT.patch [bz#520285]
- Resolves: bz#492290
  (KVM: XP virtio-net tests fail with BSOD on AMD host (due to lack of NMI injection masking ability))
- Resolves: bz#502543
  (Windows 2008 R2 KVM guest can not restart when set it as multiple cpus)
- Resolves: bz#503322
  (NMI filtering for AMD (Windows 2008 R2 KVM guest can not restart when set it as multiple cpus))
- Resolves: bz#520285
  (windows 64 bit does vmexit on each cr8 access.)

* Thu Aug 27 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-108.el5
- kvm-kernel-KVM-MMU-make-__kvm_mmu_free_some_pages-handle-empty-.patch [bz#519397]
- Resolves: bz#519397
  (KVM: MMU: make __kvm_mmu_free_some_pages handle empty list (upstream backport))

* Thu Aug 27 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-107.el5
- kvm-kernel-KVM-MMU-fix-bogus-alloc_mmu_pages-assignment.patch [bz#487857]
- Resolves: bz#487857
  (The emulator hung after input "cpu_set 1 online" on qemuMonitor and select "System->Shutdown")

* Fri Aug 14 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-106.el5
- Update kversion to 2.6.18-162.el5
- kvm-Initialize-PS2-keyboard-mouse-state-on-reset.patch [bz#515275]
- Resolves: bz#515275
  (guest not accepting keystrokes or mouse clicks after reboot)

* Tue Aug 04 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-105.el5
- kvm-kernel-KVM-MMU-handle-n_free_mmu_pages-n_alloc_mmu_pages-in.patch [bz#487857]
- Resolves: bz#487857
  (The emulator hung after input "cpu_set 1 online" on qemuMonitor and select "System->Shutdown")

* Fri Jul 31 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-104.el5
- kvm-ide-calls-register_savevm-three-times-for-pci_ide_sa.patch [bz#514887]
- Resolves: bz#514887
  (Mouse and keyboard of guest are unavailable after migration-[kvm-83-101.el5])

* Thu Jul 30 2009 Alan Pevec <apevec@redhat.com> 83-103
- Update kversion to 2.6.18-160.el5
- kvm-qemu-restore-bdrv-fat.patch [bz#514785]
- Resolves: bz#514785
  (KVM: support for -fda fat:floppy was removed - needed for RHEVM)

* Wed Jul 29 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-101.el5
- kvm-make-windows-notice-media-change.patch [bz#513991]
- kvm-Work-around-VM-state-change-handlers-running-out-of-.patch [bz#511038]
- Resolves: bz#511038
  (QEMU: crash because of calling stop twice (QXL assertion))
- Resolves: bz#513991
  (Qemu: change CD right after eject does not work)
- Disable nbd on configure [bz#512837]
- Resolves: bz#512837
  (Disable unused/unsupported features on qemu-kvm)

* Wed Jul 29 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-100.el5
- kvm-Compile-out-NBD-removal.patch [bz#512837]
- Resolves: bz#512837
  (Disable unused/unsupported features on qemu-kvm)

* Wed Jul 29 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-99.el5
- kvm-Reset-irq-line-on-qxl-and-vdi-on-guest-reset.patch [bz#514526]
- kvm-fix-for-bug-508664-KVM-could-not-read-the-boot-disk.patch [bz#508664]
- Resolves: bz#508664
  (KVM: "could not read the boot disk" error message after running "Sys Mark" benchmark on Windows Guest)
- Resolves: bz#514526
  (Reset qxl, vdi irq line on guest reset)

* Wed Jul 29 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-98.el5
- kvm-add-option-to-disable-smb-user-directories.patch [bz#512837]
- kvm-add-option-to-disable-scsi.patch [bz#512837]
- kvm-disable-isapc.patch [bz#512837]
- kvm-add-option-to-disable-kvm-nested.patch [bz#512837]
- kvm-add-option-to-disable-usb-mass-storage-devices.patch [bz#512837]
- kvm-add-option-to-disable-usb-wacom-tablets.patch [bz#512837]
- kvm-add-option-to-disable-usb-serial.patch [bz#512837]
- kvm-add-option-to-disable-usb-net.patch [bz#512837]
- kvm-add-option-to-disable-usb-bluez.patch [bz#512837]
- kvm-change-qcow2-default-cache-mode-to-none.patch [bz#512837]
- kvm-add-option-to-disable-all-cpu-s-model-different-from.patch [bz#512837]
- kvm-add-option-to-disable-vmware-drivers.patch [bz#512837]
- kvm-Enable-configure-out-cards-that-we-don-t-support.patch [bz#512837]
- kvm-Be-able-to-compile-out-bluetooth.patch [bz#512837]
- kvm-Disable-unsupported-block-formats.patch [bz#512837]
- New options to configure to disable unsupported features:
  --disable-smb --disable-scsi --disable-isapc --disable-kvm-nested
  --disable-usb-msd --disable-usb-wacom --disable-usb-serial
  --disable-usb-net --disable-usb-bluez --disable-vmware
  --disable-x86-non-generic-cpus --disable-bluez --audio-card-list=ac97
  --disable-curses
  [bz#512837]
- Resolves: bz#512837
  (Disable unused/unsupported features on qemu-kvm)
- kvm-add-workaround-for-libvirt-bug.patch [bz#499405]
- Resolves: bz#499405
  (KVM: add manufacturer and product name info to guest SMBIOS)

* Wed Jul 29 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-97.el5
- kvm-kernel-KVM-Fix-dirty-bit-tracking-for-slots-with-large-page.patch [bz#512712]
- kvm-kernel-Avoid-redelivery-of-edge-interrupt-before-next-edge.patch [bz#513946]
- Resolves: bz#512712
  (Support huge pages in KVM)
- Resolves: bz#513946
  (keyboard is slow in windows SMP guest.)

* Tue Jul 28 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-96.el5
- kvm-kernel-KVM-take-mmu_lock-when-updating-a-deleted-slot.patch [bz#513098]
- kvm-kernel-KVM-SVM-force-new-asid-on-vcpu-migration.patch [bz#513394]
- Resolves: bz#513098
  (KVM: take mmu_lock when updating a deleted slot (upstream backport))
- Resolves: bz#513394
  (KVM: SVM: force new asid on vcpu migration (upstream backport))
- kvm-Fix-hdev_open-error.patch [bz#513252]
- Resolves: bz#513252
  (Asignation instead of comparation inside if)

* Mon Jul 27 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-95.el5
- kvm-enable-rtc-hack-by-default.patch [bz#512898]
- Resolves: bz#512898
  (Enable rtd-hack by default)

* Wed Jul 22 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-94.el5
- Update kversion to 2.6.18-159.el5
- kvm-virtio_net-remove-the-tx-mitigation-timer.patch [bz#504647]
- Resolves: bz#504647
  (Low UDP throughput from Linux KVM guest)
- kvm-Use-pci_reset_function-in-RHEL5.4-so-FLR-done-proper.patch [bz#510806]
- Resolves: bz#510806
  (KVM: invoke pci_reset_function() when PCI device assigned or deassigned to a guest)

* Tue Jul 21 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-93.el5
- kvm-fix-for-bug-507942-bad-macaddr-of-e1000-in-Windows-2.patch [bz#507942]
- kvm-Set-the-iothread-s-eventfd-pipe-descriptors-to-non-b.patch [bz#511199 bz#507659 bz#511031]
- kvm-Disable-hpet-by-default-there-is-no-way-to-enable-it.patch [bz#512894]
- Resolves: bz#507659
  - Migrate command not  end and vm  responseless on  Nahalem host
- Resolves: bz#507942
  - QEMU: Windows 2003's built-in driver for e1000 does not work with QEMU's e1000  implementation
- Resolves: bz#511199
  - KVM : Failed to migrate VM to a loaded Host
- Resolves: bz#512894
  - Disable hpet by default
- Related: bz#511031
  - qemu-kvm hang during migration when stress test is running in the guest

* Thu Jul 16 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-92.el5
- kvm-kernel-KVM-fix-missing-locking-in-alloc_mmu_pages.patch [bz#510770 bz#505629]
- Resolves: bz#505629
  - KVM: MMU: protect kvm_mmu_change_mmu_pages with mmu_lock (upstream backport)
- Resolves: bz#510770
  - BUG: soft lockup - CPU#4 stuck for 10s! on kksmd

* Thu Jul 16 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-91.el5
- kvm-kernel-MMU-limit-rmap-chain.patch [bz#508776]
- kvm-kvmtrace-update-formats.patch [bz#508776]
- Resolves: bz#508776 - KVM: MMU: limit rmap chain

* Wed Jul 15 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-90.el5
- Update kversion to 2.6.18-158.el5
- kvm-net-add-net-tap-sndbuf-option-with-a-sensible-defaul.patch [bz#508861]
- Resolves: bz#508861 - kvm: add tap send buffer limit to help UDP networking

* Mon Jul 13 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-89.el5
- kvm-kernel-KVM-Introduce-set-get-_interrupt_shadow.patch [bz#509208]
- kvm-kernel-KVM-Deal-with-interrupt-shadow-state-for-emulated-in.patch [bz#509208]
- Resolves: bz#509208 - KVM fixes to make gPXE boot ROMs work
- kvm-Windows-virtio-driver-cannot-pass-WHQL-certification.patch [bz#497058]
- Resolves: bz#497058 - Change virtio-blk pci dubclass to PCI_CLASS_STORAGE_SCSI

* Mon Jul 13 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-88.el5
- kvm-KSM-suspend-fix.patch [bz#505440]
- Resolves: bz#505440 - Panic on suspend with KSM module loaded

* Fri Jul 10 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-87.el5
- kvm-kernel-KVM-limit-lapic-periodic-timer-frequency.patch [bz#510087]
- Resolves: bz#510087 - KVM: limit lapic periodic timer frequency

* Fri Jul 10 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-86.el5
- kvm-fix-bug-506375.patch [bz#506375]
- Resolves: bz#506375 - ksm latency issue when killing guests

* Fri Jul 10 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-85.el5
- Update kversion to 2.6.18-157.el5
- kvm-kernel-KVM-SVM-Remove-port-80-passthrough-upstream-backport.patch [bz#507730]
- kvm-kernel-KVM-protect-concurrent-make_all_cpus_request-upstrea.patch [bz#507733]
- Resolves: bz#507730 - KVM: SVM: Remove port 80 passthrough (upstream backport)
- Resolves: bz#507733 - KVM: protect concurrent make_all_cpus_request (upstream backport)
- kvm-make-vnc-socket-non-blocking.patch [bz#507880]
- kvm-provide-stop-reason-on-demand.patch [bz#505999]
- kvm-Change-default-CPU-model-to-model-6-skype-fix-2.patch [bz#508623]
- Resolves: bz#505999 - pause reason not stored by qemu
- Resolves: bz#507880 - qemu hangs during VNC connection from RHEVM
- Resolves: bz#508623 - Only 1 processor can be detected in "systeminfo" of win2k3 guest with -smp 2 and ACPI multiprocessor HAL.

* Tue Jul 07 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-84.el5
- kvm-net-avoid-leaking-VLANClientState-on-PCI-NIC-hot-rem.patch [bz#500977 bz#500978 bz#500980]
- kvm-Fix-rtl8139-segfault-during-live-migrate-after-NIC-h.patch [bz#500978]
- kvm-Fix-ne2k_pci-segfault-during-live-migrate-after-NIC-.patch [bz#500977]
- kvm-Fix-eepro100-segfault-during-live-migrate-after-NIC-.patch [bz#500980]
- Resolves: bz#500977 - ne2k-pci segfault during live migrate after NIC hot-unplug
- Resolves: bz#500978 - Live migration fails after rtl8139 NIC hot-unplug
- Resolves: bz#500980 - Live migrate fails after i82551 NIC hot-unplug

* Thu Jul 02 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-83.el5
- Update kversion to 2.6.18-156.el5
- kvm-kernel-kvm-x86-ignore-reads-to-perfctr-msrs.patch [bz#482423]
- Resolves: bz#482423 - Kaspersky AV crash the VM after installation
- kvm-Revert-Disable-virtio-balloon-bz-500453.patch [bz#503790]
- kvm-Remove-broken-command-line-option-balloon.patch [bz#503790]
- kvm-New-command-line-option-balloon.patch [bz#503790]
- Resolves: bz#503790 - virtio balloon: add a command-line option to disable it at runtime

* Tue Jun 30 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-82.el5
- kvm-bz-505090-Guess-host-device-type-from-requested-gues.patch [bz#505090]
- kvm-vnc-rework-VncState-release-workflow.patch [bz#505641]
- Resolves: bz#505090 - Virtual machine fails to start without cdom - qemu: could not open disk image /dev/sr0
- Resolves: bz#505641 - Remote VNC client can cause any QEMU VNC server to crash with a double-free

* Tue Jun 23 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-81.el5
- Update kversion to 2.6.18-155.el5
- kvm-enable-sysenter-on-32bit-guests-skype-fix.patch [bz#504628]
- Resolves: bz#504628 - Skype crashes on VM.

* Mon Jun 22 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-80.el5
- kvm-Fix-vga_screen_dump_blank-PPM-generation-bz-500717.patch [bz#500717]
- kvm-Add-qemu-img-check-subcommand.patch [bz#506017]
- Resolves: bz#500717 - qemu-kvm can generate invalid screendumps during reboot
- Resolves: bz#506017 - 'qemu-img check' subcommand is not backported

* Fri Jun 19 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-79.el5
- Update kversion to 2.6.18-154.el5
- Related: bz#504237 - Pull RHEV bugfixes for RHEL
- Related: bz#504713 - BIOS bug - processor goes missing with RHEL3U8 boot kernel

* Fri Jun 19 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-78.el5
- kvm-kernel-KVM-Make-paravirt-tlb-flush-also-reload-the-PAE-PDPT.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes for RHEL
- kvm-bios-Fix-missing-DMI-table-entries.patch [bz#504713]
- kvm-Correctly-assign-apic-ids-for-hotplugged-cpus.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes for RHEL
- Resolves: bz#504713 - BIOS bug - processor goes missing with RHEL3U8 boot kernel

* Wed Jun 17 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-77.el5
- kvm-kernel-KVM-x86-Ignore-reads-to-K7-EVNTSEL-MSRs.patch [bz#504237]
- kvm-kernel-KVM-MMU-protect-kvm_mmu_change_mmu_pages-with-mmu_lo.patch [bz#504237]
- kvm-kernel-KVM-Fix-PDPTR-reloading-on-CR4-writes.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Tue Jun 16 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-76.el5
- kvm-Add-reset-to-e1000-nic.patch [bz#504237]
- kvm-Add-reset-to-rtl8139-nic.patch [bz#504237]
- kvm-Register-uhci_reset-callback.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Mon Jun 15 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-75.el5
- kvm-Add-rtc-reset-function.patch [bz#504237]
- kvm-fix-unresigered-vbe-physical-mapping-as-reserved-mem.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Tue Jun 09 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-74.el5
- Remove /usr/bin/qemu-kvm and keep only /usr/libexec/qemu-kvm
- Resolves: bz#503955 - Move qemu-kvm to /usr/libexec

* Mon Jun 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-73.el5
- kvm-vdi_port-call-disconnect-on-reset-504463.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Mon Jun 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-72.el5
- kvm-KSM-avoid-losing-but-no-mem-leak-rmap_items-inside-k.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Mon Jun 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-71.el5
- kvm-migrate_fd_close-delete-associated-io-handler-before.patch [bz#504237]
- kvm-qemu-add-notify-command-line-option-to-enable-async-.patch [bz#504237]
- kvm-migration-exec-notify-upon-successful-completion-of-.patch [bz#504237]
- kvm-asynchronous-notifications-add-all-event-v3.patch [bz#504237]
- kvm-exec-migration-handle-EINTR-in-popen_get_buffer-v3.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Mon Jun 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-70.el5
- kvm-kernel-fix-bug-between-mm_to_kvm-and-kvm_get_kvm-RHEL-5-bac.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Mon Jun 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-69.el5
- BuildRequires: pciutils-devel for device assignment support
- Resolves: bz#504396

* Mon Jun 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-68.el5
- kvm-fix-qemu_aio_flush.patch [bz#504237]
- kvm-spice-change-vendor-id-504190.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Mon Jun 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-67.el5
- kvm-doesn-t-build-on-newer-RHEL-5.4-kernels-because-.patch [bz#504047]
- Resolves: bz#504047 - kvm doesn't build on newer RHEL-5.4 kernels because of get_user_pages_fast()

* Mon Jun 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-66.el5
- Move qemu-kvm to /usr/libexec, and make /usr/bin/qemu-kvm a symlink to it
- Related: bz#503955
- Resolves: bz#504237

* Sun Jun 07 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-65.el5
- kvm-kernel-Merge-kvm_ioapic_get_delivery_bitmask-into-kvm_get_i.patch [bz#504018]
- Resolves: bz#504018 - kernel oops at kvm_get_intr_delivery_bitmask+0x4e/0x86
- kvm-qxl-fix-message-flood-in-qxl_display_update-501190.patch [bz#504237]
- kvm-fix-bigmem-offset-calculation-for-qxl.patch [bz#504237]
- kvm-add-non-arbitrary-migration-stop-condition.patch [bz#504237]
- kvm-set-migration-max-downtime.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Fri Jun 05 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-64.el5
- Update kversion to 2.6.18-152.el5
- Related: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Fri Jun 05 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-63.el5
- kvm-kernel-KVM-x86-check-for-cr3-validity-in-mmu_alloc_roots.patch [bz#504237]
- kvm-augment-info-migrate-with-page-status.patch [bz#504237]
- kvm-introduce-set_rate_limit-function-for-QEMUFile.patch [bz#504237]
- kvm-allow-changing-the-speed-of-a-running-migration.patch [bz#504237]
- kvm-remove-duplicated-code.patch [bz#504237]
- kvm-only-execute-lapic-load-when-cpu-is-already-initiali.patch [bz#504237]
- kvm-make-sure-kvm_vpu_init-is-the-last-thing-called-in-c.patch [bz#504237]
- kvm-Prevent-CD-ROM-media-eject-while-device-is-locked.patch [bz#504237]
- kvm-KSM-sync-ksm-and-rhel-5.4-gup-fast.patch [bz#504237]
- kvm-ksm-remove-kprobes-usage-for-rhel-5.4-v3.patch [bz#504237]
- kvm-KSM-avoid-usage-of-free-slabed-memory.-triggered-wit.patch [bz#504237]
- Resolves: bz#504237 - Pull RHEV bugfixes added after kvm-83-58.el5ovirt

* Tue Jun 02 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-60.el5
- kvm-Disable-virtio-balloon-bz-500453.patch [bz#503811]
- Resolves: bz#503811 - Pull disable-virtio-balloon patch from RHEV branch

* Tue Jun 02 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-59.el5
- kvm-kernel-KVM-Fix-NX-support-reporting.patch [bz#503793]
- kvm-kernel-KVM-x86-check-for-cr3-validity-in-ioctl_set_sregs.patch [bz#503793]
- kvm-Revert-qemu-fix-bad-physical-address-in-kvm_update_d.patch [bz#503793]
- kvm-Enable-dirty-logging-for-all-regions-during-migratio.patch [bz#503793]
- kvm-migrate.c-migrate_fd_put_buffer-Do-not-busyloop-stop.patch [bz#503793]
- kvm-cirrus-fix-text-screen-corruption-on-reset.patch [bz#503793]
- kvm-Support-multiple-VNC-clients-re-added.patch [bz#503793]
- kvm-vnc-fix-multiple-connections-displaystate-initializa.patch [bz#503793]
- kvm-vnc-Remove-checks-for-qemu_realloc-return-value.patch [bz#503793]
- kvm-ksm-remove-full-swapping-support-for-kvm-mmu-pages-u.patch [bz#503793]
- kvm-keypad-support.patch [bz#503793]
- kvm-Call-missing-qemu_bh_delete-at-the-end-of-raw_aio_em.patch [bz#503793]
- kvm-Add-qemu_send_raw-to-vlan.patch [bz#503793]
- kvm-Minimal-ethernet-frame-length-is-64-bytes.patch [bz#503793]
- kvm-Don-t-send-all-gratuitous-packets-at-once.patch [bz#503793]
- kvm-fix-wrong-bios-pci-mapping-for-large-slots-Bug-49943.patch [bz#503793]
- Resolves: bz#503793 - Pull RHEV bugfixes between kvm-83-52.el5ovirt and kvm-83-58.el5ovirt
- Bump release number to make it higher than the latest .el5ovirt RPM

* Thu May 28 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-44.el5
- kvm-kernel-KVM-Ioctls-for-init-MSI-X-entry.patch [bz#498085]
- kvm-kernel-KVM-Add-MSI-X-interrupt-injection-logic.patch [bz#498085]
- kvm-kernel-KVM-Enable-MSI-X-for-KVM-assigned-device.patch [bz#498085]
- kvm-kernel-KVM-Get-support-IRQ-routing-entry-counts.patch [bz#498085]
- kvm-kernel-KVM-Device-assignment-framework-rework.patch [bz#498085]
- kvm-kernel-KVM-Correct-deassign-device-ioctl-to-IOW.patch [bz#498085]
- kvm-kernel-KVM-Wake-up-waitqueue-before-calling-get_cpu.patch [bz#498085]
- kvm-kernel-KVM-use-smp_send_reschedule-in-kvm_vcpu_kick.patch [bz#498085]
- kvm-kernel-KVM-protect-assigned-dev-workqueue-int-handler-and-i.patch [bz#498085]
- kvm-libkvm-support-KVM_ASSIGN_DEV_IRQ-and-KVM_DEASSI.patch [bz#498085]
- kvm-qemu-Replace-force-type-convert-with-container_o.patch [bz#498085]
- kvm-qemu-Make-device-assignment-depend-on-libpci.patch [bz#498085]
- kvm-qemu-Figure-out-device-capability.patch [bz#498085]
- kvm-qemu-Support-for-device-capability.patch [bz#498085]
- kvm-libkvm-user-interface-for-MSI-type-irq-routing.patch [bz#498085]
- kvm-libkvm-allocate-unused-gsi-for-irq-routing.patch [bz#498085]
- kvm-qemu-expose-MSI-capability-to-guest.patch [bz#498085]
- kvm-qemu-Support-MSI-convert-to-INTx-in-device-assig.patch [bz#498085]
- kvm-qemu-Add-MSI-X-related-macro-to-pci.c.patch [bz#498085]
- kvm-libkvm-add-ioctl-wrappers-for-KVM_SET_MSIX_ENTRY.patch [bz#498085]
- kvm-qemu-enable-MSI-X-capabilty-for-assigned-device.patch [bz#498085]
- kvm-qemu-fix-interrupt-pin-0-assignment.patch [bz#498085]
- kvm-qemu-Fill-config-with-correct-VID-DID.patch [bz#498085]
- kvm-qemu-emulate-command-register-for-SRIOV-virtual-.patch [bz#498085]
- kvm-qemu-Move-assigned-device-capability-init-earlie.patch [bz#498085]
- kvm-qemu-improve-pci-host-device-address-parsing.patch [bz#498085]
- kvm-qemu-don-t-check-per-vector-mask-bit-before-enab.patch [bz#498085]
- kvm-qemu-Fix-wrong-counting-of-MSI-X-table-size.patch [bz#498085]
- kvm-device-assignment-move-memset-to-after-mmap-failure-.patch [bz#498085]
- kvm-Remove-MSI-masking-when-setting-initial-MSI-X-entrie.patch [bz#498085]
- kvm-nr_cpu_ids-compat.patch [bz#498085]
- kvm-smp_send_reschedule-compat.patch [bz#498085]
- kvm-Adjust-kvm_smp_send_reschedule-availability.patch [bz#498085]
- kvm-Adjust-nr_cpu_ids-check.patch [bz#498085]
- Resolves: bz#498085 - kvm add guest MSI support

* Thu May 28 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-43.el5
- Update kversion to kernel-2.6.18-151.el5
- Related: bz#498071 - kvm external module build fixes for RHEL 5.4
- Related: bz#498084 - Add infrastructure needed for later adding guest MSI support

* Thu May 28 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-42.el5
- kvm-kernel-KVM-Add-support-to-disable-MSI-for-assigned-device.patch [bz#498084]
- kvm-kernel-KVM-Userspace-controlled-irq-routing.patch [bz#498084]
- kvm-kernel-KVM-Use-irq-routing-API-for-MSI.patch [bz#498084]
- kvm-kernel-KVM-VMX-Use-kvm_mmu_page_fault-handle-EPT-violation-.patch [bz#498084]
- kvm-kernel-KVM-Report-IRQ-injection-status-for-MSI-delivered-in.patch [bz#498084]
- kvm-kernel-KVM-define-KVM_CAP_DEVICE_DEASSIGNMENT.patch [bz#498084]
- kvm-kernel-KVM-fix-kvm_vm_ioctl_deassign_device.patch [bz#498084]
- kvm-kernel-KVM-Split-IOAPIC-structure.patch [bz#498084]
- kvm-kernel-KVM-Unify-the-delivery-of-IOAPIC-and-MSI-interrupts.patch [bz#498084]
- kvm-kernel-KVM-Change-API-of-kvm_ioapic_get_delivery_bitmask.patch [bz#498084]
- kvm-kernel-KVM-Update-intr-delivery-func-to-accept-unsigned-lon.patch [bz#498084]
- kvm-kernel-KVM-bit-ops-for-deliver_bitmap.patch [bz#498084]
- kvm-Fix-request_irq-for-2.6.19.patch [bz#498071]
- kvm-Fix-kvm_request_irq-race.patch [bz#498071]
- kvm-qemu-device-assignment-don-t-use-libkvm-s-privat.patch [bz#498084]
- kvm-qemu-device-assignment-add-assigned_dev_update_i.patch [bz#498084]
- kvm-qemu-device-assignment-fix-ROM-writing.patch [bz#498084]
- kvm-libkvm-support-for-irq-routing.patch [bz#498084]
- kvm-qemu-initialize-irq-routing-table.patch [bz#498084]
- kvm-libkvm-Fix-return-of-kvm_commit_irq_routes.patch [bz#498084]
- kvm-libkvm-add-deassign-ioctl.patch [bz#498084]
- kvm-qemu-free-device-on-error-in-init_assigned_devic.patch [bz#498084]
- kvm-qemu-wrap-assign_device-and-assign_irq.patch [bz#498084]
- kvm-qemu-deassign-device-from-guest.patch [bz#498084]
- kvm-qemu-fix-hot-remove-assigned-device.patch [bz#498084]
- kvm-qemu-fix-build-breakage-on-non-device-deassignme.patch [bz#498084]
- kvm-qemu-deassign-irq-for-INTx.patch [bz#498084]
- Resolves: bz#498071 - kvm external module build fixes for RHEL 5.4
- Resolves: bz#498084 - Add infrastructure needed for later adding guest MSI support

* Thu May 21 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-41.el5
- Point to new kernel version: 2.6.18-150.el5
- Related: bz#497232

* Wed May 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-40.el5
- Enabling spice support, now that qspice-0.3.0 is available on the buildroot
- Resolves: bz#497232 - kvm not linked against qspice library

* Wed May 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-39.el5
- kvm-Revert-external-module-don-t-redefined-get_user_page.patch [bz#501777]
  (Reverts kvm-external-module-don-t-redefined-get_user_pages_fast-.patch, that
  didn't solve the issue)
- kvm-external-module-don-t-redefine-get_user_pages_fast-o.patch [bz#501777]
- Resolves: bz#501777 - kvm doesn't build on newer RHEL-5.4 kernels because of get_user_pages_fast()

* Wed May 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-38.el5
- kvm-external-module-don-t-redefined-get_user_pages_fast-.patch [bz#501777]
- Resolves: bz#501777 - kvm doesn't build on newer RHEL-5.4 kernels because of get_user_pages_fast()

* Wed May 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-37.el5
- kvm-external-module-Fix-build-for-VT-d-AMD-IOMMU.patch [bz#498071]
- kvm-external-module-don-t-conflict-w-phys_addr_t.patch [bz#498071]
- Related: bz#498071 - kvm external module build fixes for RHEL 5.4

* Wed May 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-36.el5
- kvm-qemu-Add-support-for-SMBIOS-command-line-options-Ale.patch [bz#501729 bz#501729]
- kvm-Don-t-try-to-extract-protocol-from-absolute-filename.patch [bz#501729]
- kvm-kvmtrace_format-read-usr-share-kvm-formats-by-defaul.patch [bz#501729]
- kvm-e1000-Do-not-reinit-pci-config-space-to-0.patch [bz#501729]
- kvm-Fix-cluster-freeing-in-qcow2.patch [bz#501729]
- kvm-Revert-Fix-CVE-2008-0928-insufficient-block-device-a.patch [bz#501729]
- kvm-Fix-CVE-2008-0928-insufficient-block-device-address-.patch [bz#501729]
- kvm-don-t-use-a-32-bit-bit-type-as-offset-argument.patch [bz#501729]
- kvm-Fix-oops-on-2.6.25-guest-Rusty-Russell.patch [bz#501729]
- kvm-Fix-segfault-after-tap-host_net_remove.patch [bz#501729]
- kvm-Fix-virtio-net-segfault-during-live-migrate-after-NI.patch [bz#501729]
- kvm-Fix-e1000-segfault-during-live-migrate-after-NIC-hot.patch [bz#501729]
- kvm-Backport-oom_check-from-upstream.patch [bz#501729]
- kvm-qcow2-fix-image-creation-for-large-2TB-images-Chris-.patch [bz#501729]
- kvm-Fix-live-migratation-failure-after-pcnet-NIC-hot-unp.patch [bz#501729]
- kvm-Fix-qemu_realloc-with-size-0.patch [bz#501729]
- Spec file sync: [bz#501729]
  - Package user/formats on /usr/share/kvm
  - Add spice sanity check (disabled because with_spice is 0)
- Update kernel version requires to 2.6.18-149.el5
- Resolves: bz#501729 - Pull RHEV bugfixes between kvm-83-42.el5ovirt and kvm-83-52.el5ovirt

* Tue May 12 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-35.el5
- Spec changes that are needed with the patches recently added:
  - Package user/formats as %%doc
  - Package /usr/bin/qemu-io on kvm-tools package
- Related: bz#500263

* Tue May 12 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-34.el5
- kvm-kernel-KVM-Add-CONFIG_HAVE_KVM_IRQCHIP.patch [bz#500263]
- kvm-kernel-KVM-Interrupt-mask-notifiers-for-ioapic.patch [bz#500263]
- kvm-kernel-KVM-Reset-PIT-irq-injection-logic-when-the-PIT-IRQ-i.patch [bz#500263]
- kvm-kernel-KVM-Fix-overlapping-check-for-memory-slots.patch [bz#500263]
- kvm-kernel-KVM-MMU-Fix-off-by-one-calculating-large-page-count.patch [bz#500263]
- kvm-kernel-KVM-MMU-disable-global-page-optimization.patch [bz#500263]
- kvm-KSM-fix-bug-495714.patch [bz#500263]
- kvm-fix-extboot-from-boot-with-cache-off.patch [bz#500263]
- kvm-KSM-fix-bug-495912.patch [bz#500263]
- kvm-KSM-fix-495350-effective-bug.patch [bz#500263]
- kvm-ksm-fix-Bug-496668-stabilaty-issue.patch [bz#500263]
- kvm-qemu-drop-packet-from-tap-device-if-all-NICs-are.patch [bz#500263]
- kvm-fix-effective-bug-497042.patch [bz#500263]
- kvm-qemu-fixup-4GB-memslot-large-page-alignment.patch [bz#500263]
- kvm-Import-qemu-io-source-from-upstream.patch [bz#500263]
- kvm-qemu-io-Comment-out-readv-writev-code.patch [bz#500263]
- kvm-Add-qemu-io-to-Makefile-and-configure.patch [bz#500263]
- kvm-Fix-migration-with-smp-Bz-485966.patch [bz#500263]
- kvm-char-Fix-closing-of-various-char-devices-Jan-Kiszka.patch [bz#500263]
- kvm-spice-improve-audio-quality-493279.patch [bz#500263]
- kvm-spice-using-term_printf_async-for-vdi-log-messages-4.patch [bz#500263]
- Update kernel version dependency to 2.6.18-141.el5
- Resolves: bz#500263 - Import RHEV kvm fixes added between kvm-83-35.el5ovirt and kvm-83-42.el5ovirt

* Mon Apr 27 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-33.el5
- kvm-qemu-tool-adding-an-empty-implementation-of-term_pr.patch [bz#497886]
- kvm-block_set_watermark-use-term_printf_async-for-notif.patch [bz#497886]
- kvm-Fix-at-least-one-cause-of-qcow2-corruption.-Nolan.patch [bz#497886]
- kvm-Flush-all-pending-io-at-the-end-of-a-migration.patch [bz#497886]
- kvm-make-BlockDriver-struct-opaque-and-global.patch [bz#497886]
- kvm-Reopen-block-drivers-after-migration.patch [bz#497886]
- kvm-qcow2-corruption-Fix-alloc_cluster_link_l2.patch [bz#497886]
- kvm-Change-RTC-time-drift-IRQ-re-injection-logic.patch [bz#497886]
- kvm-KSM-fix-bug-495348.patch [bz#497886]
- kvm-KSM-fix-bug-495349-KSM-correctness-issue.patch [bz#497886]
- kvm-KSM-fix-bug-495351-effective-issue.patch [bz#497886]
- Resolves: bz#497886 - Import kvm fixes from RHEV branch

* Wed Apr 15 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-32.el5
- Build against kernel 2.6.18-135.el5
- Related: bz#488511

* Wed Apr 15 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-31.el5
- Disable qspice support while qspice is not available on RHEL-5 branch
- Related: bz#488511

* Tue Apr 14 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-30.el5
- Set build_arches to x86_64 only
- Related: bz#488511

* Wed Apr 08 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-29.el5ovirt
- kvm-external-module-hrtimer_expires_remaining-was.patch [bz#493112]
- kvm-Make-make-install-depend-on-bios-and-vgabios.patch [bz#493112]
- Remove pre-built binaries from source tarball [bz#493112]
  - Rename kvm-remove-crypto.sh to kvm-strip-tarball.sh
- Resolves: bz#493112 - Allow building KVM RHEV tree on newer kernels and on other distributions

* Mon Apr 06 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-28.el5ovirt
- kvm-Avoid-running-audio-ctl-s-when-vm-is-not-running.patch [bz#492204]
- Resolves: bz#492204 - kvm: Avoid running audio ctl's when vm is not running

* Mon Apr 06 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-27.el5ovirt
- Rebuild (again) against new qspice, now that bz#489896 is fixed again
- Resolves: bz#494251

* Mon Apr 06 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-26.el5ovirt
- Rebuild against qspice package with fixed pkgconfig file [bz#494251]
- Resolves: bz#494251

* Thu Apr 02 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-25.el5ovirt
- kvm-Revert-Introducing-qcow2-extensions-keep-backing.patch [bz#489964]
- kvm-Revert-qemu-img-info-show-highest_alloc-and-num_f.patch [bz#489964]
- kvm-Revert-qcow2-format-keep-num_free_bytes-and-sho.patch [bz#489964]
- kvm-Revert-info-blockstats-show-highest_allocated-if-e.patch [bz#489964]
- kvm-Revert-block-qcow2-export-highest_allocated-throug.patch [bz#489964]
- kvm-Revert-block-qcow2-keep-highest-allocated-byte-Ur.patch [bz#489964]
- kvm-Introducing-qcow2-extensions-Uri-Lublin.patch [bz#489964]
- kvm-block-support-known-backing-format-for-image-create.patch [bz#489964]
- kvm-block-qcow2-keep-backing-file-format-in-a-qcow2-ext.patch [bz#489964]
- kvm-block-qcow2-keep-highest-allocated-offset.patch [bz#489964]
- kvm-block-set-high-watermark-and-get-a-notification-whe.patch [bz#489964]
- kvm-Show-drive-name-on-ENOSPC-notification.patch [bz#489964]
- Resolves: bz#489964

* Thu Apr 02 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-24.el5ovirt
- Build against kernel-2.6.18-128.1.6.el5
- Related: bz#490956

* Wed Apr 01 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-23.el5ovirt
- kvm-kernel-Revert-Disable-kvmclock-by-default.patch [bz#492649]
- Resolves: bz#492649
- kvm-qemu-stop-start-cpus-before-after-devices.patch [bz#492355]
- kvm-extboot-should-update-number-of-HDs-reported-by-BIOS.patch [bz#491861]
- Resolves: bz#492355 bz#491861

* Mon Mar 30 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-22.el5ovirt
- kvm-qemu-fix-physical-memory-migration.patch [bz#492351]
- kvm-host_device_remove-remove-incorrect-check-for-devic.patch [bz#491156]
- kvm-e1000-Fix-RX-descriptor-low-threshold-interrupt-log.patch [bz#491930]
- kvm-qemu-fix-bad-physical-address-in-kvm_update_dirty_p.patch [bz#492357]
- kvm-vdi_port-fix-migration.patch [bz#492365]
- kvm-external-module-do-not-hardcode-tsc_khz.patch [bz#488543]
- kvm-kernel-Backport-fix-for-bz-482423-from-upstream.patch [bz#482423]
- Resolves: bz#482423 bz#492351 bz#491156 bz#491930 bz#492357

* Tue Mar 17 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-21.el5ovirt
- Change license tag to GPLv2 [bz#490741]
- Remove qspice-specific BuildRequires, now that qspice bz#489896 was fixed
  [bz#490956]
- Build against kernel 2.6.18-128.1.1.el5
- Resolves: bz#490741
- Related: bz#490956

* Tue Mar 17 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-20.el5ovirt
- kvm-Parse-full-PCI-device-addresses-Markus-Armbruster.patch [bz#489992]
- kvm-Backport-upstream-QEMU-PCI-hotplug-code.patch [bz#489992]
- kvm-make-qemu_announce_self-handle-non-contiguous-net-ta.patch [bz#489992]
- Resolves: bz#489992

* Mon Mar 16 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-19.el5ovirt
- kvm-kernel-Fix-BZ483561-dmesg-flooded-with-kvm-14619-cpu1-u.patch [bz#483561]
- kvm-kernel-KVM-Fix-missing-smp-tlb-flush-in-invlpg.patch [bz#490469]
- Resolves: bz#483561 bz#490469

* Thu Mar 12 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-18.el5ovirt
- kvm-Fix-size-of-async_printable_events-array.patch [bz#489971]
- Resolves: bz#489971

* Thu Mar 12 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-17.el5ovirt
- Remove unneeded code from spec %%install section
- Rebuild against qspice-0.1.0-14.gitdd420d.el5ovirt

* Wed Mar 11 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-16.el5ovirt
- Remove openssl BuildRequires. We are using libgcrypto for crypto code, now
- kvm-kernel-Disable-kvmclock-by-default.patch [bz#469425][bz#488543]
- Related: bz#469425 bz#488543

* Mon Mar 09 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-15.el5ovirt
- kvm-qemu-prevent-reset-of-vga-fb-mapping-in-case-of-isa.patch [bz#489348]
- kvm-TPR-patching-instruction_is_ok-fix-virtual-addre.patch [bz#483494]

* Mon Mar 09 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-14.el5ovirt
- kvm-vmchannel-use-Red-Hat-s-PCI-vendor-ID.patch [bz#487109]

* Thu Mar 05 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-13.el5ovirt
- kvm-kernel-KVM-x86-release-time_page-on-vcpu-destruction.patch [bz#488725]
- kvm-kernel-KVM-VMX-Update-necessary-state-when-guest-enters-l.patch [bz#488724]
- kvm-kernel-KVM-is_long_mode-should-check-for-EFER.LMA.patch [bz#488724]
- kvm-kernel-KVM-MMU-Fix-another-largepage-memory-leak.patch [bz#488725]
- kvm-kernel-KVM-MMU-handle-compound-pages-in-kvm_is_mmio_pfn.patch [bz#488727]
- kvm-bios-make-MMIO-address-page-aligned-in-guest.patch [bz#488732]
- kvm-external-module-backward-compatibility-for-com.patch [bz#488727]
- kvm-external-module-handle-compound_head-on-RHEL.patch [bz#488727]

* Tue Mar 03 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-12.el5ovirt
- kvm-Fix-cpu_physical_memory_rw-for-64-bit-I-O-accesses.patch [bz#488135]
- kvm-block-qcow2-keep-highest-allocated-byte-Uri-Lublin.patch [bz#488250]
- kvm-block-qcow2-export-highest_allocated-through-BlockD.patch [bz#488250]
- kvm-info-blockstats-show-highest_allocated-if-exists-U.patch [bz#488250]
- kvm-qcow2-format-keep-num_free_bytes-and-show-it-upo.patch [bz#488250]
- kvm-qemu-img-info-show-highest_alloc-and-num_free_byte.patch [bz#488250]
- kvm-Introducing-qcow2-extensions-keep-backing-file-for.patch [bz#484080]
- kvm-qemu-img-adding-a-F-base_fmt-option-to-qemu-img.patch [bz#484080]
- Renumbered kvm-kernel patches to allow space for more userspace patches

* Mon Mar 02 2009 Eduardo Habkost <ehabkost@redhat.com>- 83-11.el5ovirt
- kvm-add-notification-for-vmstops.patch [bz#481863]
- kvm-Change-default-werror-semantics-from-report-to-en.patch [bz#481863]

* Mon Mar 02 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-10.el5ovirt
- kvm-kernel-Report-IRQ-injection-status-to-userspace.patch [bz#487595]
- kvm-handle-IRQ-status-injection-in-userspace.patch [bz#487595]
- kvm-Allow-additions-of-ACPI-tables-from-command-line.patch [bz#488041]
- kvm-cirrus-cleanup-reset-handler.patch [bz#488036]

* Fri Feb 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-9.el5ovirt
- kvm-external-module-compatibility-for-hrtimer_expi.patch [bz#485482]
- kvm-kernel-KVM-x86-fix-LAPIC-pending-count-calculation.patch [bz#485482]
- kvm-kernel-KVM-VMX-Flush-volatile-msrs-before-emulating-rdmsr.patch [bz#486583]

* Thu Feb 19 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-8.el5ovirt
- kvm-qemu-fix-double-removal-of-assigned-device.patch [bz#485318]
- kvm-backport-kvm-qemu-fix-leak-of-ioperm-data.patch [bz#485318]
- kvm-backport-kvm-qemu-remove-the-useless-parameter.patch [bz#485318]
- kvm-qemu-use-fd-instead-of-QEMUFile-in-pre-VM-migrate-s.patch [bz#485752]
- kvm-kernel-KVM-Fix-assigned-devices-circular-locking-dependenc.patch [bz#485483]
- kvm-kernel-KVM-Fix-INTx-for-device-assignment.patch [bz#485484]
- kvm-kernel-KVM-MMU-Map-device-MMIO-as-UC-in-EPT.patch [bz#485485]

* Thu Feb 12 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-7.el5ovirt
- bz#485291:
  - kvm-don-t-call-kvm_init_vcpu-twice.patch
  - kvm-Fix-GPE-registers-read-write-handling.patch
  - kvm-Fix-CPU-hotplug.patch
  - kvm-Use-reserved-STS-bits-from-PIIX4-chipset-to-avoid-cl.patch
  - kvm-PCI-hotplug-SCI-fix.patch

* Thu Feb 12 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-6.el5ovirt
- Fix for bz#484747 (Block device corruption on ENOSPC errors):
  - kvm-Stop-VM-on-ENOSPC-error-IDE.patch
  - kvm-Stop-VM-on-error-in-scsi-disk.patch
  - kvm-Stop-VM-on-error-in-virtio-blk.patch
  - kvm-kvm-qemu-Allow-calling-vm_stop-from-vcpu-thread.patch
- Spice fix:
  - kvm-vdi_port-don-t-modifay-device-while-in-stop-state.patch
- Fixes from upstream:
  - kvm-Don-t-notify-virtio-devices-before-S_DRIVER_OK.patch
  - kvm-kvm-qemu-Don-t-unregister-unassigned-PCI-BAR.patch
  - kvm-kvm-qemu-preallocate-mem-path-memory-by-default.patch
  - kvm-kvm-qemu-Remove-eflags-conversion-into-emulator-fo.patch
  - kvm-Always-return-latest-pmsts-instead-of-the-old-one.patch
  - kvm-kvm-qemu-make-mem-path-memory-allocation-depend.patch
  - kvm-Fix-SIGSEGV-crash-in-slirp-networking-code.patch
  - kvm-check-SCSI-read-write-requests-against-max-LBA.patch
  - kvm-qemu-vnc-reset-has_WMVi-when-new-client-connects.patch
  - kvm-fix-use-of-host-serial-port.patch

* Mon Feb 09 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-4.el5ovirt
- More changes due to rpmlint warnings:
  - Fix bogus qemu-img manpage permission
  - Capitalize package summaries
  - Mark udev rules file on /etc as %%config on file list

* Mon Feb 09 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-3.el5ovirt
- Make rpmlint happy:
  - Versioned qemu-img provides
  - use %%defattr on all %%files sections
  - %%define _use_internal_dependency_generator 0
  - don't mix tabs and spaces on scripts

* Fri Feb 06 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-2.el5ovirt
- Patch reordering, so the crypto removal stuff appears first (no
  actual code changes)

* Thu Feb 05 2009 Eduardo Habkost <ehabkost@redhat.com> - 83-1.el5ovirt
- Change to tarball+patches model instead of a snapshot of a private git tree.
  The resulting code is exactly the same from kvm-82.ovirt1.test19

* Wed Feb 04 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test19-2
- Create kvm-tools subpackage, with kvmtrace and kvm_stat (bz#483844)

* Tue Feb 03 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test19-1
- kvm-82.ovirt1.test19:
  - Use libgcrypt for cryptography code instead of libcrypto
  - Fix ksm-mem.ko module loading
  - SCSI emulation fixes from Rik van Riel

* Mon Feb 02 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test18-1
- kvm-82.ovirt1.test18:
  - slirp license update
  - removed qcow-over-lvm patch series (bz#483310)

* Fri Jan 30 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test17-1
- kvm-82.ovirt1.test17:
  - Added hypercall-device-based vmchannel implementation
  - Removed network-interface-based vmchannel implementation
  - Removed cryptography code from KVM, replacing it with calls
    to libcrypto

* Thu Jan 29 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test16-1
- kvm-82.ovirt1.test16
- Rename ksm-mem.ko to ksm.ko

* Wed Jan 28 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test15-1
- Update to kvm-82.ovirt1.test15 (included new spice patches)

* Wed Jan 28 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test14-3
- YA rebuild for updated qspice/qpixman/qcairo

* Wed Jan 28 2009 Alan Pevec <apevec@redhat.com> 82.ovirt1.test14-2
- rebuild for updated qspice/qffmpeg

* Thu Jan 22 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test14-1.el5ovirt
- kvm-82.ovirt1.test14:
  - dump virt flags on initialization
  - migration notification

* Thu Jan 22 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test13-6.el5ovirt
- Changed kvm group id to the official one assigned on the setup package (bz#481021)

* Wed Jan 21 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test13-5.el5ovirt
- Try to fix kmod-kvm upgrades:
  - Remove Provides: kernel-modules (bz#474472)
  - don't run weak-modules --remove-modules on upgrades

* Wed Jan 21 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test13-4.el5ovirt
- Remove rpm usage from kmod-kvm scriptlets

* Wed Jan 21 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test13-3.el5ovirt
- modprobe ksm-mem on ksm.modules

* Wed Jan 21 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test13-2.el5ovirt
- Create 'kvm' group on %%post

* Wed Jan 21 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test13-1.el5ovirt
- kvm-82.ovirt1.test13:
  - migration async notifiers

* Tue Jan 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test12-1.el5ovirt
- kvm-82.ovirt1.test12 (new ksm patche series)

* Tue Jan 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test11-1.el5ovirt
- Update to kvm-82.ovirt1.test11 (small build fix)

* Tue Jan 20 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test10-1.el5ovirt
- Updated to kvm-82.ovirt1.test10 (multiple bug fixes)

* Mon Jan 19 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test9-1.el5ovirt
- Updated to kvm-82.ovirt1.test9 (misc fixes)

* Mon Jan 19 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test8-1.el5ovirt
- Updated to ksm patch series #3

* Fri Jan 16 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test7-1.el5ovirt
- kvm-82.ovirt1.test7:
  - Added missing kernel patch needed for ksm

* Fri Jan 16 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test6-2.el5ovirt
- Package ksmctl and ksm udev rules

* Thu Jan 15 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test6-1.el5ovirt
- kvm-82.ovirt1.test6:
  - ksm compile fixes
  - simpler compat code
  - vnc disconnect notification patch

* Thu Jan 15 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test5-1.el5ovirt
- kvm_main.c compile fix

* Thu Jan 15 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test4-1.el5ovirt
- Update to kvm-82.ovirt1.test4:
  - Newer ksm patch series
  - More compat/warnings fixe

* Wed Jan 14 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test3-1.el5ovirt
- Update to kvm-82.ovirt1.test3. Many patches pulled

* Wed Jan 14 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test2-1.el5ovirt
- Update to latest maint/2.6.29 snapshot
- Include experimental ksm patches

* Mon Jan 12 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test1-2.el5ovirt
- Build with libspice support
- Use pkgconfig for spice
- Added BuildRequires to work around missing qspice-libs-devel requires
- Build against kernel 2.6.18-128.el5

* Wed Jan 07 2009 Eduardo Habkost <ehabkost@redhat.com> - 82.ovirt1.test1-1.el5ovirt
- Update to kvm-82.ovirt1.test1, that contains
  kvm-82-maint-snapshot-2009-01-05 + qxl patches

* Wed Jan 07 2009 Eduardo Habkost <ehabkost@redhat.com> - 82-2.maint.snapshot.2009.01.05.el5ovirt
- Don't use prebuilt binaries (bz#474886):
  - Build bios from source instead of using the prebuilt binaries
  - Use the pxe images from the etherboot packag

* Mon Jan 05 2009 Eduardo Habkost <ehabkost@redhat.com> - 82-1.maint.snapshot.2009.01.05.el5ovirt
- Rebase to maint/2.6.29 snapshot from 2009-01-05
- Add fix to kvm-trace build

* Tue Nov 11 2008 Eduardo Habkost <ehabkost@redhat.com> -77-3.maint.snapshot.2008.11.11.ovirt
- Respin maint/2.6.28 snapshot, from 2008-11-11:
  - kernel:    e45948b071d8be59044ac232d99a2ca83fd93266
  - userspace: ccabb53f1a84f11896c840391f7ade3756214086

* Tue Oct 28 2008 Eduardo Habkost <ehabkost@redhat.com> -77-2.maint.snapshot.2008.10.28.ovirt
- Rebase to kvm maint/2.6.28 snapshot from 2008-10-28:
  - kernel:    0d41e9e3f1c500a05716deaa927b56a15b133030
  - userspace: 7c29f61b152c036e9511941e4f0254f6de326052
- Patches removed, as they (or their equivalent) are already upstream:
  - kvm-qemu-migration-nowait.patch
  - kvm-Test-for-EXT_CONFIG_KVM_TRACE-instead-of-CONFIG_KVM_.patch

* Fri Oct 24 2008 Eduardo Habkost <ehabkost@redhat.com> -77-1.el5.ovirt
- Rebase to kvm-77
- Remove wildcards from %%files list
- Remove another sparc bios file that is not needed

* Thu Oct 23 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-12.el5.ovirt
- Fix building of extboot.bin
- Fix typo on %%{__smp_mflags} usage on %%build

* Wed Oct 22 2008 Eduardo Habkost <ehabkost@redhat.com> - 74.11.el5.ovirt
- Use RHEL kmod magic support to build modules, but with hacks
  to avoid the ksym dependencies and to make it work on brew

* Wed Oct 22 2008 Eduardo Habkost <ehabkost@redhat.com> - 74.10.el5.ovirt
- Add kvmtrace pthread_join() segfault fix

* Tue Oct 21 2008 Eduardo Habkost <ehabkost@redhat.com> - 74.9.el5.ovirt
- Add kvmtrace utilities to package
- Rebuild against kernel-2.6.18-120.el5

* Mon Oct 06 2008 Eduardo Habkost <ehabkost@redhat.com> - 74.8.el5.ovirt
- Rebuild against kernel-2.6.18-118.el5

* Wed Sep 24 2008 Eduardo Habkost <ehabkost@redhat.com> - 74.7.el5.ovirt
- Set with_modules=0 on Fedora
- Build i386 on Fedora

* Wed Sep 24 2008 Eduardo Habkost <ehabkost@redhat.com> - 74.6.el5.ovirt
- Fix build with with_modules=0
- Don't include qemu-img when built on Fedora
- Put qemu-img on a kvm-qemu-img subpackage, with Provides: qemu-img

* Tue Sep 23 2008 Eduardo Habkost <ehabkost@redhat.com> - 74.5.el5.ovirt
- Use native RHEL5 anon_inodes implementation instead of compat functions

* Mon Sep 22 2008 Eduardo Habkost <ehabkost@redhat.com> - 74.4.el5.ovirt
- Enable kvm_trace
- Use "real" release number (74-4.el5.ovirt) instead of .testX release
  numbers. The package is on CVS, now

* Fri Sep 19 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-3.el5.test5
- Build against kernel-2.6.18-116.el5

* Wed Sep 17 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-3.el5.test4
- Added depmod to kmod %%post and %%postun
- Fix %%if lines to make it possible to not build the kmod package
- Make kvm-kmod depend on the kernel it was built to
- Make kvm depend on kvm-kmod

* Tue Sep 16 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-3.el5.test3
- Rebuild against kernel 2.6.18-115.el5.extkvm_test13

* Thu Sep 11 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-3.el5.test2
- Package the kernel modules in a kvm-kmod package, hardcoded to build
  for 2.6.18-111.el5.extkvm_test12
- Fix page_find() and page_find_alloc() range-checking for addresses
  larger than 32-bit
- Remove i386 from ExclusiveArch, as we don't have i386 kernel packages
  built on the ovirt build target

* Tue Sep 08 2008 Glauber Costa <glommer@redhat.com> - 74-3.el5.test1
- Replace pxe boot patch with upstream version

* Wed Sep 03 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-2.el5.test4
- Rebuilding w/ the virtio-capable kernel-headers

* Tue Sep 02 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-2.el5.test3
- Added qemu-migration-nowait.patch

* Tue Sep 02 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-2.el5.test2
- Oops. Actually get qemu-img binary in the package, not only the man pages  :)

* Mon Sep 01 2008 Eduardo Habkost <ehabkost@redhat.com> - 74-2.el5.test1
- Added kvm-74-pxeboot-fix2.patch, Glauber's fix for the PXE boot triple fault
- Don't remove qemu-img from the package

* Thu Aug 28 2008 Glauber Costa <glommer@redhat.com> - 74-2
- just a tag increase, because CVS is so awesome...

* Thu Aug 28 2008 Glauber Costa <glommer@redhat.com> - 74-1
- Update to newly released kvm-74

* Tue Aug 26 2008 Glauber Costa <glommer@redhat.com> - 73-3.20080825
- Moved forward to yesterday's snapshot. It contains the remaining
  parts of mark's series of GSO patches. It sould be all back to normal
  when kvm-74 is released.

* Tue Aug 26 2008 Glauber Costa <glommer@redhat.com> - 73-2
- updated block rw patch

* Thu Aug 21 2008 Glauber Costa <gcosta@redhat.com> - 73-1
- Update to kvm-73.
- alsa enablement patch not needed anymore - removed.
- Add conditional so we can use this same rpm for rhel.

* Fri Aug 01 2008 Glauber Costa <gcosta@redhat.com> - 72-2
- Remove stubs-32.h BuildRequire. We are building fine without it.

* Mon Jul 28 2008 Glauber Costa <gcosta@redhat.com> - 72-1
- kvm-72

* Tue Jul 22 2008 Glauber Costa <gcosta@redhat.com> - 71-2
- Apply patches correctly.
- Enable ia64.

* Mon Jul 21 2008 Glauber Costa <gcosta@redhat.com> - 71-1
- Update to kvm-71
- --enable-alsa is no more, and kvm-71 seem to have troubles yet to
  be sorted out upstream with parameter passing to qemu. So as a temporary
  quickfix, add kvm-71-alsa.patch to handle it.

* Wed Jun 25 2008 Tomas Mraz <tmraz@redhat.com> - 70-2
- rebuild with new gnutls

* Tue Jun 17 2008 Glauber Costa <gcosta@redhat.com> - 70-1
- Update to kvm-70
- Added qemu-nbd command
- gcc34 build dependency is gone

* Tue May 20 2008 Glauber Costa <gcosta@redhat.com> - 69-1
- Update to kvm-69
- Removed Patch4 (Upstreamed)
- Removed virtio-boot patch (Upstreamed)
- Regenerated the other patches

* Mon May  5 2008 Daniel P. Berrange <berrange@redhat.com> - 68-1
- Update to kvm-68
- Put text console PTY in rawmode

* Tue Apr 29 2008 Mark McLoughlin <markmc@redhat.com> - 65-2
- Fix -kernel with virtio/extboot drives (#444578)

* Tue Apr  8 2008 Jeremy Katz <katzj@redhat.com> - 65-1
- Update to kvm-65 to fix smp instability

* Tue Apr  1 2008 Jeremy Katz <katzj@redhat.com> - 64-3
- and back to rtl8139 to avoid breaking windows guests (#439945)

* Fri Mar 28 2008 Jeremy Katz <katzj@redhat.com> - 64-2
- back to cirrus for video due to bugs with vmwarevga

* Fri Mar 28 2008 Jeremy Katz <katzj@redhat.com> - 64-1
- update to kvm-64

* Fri Mar  7 2008 Jeremy Katz <katzj@redhat.com> - 63-2
- Fix the build

* Wed Mar  5 2008 Jeremy Katz <katzj@redhat.com> - 63-1
- Update to kvm-63

* Tue Mar  4 2008 Kevin Fenzi <kevin@tummy.com> - 62-4
- Make e1000 the default network driver

* Mon Mar  3 2008 Jeremy Katz <katzj@redhat.com> - 62-3
- Default to vmwaresvga now that it's been fixed to work

* Wed Feb 27 2008 Daniel P. Berrange <berrange@redhat.com> - 62-2.fc9
- Fix block device checks for extendable disk formats (rhbz #434978)

* Tue Feb 26 2008 Jeremy Katz <katzj@redhat.com> - 62-1
- Update to kvm-62

* Tue Feb 19 2008 Daniel P. Berrange <berrange@redhat.com> - 61-2.fc9
- Fix block device extents check (rhbz #433560)

* Tue Feb 19 2008 Daniel P. Berrange <berrange@redhat.com> - 61-1.fc9
- Updated to kvm-61

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 60-2
- Autorebuild for GCC 4.3

* Thu Jan 31 2008 Jeremy Katz <katzj@redhat.com> 
- We don't need e2fsprogs-devel to build anymore (#331871)

* Thu Jan 24 2008 Daniel P. Berrange <berrange@redhat.com> - 60-1.fc9
- Updated to kvm-60
- Fix license tag to keep rpmlint quiet
- Remove unused PPC, Sparc and PPC Video BIOS

* Tue Jan 15 2008 Bill Nottingham <notting@redhat.com>: - 59-1
- add upstream patch to fix VMs that no longer boot (#427317)
- update to kvm-59

* Thu Dec 27 2007 Jeremy Katz <katzj@redhat.com> - 58-2
- Fix up defaults patch to apply

* Thu Dec 27 2007 Jeremy Katz <katzj@redhat.com> - 58-1
- Update to kvm-58

* Thu Dec 13 2007 Jeremy Katz <katzj@redhat.com> - 56-1
- Update to kvm-56

* Tue Dec  4 2007 Jeremy Katz <katzj@redhat.com> - 55-1
- Update to kvm-55

* Mon Dec  3 2007 Jeremy Katz <katzj@redhat.com> - 54-1
- update to kvm-54

* Tue Nov 20 2007 Jeremy Katz <katzj@redhat.com> - 53-1
- update to kvm-53

* Wed Nov  7 2007 Jeremy Katz <katzj@redhat.com> - 51-1
- update to kvm-51

* Tue Nov  6 2007 Jeremy Katz <katzj@redhat.com> - 50-1
- update to kvm-50, drop all the patches that have gone upstream

* Mon Oct 15 2007 Daniel P. Berrange <berrange@redhat.com> - 36-7.fc8
- Fixed PXE boot when KVM is enabled (rhbz #331191)

* Wed Sep 26 2007 Daniel P. Berrange <berrange@redhat.com> - 36-6.fc8
- Fixed rtl8139 checksum calculation for Vista (rhbz #308201)

* Mon Sep 24 2007 Jeremy Katz <katzj@redhat.com> - 36-5
- fix build on x86_64

* Mon Sep 24 2007 Jeremy Katz <katzj@redhat.com> - 36-3
- add support for selecting boot device at runtime

* Tue Sep  4 2007 Jeremy Katz <katzj@redhat.com> - 36-2
- rebase vnc auth patch

* Tue Sep  4 2007 Jeremy Katz <katzj@redhat.com> - 36-1
- update to kvm-36

* Mon Aug 27 2007 Daniel P. Berrange <berrange@redhat.com> - 35-3.fc8
- Added patch for VNC password auth and TLS+x509 cert auth

* Mon Aug 20 2007 Jeremy Katz <katzj@redhat.com> - 35-2
- add fix for ATAPI from upstream qemu

* Mon Aug 20 2007 Jeremy Katz <katzj@redhat.com> - 35-1
- update to kvm-35
- patch to use -Wl,--build-id so that we get debuginfo

* Thu Jul 19 2007 Jeremy Katz <katzj@redhat.com> - 31-1
- update to kvm-31

* Mon Jul 16 2007 Jeremy Katz <katzj@redhat.com> - 28-2
- add patch from danpb to fix mac addrs of multiple 8139 nics (#247641)

* Wed Jun 13 2007 Jeremy Katz <katzj@redhat.com> - 28-1
- update to kvm-28

* Sat Jun  9 2007 Jeremy Katz <katzj@redhat.com> - 27-1
- update to kvm-27

* Tue May 29 2007 Jeremy Katz <katzj@redhat.com> - 26-1
- update to kvm-26

* Wed May 16 2007 Jeremy Katz <katzj@redhat.com> - 24-1
- update to kvm-24

* Wed Apr 25 2007 Jeremy Katz <katzj@redhat.com> - 19-2
- fix kernel and ramdisk being specified on the command line (#237879)

* Tue Apr 17 2007 Jeremy Katz <katzj@redhat.com> - 19-1
- update to kvm-19
- use rtl8139 as the default nic emulation instead of ne2k_pci (#236790)

* Mon Mar 26 2007 Jeremy Katz <katzj@redhat.com> - 15-2
- add file so that kvm modules get loaded on boot

* Wed Mar  7 2007 Jeremy Katz <katzj@redhat.com> - 15-1
- update to kvm-15

* Mon Feb 26 2007 Jeremy Katz <katzj@redhat.com> - 14-2
- use default optflags for non-qemu pieces (#230012)

* Fri Feb 23 2007 Jeremy Katz <katzj@redhat.com> - 14-1
- update to kvm-14
- note: this requires a kernel that's 2.6.21-rc1 or newer

* Mon Feb 19 2007 Jeremy Katz <katzj@redhat.com> - 12-3
- add the buildrequires for the docs to build

* Mon Feb 19 2007 Jeremy Katz <katzj@redhat.com> - 12-2
- include bios and keymaps in the kvm package since we need a slightly 
  different version for kvm now
- include man page

* Fri Jan 26 2007 Jeremy Katz <katzj@redhat.com> - 12-1
- update to kvm-12
- add qemu patch for better ATAPI DMA support (which works with ata_piix)

* Fri Jan 19 2007 Jeremy Katz <katzj@redhat.com> - 11-1
- update to kvm-11

* Fri Jan  5 2007 Jeremy Katz <katzj@redhat.com> - 9-1
- update to kvm-9

* Wed Jan  3 2007 Jeremy Katz <katzj@redhat.com> - 7-4
- actually build without -devel...

* Wed Dec 20 2006 Jeremy Katz <katzj@redhat.com> - 7-3
- remove the -devel subpackage since there's no shared lib upstream yet
- direct download link for source 

* Tue Dec 19 2006 Jeremy Katz <katzj@redhat.com> - 7-2
- BR e2fsprogs-devel

* Tue Dec 19 2006 Jeremy Katz <katzj@redhat.com> - 7-1
- Initial build 

